/*-----------------------------------------------------------------------
Nom du fichier: HMC6352
Auteur: Philippe Mariano

Document ressource: http://www.magneticsensors.com/datasheets/HMC6352.pdf

Rle : Fichier d'en tte pour la commande de la boussole Honeywell HMC6352

Cr le :  19/05/2010
Dernire rvision le : 24/02/2011

Cross compilateur utilis: CodeVisionAVR V2
Composant cible : ATMEL 8 bits

Remarque: Ce fichier est destin  un projet CVAVR 
Il doit tre plac dans le sous rpertoire \CVAVR\INC\ ou dans le rpertoire
du projet
------------------------------------------------------------------------*/
#ifndef _HM6352_INCLUDED_ 	
#define _HM6352_INCLUDED_

#pragma used+
/*--------------------------------------------------------------------------------------------------------------
 Commande de la boussole Honeywell HMC6352 avec les fonctions du driver TWI_Master
----------------------------------------------------------------------------------------------------------------
Mots de commande (pour info) 
----------------------------------------------------------------------------------------------------------------
Cde Byte  | Arg 1 byte		| Arg 2 byte |   response 1 byte | response 2 byte | Description
----------------------------------------------------------------------------------------------------------------
'w'(0x77) |	EEPROM Address  | 	data     |                   |                 | Write to EEPROM
'r'(0x72) |	EEPROM Address  | 	         |     data          |                 | Read to EEPROM
'G'(0x47) | RAM address     |   data     |                   |                 | Write to RAM
'g'(0x67) | RAM address     |    	     |     data          |                 | Read to RAM
'S'(0x53) | 																   | Enter to sleep mode
'W'(0x57) | 																   | Exit to sleep mode
'O'(0x4F) | 																   | Update Bridge Offsets (S/R Now)
'C'(Ox43) | 																   | Enter User Calibration mode
'E'(0x45) | 																   | Exit User Calibration mode   
'L'(0x4C) | 																   | Save Op Mode to EEPROM
'A'(0x41) |                 |    	     |     MSB data      |    LSB Data     | Get data. Compensate and
																			   | Calculate New heading
----------------------------------------------------------------------------------------------------------------
A modifier ventuellement aprs ESSAIS !!!!!!
-------------------------------------------------------------------------------------------------------------
Pour lire un ou plusieurs registre(s) de la la boussole Honeywell HMC6352
- Avec la fonction "TWI_Start_Transc_With_Data()":
(1) Envoyer la trame 1 { HMC6352_ADD_BASE_W, Octet_Numro_premier_registre__Lire }  puis
(2) Envoyer la trame 2 { HMC6352_ADD_BASE_R, emplacements libres pour les donnes }
- Avec la fonction "TWI_Get_Data_From_Transceiver()":
Transfrer le contenu du buffer TWI dans le tableau "message"
-------------------------------------------------------------------------------------------------------------
Pour crire dans un registre
Avec la fonction "TWI_Start_Transc_With_Data()"
Envoyer la trame { HMC6352_ADD_BASE_W, Octet_Numro_registre__Ecrire, Valeur__crire }
--------------------------------------------------------------------------------------------------------------*/

//--------------------------------------------------------------------------------------------------------------
// Espace d'adressage de la boussole Honeywell HMC6352
//--------------------------------------------------------------------------------------------------------------
// Adresses de base de la boussole (par dfaut)
//--------------------------------------------------------------------------------------------------------------
#ifndef
#define HMC6352_SLA_W				    0x42    // Octet de l'adresse de base par dfaut +R/W=0  redfinir dans
#endif					                	    // le fichier source du programme si ncessaire

#ifndef
#define HMC6352_SLA_R				    0x43    // Octet de l'adresse de base par dfaut +R/W=1  redfinir dans
#endif										    // le fichier source du programme si ncessaire
//--------------------------------------------------------------------------------------------------------------
// Adresses des registres en RAM de la boussole HMC6352
//--------------------------------------------------------------------------------------------------------------
#ifndef
#define	Operational_Mode_RAM		    0x74  	    // Adresse du registre de control du mode oprationnel
#endif                                  			// (measurement rate, set/reset, standby, query, continuous)


#ifndef
#define Output_Mode_RAM				    0x4E	    //  Format du rsultat de la mesure
#endif                                  			// 	0 - 3599 par dfaut

//--------------------------------------------------------------------------------------------------------------
// Adresses des registres en EEPROM de la boussole HMC6352
//--------------------------------------------------------------------------------------------------------------
#ifndef
#define HMC6352_Reg_ADD_BASE		    0x00	    // Sauvegarde de l'adresse de la boussole
#endif                                              // 0x42 par dfaut

#ifndef
#define HMC6352_Reg_MagnX_MSB		    0x01	    // poids fort du mot X
#endif                                              // valeur issue d'un test constructeur par dfaut

#ifndef
#define HMC6352_Reg_MagnX_LSB		    0x02	    // poids faible du mot X
#endif                                              // valeur issue d'un test constructeur par dfaut

#ifndef
#define HMC6352_Reg_MagnY_MSB		    0x03	    // poids fort du mot Y
#endif                              				// valeur issue d'un test constructeur par dfaut

#ifndef
#define HMC6352_Reg_MagnY_LSB		    0x04	    // poids faible du mot Y
#endif												// valeur issue d'un test constructeur par dfaut

#ifndef
#define HMC6352_Reg_Delay		    	0x05	    // Delais entre deux mesures (0 - 255ms)
#endif                                              // 1ms par dfaut

#ifndef
#define HMC6352_Reg_Average_Measure		0x06	    // Nombre de valeur  moyenner sur une mesure (1  16)
#endif                                              // 4 par dfaut

#ifndef
#define HMC6352_Reg_Soft_Vers			0x07	    // Version du logiciel
#endif                                              // > 1

#ifndef
#define Operational_Mode_EEPROM     	0x08	    // Sauvegarde du contenu du registre "Operational_Mode_RAM"
#endif                                  		    // 0x50 par dfaut

/*--------------------------------------------------------------------------------------------------------------
 Construction du contenu du registre Operational_Mode_MEM avec MEM = RAM ou EEPROM 
 --------------------------------------------------------------------------------------------------------------
 b7 = 0
 b6 b5 : Continuous Mode Measurement Rate 
    
 b6 b5  Description
 -------------------------------
 0  0   1Hz Measurement Rate
 0  1   5Hz Measurement Rate
 1  0   10Hz Measurement Rate
 1  1   20Hz Measurement Rate
 
 b4 : (Periodic SET/RESET), 0 = Off , 1 = On
 b3 = 0
 b2 = 0
 b1 b0 : Operational Mode Value 
 
 b1 b0  Description
 -------------------------------
 0  0   Standby Mode
 0  1   Query Mode
 1  0   Continuous Mode
 1  1   Not Allowed

--------------------------------------------------------------------------------------------------------------
Construction du contenu du registre Output Data Mode
 --------------------------------------------------------------------------------------------------------------
 b7  b3= 0
  
 b2 b1 b0: Output Mode Value
 b2 b1 b0  Description
 -------------------------------
 0  0  0 Heading Mode
 0  0  1 Raw Magnetometer X Mode
 0  1  0 Raw Magnetometer Y Mode
 0  1  1 Magnetometer X Mode
 1  0  0 Magnetometer Y Mode  
 --------------------------------------------------------------------------------------------------------------*/
//**************************************************************************************************************
#endif
