/*==============================================================================
Nom du fichier source : LitClav102.h
Auteur: Philippe MARIANO

Cr le 15/03/2008
Dernire rvision le : 23/03/2011

Rle: Fichier d'en-tte de la librairie LitClav102.lib
Description : Dsrialiser et dcoder une trame issue d'un clavier de PC type PS2
Sources : Note d'application ATMEL AVR313 "interfacing the PC AT Keyboard" 
adaptes au cross compilateur CVAVR V2.

Cross compilateur utilis: CodeVisionAVR V2
Composant cible : Atmel 8 bits (ATMega8535)

A placer dans le rpertoire du projet
================================================================================*/


#ifndef _LitClav102_INCLUDED_
#define _LitClav102_INCLUDED_

#pragma used+

//******************************************************************************
//******************************************************************************
// GESTION d'un clavier de PC type PS2
//******************************************************************************
//******************************************************************************

// Interrupt vectors definitions
// Sur la carte SSI V1, le signal "clock" du clavier est reu par la broche PD2
#ifndef EXT_INT0
#define EXT_INT0 	    2
#endif

// Sur la carte SSI V1, le signal "DATA"est reu par la broche PA0
// Mettre le cavalier PAO en 1-->2
#ifndef SENS_DATA_CLAV
#define SENS_DATA_CLAV	DDRA.0
#endif
#ifndef DATA_CLAV
#define DATA_CLAV 	    PINA.0
#endif


#ifndef SORTIE
#define SORTIE		    1
#endif
#ifndef ENTREE
#define ENTREE		    0
#endif

// Rglage du sens de la communication dans la routine d'interruption
#ifndef RECEPTION
#define RECEPTION		0
#endif

#ifndef TRANSMISSION
#define TRANSMISSION	1
#endif

// bits de contrle du clavier IBM PC
//--------------------------------------------Trame------------Code -----------
#ifndef REINITIALISATION_CLAVIER
#define REINITIALISATION_CLAVIER 	0b0000001111111111
#endif						//  0xFF parit impaire 1 bit de stop


//---------------------------------------------------------------------------------------------------------------------
/* Communication avec le clavier PS2
Le programme principal se synchronise avec la routine d'interruption situe dans 
la bibliothque LitClav.lib avec les variables ci-dessous
---------------------------------------------------------------------------------------------------------------------*/ 
extern unsigned char g_key_ASCII; 	    // Contient le code ASCII de la touche presse  
					                    // ( initialiser avec un caractre n'existant 
					                    // pas sur le clavier utilis)
extern bit g_flag_char;			        // g_flag_char = 1 lorsqu'une touche est appuye
					                    // g_flag_char = 0 lorsqu'une touche a t relche
extern bit g_Sens_transfert;		        // Indique le sens de la communication  
					                    // g_Sens_transfert = 0 => C <--- clavier
			  		                    // g_Sens_transfert = 1 => C ---> clavier
extern unsigned int g_Trame_TX;  
// ------------------------------------------------------------------------------------------
// Sous programme d'interruption dclench lors de la capture d'un front sur INT0
// ------------------------------------------------------------------------------------------
interrupt [EXT_INT0] void ext_int0_isr(void);
/*
Rle : Dcoder et dsrialiser la trame IBM issue du clavier type PS2 ou transmettre
des caractres de contrle au clavier pour dtecter sa prsence et le configurer.

Description du fonctionnement:
// ------------------------------------------------------------------------------------------
EN RECEPTION: Acquire les 11 bits de la trame IBM transmise par le clavier, les
dsrialise, dcode le caractre reu grace aux tables shift[][] et unshift[][] situe dans
le fichier scancode2.h et place le caractre ASCII correspondant dans une variable globale
<g_key_ASCII>. Previent la routine consommatrice du caractre en positionnant  1 le drapeau
<g_flag_char>.

EN EMMISSION : Transmet les 10 bits de la valeur contenue dans la variable globale de type
entier <g_trame_TX> sur les fronts montants du signal d'horloge (fourni par le clavier) puis
repasse en rception.

// ------------------------------------------------------------------------------------------

Table de transcodage utilise : scancode2.h

// ------------------------------------------------------------------------------------------
Entres :
- Trame IBM issue d'un clavier PS2 (signal "clock" reli  la broche INT0 du C
et signal "DATA" reli  la broche dfinie plus haut (PAO sur la carte SSI).

- <g_Sens_transfert> : variable globale de type unsigned char indiquant le sens de
communication (C <---> clavier) que doit grer la routine d'interruption
		<g_Sens_transfert>  = 0  => RECEPTION (C <--- clavier)
		<g_Sens_transfert>  = 1  => Transmission (C ---> clavier)

- <g_Trame_TX>  : variable globale de type unsigned int contenant la trame 
transmettre au clavier (transmission des 10 bits de poids faible).
Composition de la trame :0 0 0 0 0 0 d7 d6 d5 d4 d3 d2 d1 d0 (parit) (stop=1)
Remarque: la parit est impaire par dfaut.

// ------------------------------------------------------------------------------------------
Sorties :
- <g_key_ASCII> : variable globale de type unsigned char contenant le code ASCII du caractre
correspondant  la touche dtecte. Ce code est obtenu dans la table de transcodage situe dans
<scancode2.h>

- <g_flag_char> :variables globales de type unsigned char
		<g_flag_char> = 1 lorsqu'une touche est presse
		<g_flag_char> = 0 lorsqu'une touche a t relche

//============================================================================================
REMARQUE IMPORTANTE : LES VARIABLES DEFINIES CI-DESSUS DOIVENT OBLIGATOIREMENT ETRE PLACEES
DANS LE CHAMP "VARIABLES GLOBALES" DU PROGRAMME FAISANT APPEL A LA ROUTINE D'INTERRUPTION.
//============================================================================================
*/

#pragma used-

#pragma library LitClav102.lib

#endif