/*==============================================================================
Nom du fichier source : LitClav102.c
Auteur: Philippe MARIANO

Rle: Source de la librairie LitClav102.lib
Description : Dsrialiser et dcoder une trame issue d'un clavier de PC type PS2
Sources : Note d'application ATMEL AVR313 "interfacing the PC AT Keyboard" 
adaptes au cross compilateur CVAVR V2.

Cr le 15/03/2008
Dernire rvision le : 23/03/2011

Cross compilateur utilis: CodeVisionAVR V2
Composant cible : Atmel 8 bits (ATMega8535)

Remarque: Une fois compil par -> file --> Convert library
le fichier LitClav102.lib est automatiquement plac dans le rpertoire CVAVR\LIB
A placer dans le rpertoire du projet
================================================================================*/

//--------------------------------------------------------------------------------------------------------
// Bibliothques
//--------------------------------------------------------------------------------------------------------
#include <mega8535.h>
//--------------------------------------------------------------------------------------------------------
// Dveloppes pour l'appication ( placer dans le rpertoire du projet)
//--------------------------------------------------------------------------------------------------------
#include "scancode2.h"
#include "LitClav102.h"
//--------------------------------------------------------------------------------------------------------

//========================================================================================================
//========================================================================================================
// -------------------------------------------------------------------------------------------------------
// Sous programme d'interruption dclench lors de la capture d'un front sur INT0
// -------------------------------------------------------------------------------------------------------
#if funcused ext_int0_isr
interrupt [EXT_INT0] void ext_int0_isr(void)
{
//========================================================================================================
// Variables 
//--------------------------------------------------------------------------------------------------------
//  type 			    Dsignation			            Commentaires
//--------------------------------------------------------------------------------------------------------
//Remarques g_ : variables globales
//--------------------------------------------------------------------------------------------------------
static unsigned int 	g_data = 0; 	  	// Trame transmise par le clavier
static unsigned char 	g_data_aff;         // Caractre extrait de la trame transmise par le clavier

static unsigned char 	edge = 0; 		    // edge = 0 si front descendant; edge =  1 si front montant
					  	                    // (du signal CLK provenant du clavier)
static char 		    bitcount_RX = 11;	// Permet de mmoriser le nombre de bits reus du clavier
static char 		    bitcount_TX = 10;   // Permet de mmoriser le nombre de bits transmis au clavier

static unsigned char 	is_up=0;		    // Etat de la touche
					  	                    // is_up = 0 : touche relche
					                        // is_up = 1 : touche actionne

static unsigned char    shift = 0;		    // Dtection action sur la touche shift
unsigned char 		    i;                  // Compteur d'usage gnral
//========================================================================================================


switch (g_Sens_transfert)
{// Debut switch1
//========================================================================================================
// Rception de la trame PS2
//--------------------------------------------------------------------------------------------------------
  case 0 :
// Dsrialisation 
//--------------------------------------------------------------------------------------------------------
  if (!edge)                                    // Si front descendant
  {// dbut if_1
    if (bitcount_RX < 12 && bitcount_RX > 0)    // Acquisition d'un bit du code
    {                                           // dbut if_2 sur le front descendant de clk
      g_data = (g_data >> 1);
      if (DATA_CLAV)
        g_data = g_data | 0x8000;

    }// fin if_2
    MCUCR = 3;                                  // INT0 actif sur le prochain front montant
    edge = 1;
  }//fin if_1

 else                                           // si front descendant: dcomptage du nombre de bits
  {                                             // Dbut sinon_1 reus sur le front montant
    MCUCR = 2;                                  // INT0 actif sur le prochain front descendant
    edge = 0;
    if (--bitcount_RX == 0)
     { // dbut if3
       g_data = (g_data >> 5);                  // Les 11 bits reus sont positionns dans g_data
                                                // Extraction du code caractre dans
       g_data_aff = (g_data>>1);                // la trame au format PS2
       
//--------------------------------------------------------------------------------------------------------
// Dcodage du caractre reu
//--------------------------------------------------------------------------------------------------------
      if (!is_up)                               // si dernier caractre reu = touche relche
        {                                       // dbut if_4
          switch (g_data_aff)
           {                                    // dbut switch_2
             case 0xf0 :                        // touche relche
               is_up = 1;
               g_flag_char = 0;
             break;

             case 0x12 :                        // dtection shift gauche
               shift = 1;
             break;

             case 0x59 :                        // dtection shift droite
               shift = 1;
             break;

             default:
               if (!shift)                      // shift non appuy
                 {
                  for (i = 0; unshifted[i][0] != g_data_aff && unshifted[i][0]; i++);
                  if (unshifted[i][0] == g_data_aff)
                   {
                     g_key_ASCII = unshifted[i][1];
                     if (g_flag_char==0)
                 		g_flag_char = 1;
                   }
                 }
                 else                           // si shift appuy
                 {
                  for (i = 0; shifted[i][0] != g_data_aff && shifted[i][0]; i++);
                  if (shifted[i][0] == g_data_aff)
                   {
                     g_key_ASCII = shifted[i][1];
                     if (g_flag_char==0)
                       		g_flag_char = 1;
                   }
                 }
             break;
          }                                     // fin switch_2
       }                                        // fin if_4

       else
         {
          is_up = 0;
          switch (g_data_aff)
           {
             case 0x12 :                        // dtection shift gauche
               shift = 0;
             break;

             case 0x59 :                        // dtection shift droite
              shift = 0;
             break;
          }
         }  
          bitcount_RX = 11;                     // Initialisation du compteur de rception
     }                                          // fin if_3
   }                                            // fin sinon_1
 break;                                         // fin case_0
//========================================================================================================
// Emmission d'une trame PS2
//--------------------------------------------------------------------------------------------------------
 case 1:  
         if (bitcount_TX != 0)
             {
              DATA_CLAV = g_Trame_TX;
              bitcount_TX -= 1;
              g_Trame_TX = (g_Trame_TX >> 1);
             }
         else
             {
              bitcount_TX = 10;                 // Initialisation du compteur de rception
              g_Sens_transfert = RECEPTION;     // Mode rception en fin d'mmission
              SENS_DATA_CLAV = ENTREE;          // Broche du signal Data en entre
             }
 break;                                         // fin case 1
 }                                              // fin switch 1
}
//========================================================================================================
#endif
//========================================================================================================
//========================================================================================================

