/*-----------------------------------------------------------------------
Nom du fichier: SISISVL.h
Auteur: Philippe MARIANO

Projet: Robot suiveur de ligne
Rle: fichier d'en-tte de la bibliothque "SISISVL.lib"
Cr le: 21/01/2010
Dernire rvision le:  17/02/2010

Cross compilateur utilis: CodeVisionAVR
Composant cible : ATMEL 8 bits sur carte "Robot SISI"

Remarque: Ce fichier est destin  un projet CVAVR utilisant la carte SSI
Il doit tre plac dans le sous rpertoire \CVAVR\INC\ ou dans le rpertoire 
du projet 
------------------------------------------------------------------------*/

// -----------------------------------------------------------------------------------------------
#ifndef _SISISVL_INCLUDED_ 	
#define _SISISVL_INCLUDED_ 
   
// ***********************************************************************************************

// ***********************************************************************************************
// 										DEFINITIONS
// ===============================================================================================
// Definitions pour l'interface IHM de la carte ATMEL SISI  
// BP et Leds sur le bus I2C 
// ===============================================================================================
// Code des BPs 
// -----------------------------------------------------------------------------------------------
#ifndef ECHAP_I2C
#define ECHAP_I2C   	128  
#endif 
#ifndef ENTR_I2C
#define ENTR_I2C 		64 
#endif
#ifndef OK_I2C
#define OK_I2C			32  
#endif 
#ifndef SET_I2C
#define SET_I2C			16 
#endif
#ifndef MOINS_I2C
#define MOINS_I2C     	8 
#endif
#ifndef FlecheB_I2C
#define FlecheB_I2C 	4 
#endif  
#ifndef FlecheH_I2C
#define FlecheH_I2C 	2 
#endif 
#ifndef PLUS_I2C
#define PLUS_I2C     	1
#endif  
// -----------------------------------------------------------------------------------------------
// Adresses des Ports E/S I2C PCF8574 relis au BP et aux LED
// -----------------------------------------------------------------------------------------------
#ifndef Add_LED_I2C
#define Add_LED_I2C   	0x40    // SLA+W
#endif  

#ifndef Add_BP_I2C
#define Add_BP_I2C   	0x42  	// SLA+W
#endif
// ===============================================================================================
// =============================================================================================== 
// Dfinitions pour le robot suiveur de ligne
// ===============================================================================================
// Sortie du comparateur analogique
// -----------------------------------------------------------------------------------------------
#ifndef AC0
#define ACO 	ACSR.5            
#endif
// -----------------------------------------------------------------------------------------------
// Signaux de commande des capteurs IR (capteur  5 cellules)
// ----------------------------------------------------------------------------------------------- 
// PA7 | PA6 | PA5 | PA4  | PA3 | PA2 | PA1 | PA0
// Res | Res | Res | IRG  |IRCG | IRC |IRCD | IRD  connecteur vers l'avant
// Res | Res|  Res | IRD  |IRCD | IRC |IRCG | IRG  connecteur vers l'arrire 
// Res: utilis par capteur 8 cellules
#ifndef CAPTEUR_IR
#define CAPTEUR_IR 	PORTA  
#endif   
// -----------------------------------------------------------------------------------------------
// Signaux de commande des moteurs 
// -----------------------------------------------------------------------------------------------  
#ifndef CDE_MOTD
#define CDE_MOTD	OCR1AL       	// Cde moteur Droit
#endif
#ifndef CDE_MOTG
#define CDE_MOTG	OCR1BL	    	// Cde moteur Gauche     
#endif
// -----------------------------------------------------------------------------------------------
// Signaux de commande des Servos
// ----------------------------------------------------------------------------------------------- 
#ifndef CDE_SERVO1
#define CDE_SERVO1	PORTD.6
#endif
#ifndef CDE_SERVO2
#define CDE_SERVO2	PORTD.7
#endif   
// -----------------------------------------------------------------------------------------------
// Adresses de la CGRAM de l'afficheur LCD type Hitachi
// ----------------------------------------------------------------------------------------------- 
//@ : adresse  
#ifndef Add_FlecheH_CGRAM
#define Add_FlecheH_CGRAM 0x40 // @1 Caractre flche haut
#endif
#ifndef Add_FlecheB_CGRAM
#define Add_FlecheB_CGRAM 0x48 // @2 Caractre flche bas
#endif
// -----------------------------------------------------------------------------------------------
// Caractres spcifiques  afficher sur le LCD  
// ----------------------------------------------------------------------------------------------- 
#ifndef Caractere_FlecheH
#define Caractere_FlecheH	0 
#endif
#ifndef Caractere_FlecheB
#define Caractere_FlecheB	1
#endif
// -----------------------------------------------------------------------------------------------
// ===============================================================================================


// ***********************************************************************************************
// ***********************************************************************************************
// Prototype des fonctions dveloppes pour la carte SISI monte sur un robot suiveur de ligne
// ***********************************************************************************************
// ***********************************************************************************************
// ----------------------------------------------- Rcapitulatif --------------------------------- 
// 1 unsigned char Lire_BP_I2C_Soft(void);
// 2 Affiche_LCD(char *ligne0,char *ligne1);
// 3 void Arret_Moteurs(void);
// 4 void Active_Moteurs(void);
// 5 void Affiche_Fleche(void);
// 6 void Prise_Balle(void);
// -----------------------------------------------------------------------------------------------

#pragma used+

unsigned char Lire_BP_I2C_Soft(void);
/* -----------------------------------------------------------------------------------------------
Rle : Lit l'tat des boutons-poussoirs de l'IHM relie  la carte ATMEL S_ISI(PCF8574) 
et renvoie un code sur 8 bits. Remarque : I2C mul.

Commentaires : Dans un premier temps, la fonction renvoie le code du bouton-poussoir 
actionn (PLUS_I2C = 0x01, FlecheH=0x02, FlecheB=0x04, MOINS_I2C = Ox08, SET_I2C = 0x10, 
OK_I2C = 0x20, ENTR_I2C=0x40, ECHAP_I2C = 0x80) puis elle renvoie 0xFF si la touche est 
maintenue ou 0x00 si la touche est relche.

Entres : aucunes

Sortie : code de la touche ou 0x00(relche) ou 0xFF(maintenue)
-----------------------------------------------------------------------------------------------*/   
// --------------------------------------------------------------------------------------------------------
void Affiche_LCD(char *ligne0,char *ligne1);
/* --------------------------------------------------------------------------------------------------------
Rle : Gre l'affichage d'un LCD quip d'un contrleur Hitachi (command en mode 4 bits)

Commentaires : Envoie le contenu de deux tableaux de 16 caractres sur les lignes 0 et
1 d'un afficheur LCD 2*16 caractres.
Chaque tableau doit pouvoir contenir 17 valeurs (les 16 caractres  afficher + \0)

Librairie utilis : lcd.h

Entres : ligne0, ligne1 = tableaux de 17 caractres

Sorties : Aucune
---------------------------------------------------------------------------------------------------------*/
void Arret_Moteurs(void);
// ----------------------------------------------------------------------------------------------

// ----------------------------------------------------------------------------------------------
void Active_Moteurs(void);
// ----------------------------------------------------------------------------------------------

// ----------------------------------------------------------------------------------------------
void Affiche_Fleche(void);
// ---------------------------------------------------------------------------------------------- 

// ----------------------------------------------------------------------------------------------
void Prise_Balle(void);
// ---------------------------------------------------------------------------------------------- 

#pragma used-

#pragma library SISISVL.lib

#endif    // termine la directive ifndef