/*****************************************************************************************
******************************************************************************************
Nom du fichier:SISI2.h
------------------------------------------------------------------------------------------
Auteur: Philippe MARIANO
------------------------------------------------------------------------------------------
Rle: fichier d'en-tte de la librairie sisi2.lib
------------------------------------------------------------------------------------------
Cr le : 29/03/2011
Dernire rvision le : 14/01/2012
------------------------------------------------------------------------------------------
Cross compilateur utilis: CodeVisionAVR V2.04.08
------------------------------------------------------------------------------------------
Composants cibles : ATMEL 8 bits
------------------------------------------------------------------------------------------
CIBLE HARDWARE: Carte pour les TP ATMEL SISI 
------------------------------------------------------------------------------------------
Remarques:
Ce fichier est destin  un projet CVAVR utilisant la carte SISI
Il doit tre plac dans le rpertoire du projet avec le fichier SISI.lib
*****************************************************************************************
*****************************************************************************************/

#ifndef _SISI2_INCLUDED_         // Evite que le fichier ne soit inclus plusieurs fois
#define _SISI2_INCLUDED_

// **************************************************************************************************************
// **************************************************************************************************************
// 										        DEFINITIONS
// ==============================================================================================================
// Definitions pour l'interface IHM de la carte ATMEL SISI (BP et Leds sur le bus I2C)   
// ==============================================================================================================
// Code des BPs 
//---------------------------------------------------------------------------------------------------------------
#ifndef ECHAP_I2C
#define ECHAP_I2C   	128  
#endif 
#ifndef ENTR_I2C
#define ENTR_I2C 		64 
#endif
#ifndef OK_I2C
#define OK_I2C			32  
#endif 
#ifndef SET_I2C
#define SET_I2C			16 
#endif
#ifndef MOINS_I2C
#define MOINS_I2C     	8 
#endif
#ifndef FlecheB_I2C
#define FlecheB_I2C 	4 
#endif  
#ifndef FlecheH_I2C
#define FlecheH_I2C 	2 
#endif 
#ifndef PLUS_I2C
#define PLUS_I2C     	1
#endif  
//---------------------------------------------------------------------------------------------------------------
// Adresses par dfaut des Ports E/S I2C PCF8574 relis au BP et aux LED
//---------------------------------------------------------------------------------------------------------------
// !!!!!!!!!!!!!!!!!!!!!!!!!!  Vrifier la position des cavaliers sur la carte IHM SISI  !!!!!!!!!!!!!!!!!!!!!!!!
#ifndef Add_LED_I2C
#define Add_LED_I2C   	0x40    // SLA+W   
#endif  

#ifndef Add_BP_I2C
#define Add_BP_I2C   	0x42  	// SLA+W
#endif
//---------------------------------------------------------------------------------------------------------------
// Adresses de base de la CGRAM dans l'afficheur LCD  processeur Hitachi
//---------------------------------------------------------------------------------------------------------------  
#ifndef Add_Base_CGRAM
#define Add_Base_CGRAM           0x40              
#endif
//---------------------------------------------------------------------------------------------------------------
// Caractres spcifiques  afficher sur le LCD  
//--------------------------------------------------------------------------------------------------------------- 
#ifndef Caractere_FlecheH
#define Caractere_FlecheH	        0 
#endif
#ifndef Caractere_FlecheB
#define Caractere_FlecheB	        1
#endif
// **************************************************************************************************************
// **************************************************************************************************************
// Prototype des fonctions gnrales de la carte SSI
// **************************************************************************************************************
// **************************************************************************************************************
// 1 unsigned char Lire_BP_I2C_Soft(void);                                         // Clavier carte IHM SISI
// 2 Affiche_LCD(char *ligne0,char *ligne1);                                       // Afficheur LCD carte IHM SISI
// 3 void Affiche_Fleche(void);
// 4 int RegleHTR(unsigned char AddPCF8583, unsigned char HeureOuDate, unsigned char HeureOuJour,
// unsigned char MinutesOuMois, unsigned int SecondeOuAnnee);
// **************************************************************************************************************

#pragma used+
//---------------------------------------------------------------------------------------------------------------
unsigned char Lire_BP_I2C_Soft(void);
/* --------------------------------------------------------------------------------------------------------------
1) Gestion du clavier I2C de la carte SISI
//---------------------------------------------------------------------------------------------------------------
Rle : Lit l'tat des boutons-poussoirs de l'IHM relie  la carte ATMEL SISI(PCF8574) 
et renvoie un code sur 8 bits. 

Remarque : I2C mul.

Commentaires : Dans un premier temps, la fonction renvoie le code du bouton-poussoir 
actionn (PLUS_I2C = 0x01, FlecheH=0x02, FlecheB=0x04, MOINS_I2C = Ox08, SET_I2C = 0x10, 
OK_I2C = 0x20, ENTR_I2C=0x40, ECHAP_I2C = 0x80) puis elle renvoie 0xFF si la touche est 
maintenue ou 0x00 si la touche est relche.

Entre(s) : aucunes

Sortie(s) : code de la touche ou 0x00(relche) ou 0xFF(maintenue)
---------------------------------------------------------------------------------------------------------------*/   
// ==============================================================================================================
void Affiche_LCD(char *ligne0,char *ligne1);
/* --------------------------------------------------------------------------------------------------------------
2) Gestion de l'afficheur LCD
//---------------------------------------------------------------------------------------------------------------
Rle : Gre l'affichage d'un LCD quip d'un processeur Hitachi (command en mode 4 bits)

Commentaires : Envoie le contenu de deux tableaux de 16 caractres sur les lignes 0 et 1 d'un 
afficheur LCD 2*16 caractres.
Chaque tableau doit pouvoir contenir 17 valeurs (les 16 caractres  afficher + \0)

Librairie utilise : lcd.h

Entre(s) : ligne0, ligne1 = tableaux de 17 caractres

Sorties : Aucune
---------------------------------------------------------------------------------------------------------------*/
// ==============================================================================================================
void Affiche_Fleche(void);
/* --------------------------------------------------------------------------------------------------------------
3) Affichage de caractres personaliss sur le LCD Hitachi
//---------------------------------------------------------------------------------------------------------------
Rle : Dessine les caractres personnaliss (flches), situs en CGRAM, aux positions (15,0) et (15,1) 
de l'afficheur LCD.

Librairie utilise : lcd.h

Entre(s) : aucune

Sortie(s) : Aucune
---------------------------------------------------------------------------------------------------------------*/
//---------------------------------------------------------------------------------------------------------------
int RegleHTR(unsigned char AddPCF8583, unsigned char HeureOuDate, unsigned char HeureOuJour,
unsigned char MinutesOuMois, unsigned int SecondeOuAnnee);
//---------------------------------------------------------------------------------------------------------------
//4) Rglage de l'horloge temp rel PCF8583
//---------------------------------------------------------------------------------------------------------------
// Etats du graphe des transitions "REGLAGE"
//---------------------------------------------------------------------------------------------------------------
#ifndef Regle_Heure_ou_date
#define Regle_Heure_ou_date	    0
#endif
#ifndef Regle_min_mois
#define Regle_min_mois		    1
#endif
#ifndef Regle_seconde_annee
#define Regle_seconde_annee 	2
#endif
#ifndef Mise_a_jour_HTR
#define Mise_a_jour_HTR		    3
#endif
/* --------------------------------------------------------------------------------------------------------------
Rle : Rgle la date et l'heure d'une HTR PCF8583 situe  adresse (0 ou 1)

Commentaires :
La fonction rgle l'heure si Heure_ou_Date = 0 ou de la date si Heure_ou_Date = 1.
Les paramtres H_J, mn_mois, sec_annee servent de base aux rglages.
Celui-ci s'effectue avec les BP :
- PLUS_I2C pour augmenter une valeur,
- MOINS_I2C pour diminuer une valeur,
- OK_I2C  pour valider la valeur modifie et passer au rglage suivant
- ECHAP_I2C pour transfrer la valeur rgle et sortir de la fonction

Librairie utilise : PCF8583.h

Entres :
	adresse : adresse du boitier (0 ou 1 selon A0)
	Si Heure_ou_Date = 0 (rglage de l'heure) alors -1 < H_J < 24, -1 < mn_mois < 60
							-1 < sec_annee < 60
						  sinon -1 < H_J < 32, 0 < mn_mois < 13
							1999 < sec_annee < 2050
Sortie : la fonction renvoie 0
---------------------------------------------------------------------------------------------------------*/
// ********************************************************************************************************

#pragma used-

#pragma library SISI2.lib

#endif    // termine la directive ifndef
