/*=======================================================================
Nom du fichier:SISI2.c
Auteur: Philippe MARIANO

Rle: Source de la librairie sisi2.lib
Cr le 29/03/2011
Dernire rvision le 14/1/2012

Cross compilateur utilis: CodeVisionAVR V2.04.08
Composant cible : Atmel 8 bits (ATMega)

Cible Hardware  : Carte ATMEL SISI

Remarque: Une fois compil par -> file --> Convert library
le fichier sisi2.lib est automatiquement plac dans le rpertoire CVAVR\LIB
A mettre dans le rpertoire du projet
========================================================================*/

#include <pcf8583.h>
#include <stdio.h>
#include <delay.h>
#include <lcd.h>
#include "PCF8574.h"
#include "SISI2.h"

// ****************************************************************************************************************************
// ****************************************************************************************************************************
// Fonctions pour la carte SISI
// ****************************************************************************************************************************
// ****************************************************************************************************************************
// Rcapitulatif
//-----------------------------------------------------------------------------------------------------------------------------
// 1- Lire_BP_I2C_Soft // Lecture du clavier de la carte SISI via le bus I2C gr en mode software 
// 2- Affiche_LCD      // Affichage de deux lignes de 16 caractres sur un LCD  processeur HITACHI (mode 4 bits)
// 3- Affiche_Fleche   // Affichage des flches  droite de l'cran LCD
// 4- RegleHTR         // Rglage de l'heure et de la date sur le PCF8583
// *****************************************************************************************************************************
// =============================================================================================================================
// =============================================================================================================================
// Carte IHM
// =============================================================================================================================  
// 1- Lire_BP_I2C_Soft // Lecture du clavier de la carte SISI via le bus I2C gr en mode software
//-----------------------------------------------------------------------------------------------------------------------------
// Cration : Mars 2009
// Dernire rvision: Mars 2009
//------------------------------------------------------------------------------------------------------------------------------ 
/* Rle : Lit l'tat des boutons-poussoirs de l'IHM relie  la carte ATMEL SISI(PCF8574) 
et renvoie un code sur 8 bits. 

Remarque : I2C mul.

Commentaires : Dans un premier temps, la fonction renvoie le code du bouton-poussoir 
actionn (PLUS_I2C = 0x01, FlecheH=0x02, FlecheB=0x04, MOINS_I2C = Ox08, SET_I2C = 0x10, 
OK_I2C = 0x20, ENTR_I2C=0x40, ECHAP_I2C = 0x80) puis elle renvoie 0xFF si la touche est 
maintenue ou 0x00 si la touche est relche.

Entre(s) : aucunes

Sortie(s) : code de la touche ou 0x00(relche) ou 0xFF(maintenue)
------------------------------------------------------------------------------------------------------------------------------*/  
#if funcused Lire_BP_I2C_Soft
unsigned char Lire_BP_I2C_Soft(void)
{ 
  #define AUCUN    0x00
  
  static enum Etat_I2C {Attente_Relache_BP_I2C,Attente_Appui_BP_I2C} Etat_BP_I2C=Attente_Appui_BP_I2C;
  
  unsigned char Quel_BP_I2C, Quel_BP_I2C_1; 
  
  Quel_BP_I2C = Lire_Port_I2C_Soft(Add_BP_I2C); // Lecture du clavier
  
  switch (Etat_BP_I2C)
   {
    case Attente_Relache_BP_I2C :        // Etat d'attente : relchement de la touche
              if (Quel_BP_I2C == AUCUN)     // Si on dtecte le relchement de la touche
               {
                 Quel_BP_I2C_1 = Quel_BP_I2C;       
                 delay_ms(20);         // On attend 20ms (traitement des rebonds du contact)
                 
                 Quel_BP_I2C = Lire_Port_I2C_Soft(Add_BP_I2C); // Lecture du clavier
                 
                 if (Quel_BP_I2C_1 == Quel_BP_I2C)         // Si elle est bien relche
                  {
                   Etat_BP_I2C = Attente_Appui_BP_I2C;     // On passe dans l'tat : Attente d'un appui
                   return 0x00;                     // et on sort de la fonction en renvoyant 0 
                  }
                 else return 0xff; // sinon la touche est toujours actionne, 
               }           // On sort de la fonction en renvoyant 0
              else return 0xff; 
    break;
    
    case Attente_Appui_BP_I2C :     // Etat d'attente : appui sur la touche
              if (Quel_BP_I2C != AUCUN) // Si on dtecte qu'une touche est actionne
               {
                 Quel_BP_I2C_1 = Quel_BP_I2C; 
                 delay_ms(20);        // On attend 20ms (traitement des rebonds du contact)   
                 
                 Quel_BP_I2C = Lire_Port_I2C_Soft(Add_BP_I2C); // Lecture du clavier 
                    
                 if (Quel_BP_I2C_1 == Quel_BP_I2C)       // Si elle est bien appuye
                  {                       
                   Etat_BP_I2C = Attente_Relache_BP_I2C; // on passe dans l'tat Attente_relache
                   return Quel_BP_I2C;                 // et on renvoie son code
                  }
                 else return 0x00;                 // sinon la touche est relche,
               }                                // On sort de la fonction en renvoyant 255
              else return 0x00; 
    break;
   }
} 
#endif 
// =============================================================================================================================     
// 2- Affiche_LCD      // Affichage de deux lignes de 16 caractres sur un LCD  processeur HITACHI (mode 4 bits)
//------------------------------------------------------------------------------------------------------------------------------ 
// Cration : Mars 2003
// Dernire rvision: Mars 2003 
/* -----------------------------------------------------------------------------------------------------------------------------
Rle : Gre l'affichage d'un LCD quip d'un processeur Hitachi (command en mode 4 bits)

Commentaires : Envoie le contenu de deux tableaux de 16 caractres sur les lignes 0 et 1 d'un 
afficheur LCD 2*16 caractres.
Chaque tableau doit pouvoir contenir 17 valeurs (les 16 caractres  afficher + \0)

Librairie utilise : lcd.h

Entre(s) : ligne0, ligne1 = tableaux de 17 caractres

Sorties : Aucune
------------------------------------------------------------------------------------------------------------------------------*/
#if funcused Affiche_LCD
void Affiche_LCD(char *ligne1,char *ligne2)
{
		lcd_clear();
        lcd_puts(ligne1);
        lcd_gotoxy(0,1);
        lcd_puts(ligne2);
}
#endif
// =============================================================================================================================
// 3- Affiche_Fleche   // Affichage des flches  droite de l'cran LCD
//------------------------------------------------------------------------------------------------------------------------------
// Cration : Mars 2009
// Dernire rvision: Mars 2009
//------------------------------------------------------------------------------------------------------------------------------
#if funcused Affiche_Fleche
void Affiche_Fleche(void)
{
  lcd_gotoxy(15,0);	// Affichage flecheHaut
  lcd_putchar(Caractere_FlecheH);	
  lcd_gotoxy(15,1);	// Affichage flecheBas
  lcd_putchar(Caractere_FlecheB);
}
#endif
// =============================================================================================================================
//------------------------------------------------------------------------------------------------------------------------------
// 4- RegleHTR         // Rglage de l'heure et de la date sur le PCF8583
//------------------------------------------------------------------------------------------------------------------------------
// Cration : Mars 2003
// Dernire rvision :Janv 2012
//------------------------------------------------------------------------------------------------------------------------------
#if funcused RegleHTR
int RegleHTR(unsigned char AddPCF8583, unsigned char HeureOuDate, unsigned char HeureOuJour,
unsigned char MinutesOuMois, unsigned int SecondeOuAnnee)
{
#define RegleHeureOuDate            0
#define RegleMinMois                1
#define RegleSecondeAnnee           2
#define MiseAJourHTR                3
//------------------------------------------------------------------------------------------------------------------------------
// Type                     Nom                                    Description
//------------------------------------------------------------------------------------------------------------------------------
// Buffer pour l'afficheur LCD  processeur HITACHI
 char DisplayBufferLigne0[17];                                  // Buffer ligne 0 de l'afficheur
 char DisplayBufferLigne1[17];                                  // Buffer ligne 1 de l'afficheur
//------------------------------------------------------------------------------------------------------------------------------
 unsigned char BpSISI = 0;                                       // Bouton-poussoir activ sur la carte ATMEL SSI
 unsigned char HeureOuJour_1 = 0, MinutesOuMois_1 = 0;          // Assurent la stabilit de l'affichage sur le LCD
 unsigned int SecondeOuAnnee_1 = 0;
 unsigned char EtatGraphe = RegleHeureOuDate;                   // Permet de faire voluer le graphe des transitions
 unsigned char EtatGraphe_1 = RegleMinMois;
//------------------------------------------------------------------------------------------------------------------------------
// Boucle infinie
 while(1)
 {
  BpSISI = Lire_BP_I2C_Soft();

  switch(EtatGraphe){

    case RegleHeureOuDate :
                    if (HeureOuDate == 0)     // Rglage de l'heure
                        {
                            if ((HeureOuJour_1 != HeureOuJour) || (EtatGraphe_1 != EtatGraphe))
                            {
                                sprintf(DisplayBufferLigne0,"+/- Ok>mn Echa->");
                                sprintf(DisplayBufferLigne1,"h: %-uh/%-umn/%-us ",HeureOuJour, MinutesOuMois,SecondeOuAnnee);
                                 Affiche_LCD(DisplayBufferLigne0,DisplayBufferLigne1);
                                  HeureOuJour_1 = HeureOuJour;
                              }
                          }
                      else                       // Rglage de la date
                          {
                            if ((HeureOuJour_1 != HeureOuJour) || (EtatGraphe_1 != EtatGraphe))
                            {
                                sprintf(DisplayBufferLigne0,"+/- Ok>M Echap->");
                                sprintf(DisplayBufferLigne1,"J: %-u/%-u/%-i",HeureOuJour, MinutesOuMois,SecondeOuAnnee);
                                 Affiche_LCD(DisplayBufferLigne0,DisplayBufferLigne1);
                                  HeureOuJour_1 = HeureOuJour;
                              }
                          }

                      switch(BpSISI)
                          {
                              case PLUS_I2C   : HeureOuJour = HeureOuJour + 1;
                                         if (HeureOuDate == 0)
                                         {
                                           if (HeureOuJour == 24) HeureOuJour = 0;
                                         }
                                         else
                                         {
                                          if (HeureOuJour == 32) HeureOuJour = 1;
                                         }
                            break;

                              case MOINS_I2C   : HeureOuJour = HeureOuJour - 1;
                                        if (HeureOuDate == 0)
                                         {
                                          if ((signed char)HeureOuJour == -1) HeureOuJour = 23;
                                         }
                                         else
                                         {
                                          if (HeureOuJour == 0) HeureOuJour = 31;
                                         }
                            break;
                              case OK_I2C    : EtatGraphe = RegleMinMois; break;
                              case ECHAP_I2C : EtatGraphe = MiseAJourHTR; break;
                              default    : EtatGraphe = RegleHeureOuDate;
                          }

                       EtatGraphe_1 = RegleHeureOuDate;
    break;
//------------------------------------------------------------------------------------------------------------------------------
    case RegleMinMois    :
                    if (HeureOuDate == 0)    // Rglage des minutes
                        {
                            if ((MinutesOuMois_1 != MinutesOuMois) || (EtatGraphe_1 != EtatGraphe))
                            {
                                sprintf(DisplayBufferLigne0,"+/- Ok>s Echap->");
                                sprintf(DisplayBufferLigne1,"mn: %-uh/%-umn/%-us",HeureOuJour, MinutesOuMois, SecondeOuAnnee);
                                 Affiche_LCD(DisplayBufferLigne0,DisplayBufferLigne1);
                                  MinutesOuMois_1 = MinutesOuMois;
                              }
                           }

                      else
                           {                  // Rglage du mois
                            if ((MinutesOuMois_1 != MinutesOuMois) || (EtatGraphe_1 != EtatGraphe))
                            {
                                sprintf(DisplayBufferLigne0,"+/- Ok>A Echap->");
                                sprintf(DisplayBufferLigne1,"M: %-u/%-u/%-i",HeureOuJour, MinutesOuMois, SecondeOuAnnee);
                                 Affiche_LCD(DisplayBufferLigne0,DisplayBufferLigne1);
                                  MinutesOuMois_1 = MinutesOuMois;
                              }
                           }

                      switch(BpSISI)
                      {
                          case PLUS_I2C   : MinutesOuMois = MinutesOuMois + 1;
                                     if (HeureOuDate == 0)
                                         {
                                          if (MinutesOuMois == 60) MinutesOuMois = 0;
                                         }
                                         else
                                         {
                                           if (MinutesOuMois == 13) MinutesOuMois = 1;
                                         }
                        break;

                          case MOINS_I2C   : MinutesOuMois = MinutesOuMois - 1;
                                     if (HeureOuDate == 0)
                                         {
                                          if ((signed char)MinutesOuMois == -1) MinutesOuMois = 59;
                                         }
                                         else
                                         {
                                          if (MinutesOuMois == 0) MinutesOuMois = 12;
                                         }
                        break;
                          case OK_I2C    : EtatGraphe = RegleSecondeAnnee; break;
                          case ECHAP_I2C : EtatGraphe = MiseAJourHTR; break;
                          default    : EtatGraphe = RegleMinMois;
                      }

                      EtatGraphe_1 = RegleMinMois;

    break;
//------------------------------------------------------------------------------------------------------------------------------
    case RegleSecondeAnnee:
                    if (HeureOuDate == 0)     // Rglage des secondes
                     {
                      if ((SecondeOuAnnee_1 != SecondeOuAnnee) || (EtatGraphe_1 != EtatGraphe))
                        {
                            sprintf(DisplayBufferLigne0,"+/- Ok>h Echap->");
                            sprintf(DisplayBufferLigne1,"s: %-uh/%-umn/%-us ",HeureOuJour, MinutesOuMois,SecondeOuAnnee);
                             Affiche_LCD(DisplayBufferLigne0,DisplayBufferLigne1);
                              SecondeOuAnnee_1 = SecondeOuAnnee;
                          }
                       }

                      else
                      {                       // Rglage des annes
                        if ((SecondeOuAnnee_1 != SecondeOuAnnee) || (EtatGraphe_1 != EtatGraphe))
                        {
                            sprintf(DisplayBufferLigne0,"+/- Ok>J Echap->");
                            sprintf(DisplayBufferLigne1,"A: %-u/%-u/%-i",HeureOuJour, MinutesOuMois, SecondeOuAnnee);
                             Affiche_LCD(DisplayBufferLigne0,DisplayBufferLigne1);
                              SecondeOuAnnee_1 = SecondeOuAnnee;
                          }
                      }

                      switch(BpSISI)
                       {
                         case PLUS_I2C : SecondeOuAnnee = SecondeOuAnnee + 1;
                                    if (HeureOuDate == 0)
                                         {
                                          if (SecondeOuAnnee == 60) SecondeOuAnnee = 0;
                                         }
                                         else
                                         {
                                           if (SecondeOuAnnee == 2021) SecondeOuAnnee = 2010;
                                         }
                        break;

                          case MOINS_I2C : SecondeOuAnnee = SecondeOuAnnee - 1;
                                    if (HeureOuDate == 0)
                                         {
                                          if (SecondeOuAnnee == -1) SecondeOuAnnee = 59;
                                         }
                                         else
                                         {
                                           if (SecondeOuAnnee == 2009) SecondeOuAnnee = 2020;
                                         }
                        break;
                          case OK_I2C  : EtatGraphe = RegleHeureOuDate; break;
                          case ECHAP_I2C : EtatGraphe = MiseAJourHTR; break;
                          default  : EtatGraphe = RegleSecondeAnnee;
        	      	 }

                     EtatGraphe_1 = RegleSecondeAnnee;

  break;
//------------------------------------------------------------------------------------------------------------------------------
    case MiseAJourHTR  :  // Ecriture des rglages dans l'HTR PCF8583
                   if (HeureOuDate == 1)
  				            rtc_set_date(AddPCF8583,HeureOuJour,MinutesOuMois,SecondeOuAnnee);
  			        else
  			  	            rtc_set_time(AddPCF8583,HeureOuJour,MinutesOuMois,SecondeOuAnnee,0);
  			        return 0;
    break;
//------------------------------------------------------------------------------------------------------------------------------
     }//fin switch
//------------------------------------------------------------------------------------------------------------------------------
   } //fin while
//------------------------------------------------------------------------------------------------------------------------------
} // fin SP
#endif
//------------------------------------------------------------------------------------------------------------------------------
// =============================================================================================================================