/*-----------------------------------------------------------------------------
Nom du fichier:AVRTWIDRV.c
Auteur: Philippe MARIANO

Cr le 13/02/2010
Dernire rvision le 13/02/2010

Rle: Fonctions du drivers TWI (I2C)
Source : Note d'application AVR315, adaptes au cross compilateur CVAVR.

Cross compilateur utilis : CodeVisionAVR
Composant cible : ATMEL 8 bits

Remarque: Une fois compil par -> file --> Convert library
le fichier AVRTWIDRV.lib est automatiquement plac dans le rpertoire CVAVR\LIB 
-----------------------------------------------------------------------------*/

#include <AVRTWIDRV.h>  

// Declare your global variables here 
//-----------------------------------------------------------------------------------------------------------------------------
static unsigned char TWI_msgSize;             		// Number of bytes to be transmitted.       
static unsigned char TWI_buf[TWI_BUFFER_SIZE];    	// Transceiver buffer
static unsigned char TWI_state = TWI_NO_STATE;      // State byte. Default set to TWI_NO_STATE 
 
union TWI_STR                      					// Status byte holding flags.
{
    unsigned char all;
    unsigned char lastTransOK:1;      
    unsigned char unusedBits:7; 
} TWI_statusReg ={0};  
//-----------------------------------------------------------------------------------------------------------------------------


//-----------------------------------------------------------------------------------------------------------------------------
// Fonctions du drivers TWI
//-----------------------------------------------------------------------------------------------------------------------------
#if funcused TWI_Master_Initialise
void TWI_Master_Initialise(void)
{                                               // Adapte pour CVAVR
  TWBR = TWI_TWBR;                              // Set bit rate register (Baudrate). Defined in header file.
// TWSR = TWI_TWPS;                             // Not used. Driver presumes prescaler to be 00.
  TWDR = 0xFF;                                  // Default content = SDA released.
  												// TWCR = TWINT TWEA TWSTA TWSTO TWWC TWEN - TWIE
  TWCR = 0b00000100;                            // (1<<TWEN)| Enable TWI-interface and release TWI pins.
                               					// (0<<TWIE)|(0<<TWINT)|Disable Interupt.
                               					// (0<<TWEA)|(0<<TWSTA)|(0<<TWSTO)| No Signal requests.
                                         		// 0<<TWWC); 
}  
#endif
//-----------------------------------------------------------------------------------------------------------------------------
#if funcused TWI_Transceiver_Busy
unsigned char TWI_Transceiver_Busy(void)
{                                               // Adapte pour CVAVR
  return ( TWCR & 0b00000001);                  // ( TWCR & (1<<TWIE) ) IF TWI Interrupt is enabled then the Transceiver is busy
}
#endif
//-----------------------------------------------------------------------------------------------------------------------------

#if funcused TWI_Start_Transc_With_Data
void TWI_Start_Transc_With_Data( unsigned char *msg, unsigned char msgSize )
{
  unsigned char temp;
                                                // Adapte pour CVAVR
  while ( TWI_Transceiver_Busy() );             // Wait until TWI is ready for next transmission.

  TWI_msgSize = msgSize;                        // Number of data to transmit.
  TWI_buf[0]  = msg[0];                         // Store slave address with R/W setting.
  if (!( msg[0] & 0b00000001 ))       			// (!( msg[0] & (TRUE<<TWI_READ_BIT) ))
  {												// If it is a write operation, then also copy data.
    for ( temp = 1; temp < msgSize; temp++ )
      TWI_buf[ temp ] = msg[ temp ];
  }
  TWI_statusReg.all = 0;                        // !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  TWI_state         = TWI_NO_STATE ;            //  TWCR = TWINT TWEA TWSTA TWSTO TWWC TWEN - TWIE
  TWCR =  0b10100101;                           // (1<<TWEN)| TWI Interface enabled.
                           						// (1<<TWIE)|(1<<TWINT)|Enable TWI Interupt and clear the flag.
                								// (0<<TWEA)|(1<<TWSTA)|(0<<TWSTO)|Initiate a START condition!!!!!.
                                      			// (0<<TWWC);
} 
#endif

//-----------------------------------------------------------------------------------------------------------------------------
#if funcused TWI_Get_Data_From_Transceiver
unsigned char TWI_Get_Data_From_Transceiver( unsigned char *msg, unsigned char msgSize )
{
  unsigned char i;
          
  while ( TWI_Transceiver_Busy() );             // Wait until TWI is ready for next transmission.

  if( TWI_statusReg.lastTransOK )               // Last transmission competed successfully.              
  {                                             
    for ( i=0; i<msgSize; i++ )                 // Copy data from Transceiver buffer.
    {
      msg[ i ] = TWI_buf[ i ];
    }
  }
  return( TWI_statusReg.lastTransOK );                                   
} 
#endif 
//-----------------------------------------------------------------------------------------------------------------------------

// ----------------------------------------------------------------------------------------------------------------------------
// Interruption TWI
// ----------------------------------------------------------------------------------------------------------------------------
#if funcused twi_isr
interrupt [TWI] void twi_isr(void)      		// Adapte pour CVAVR
{												// #pragma vector=TWI_vect
												// __interrupt void TWI_ISR(void)
  static unsigned char TWI_bufPtr;
  
  switch (TWSR)
  {
    case TWI_START:             				// START has been transmitted  
    
    case TWI_REP_START:         				// Repeated START has been transmitted
      TWI_bufPtr = 0;   						// Set buffer pointer to the TWI Address location
      				
    case TWI_MTX_ADR_ACK:       				// SLA+W has been tramsmitted and ACK received 
    
    case TWI_MTX_DATA_ACK:      				// Data byte has been tramsmitted and ACK received
      if (TWI_bufPtr < TWI_msgSize)
      {
        TWDR = TWI_buf[TWI_bufPtr++];           // TWCR = TWINT TWEA TWSTA TWSTO TWWC TWEN - TWIE
        TWCR = 0b10000101;                      // (1<<TWEN)| TWI Interface enabled
        										// (1<<TWIE)|(1<<TWINT)|Enable TWI Interupt and clear the flag to send byte
                         				  		// (0<<TWEA)|(0<<TWSTA)|(0<<TWSTO)| 
               						  			// (0<<TWWC); 
      }
      else                    					// Send STOP after last byte
      {
        TWI_statusReg.lastTransOK = TRUE;       // Set status bits to completed successfully.
         						  				// TWCR = TWINT TWEA TWSTA TWSTO TWWC TWEN - TWIE 
        TWCR = 0b10010100; 		                // (1<<TWEN)| TWI Interface enabled
        										// (0<<TWIE)|(1<<TWINT)| Disable TWI Interrupt and clear the flag
                         				  		// (0<<TWEA)|(0<<TWSTA)|(1<<TWSTO)| Initiate a STOP condition.
                               				  	// (0<<TWWC);
      }
    break;
      
    case TWI_MRX_DATA_ACK:      				// Data byte has been received and ACK tramsmitted
      TWI_buf[TWI_bufPtr++] = TWDR; 
      
    case TWI_MRX_ADR_ACK:       				// SLA+R has been tramsmitted and ACK received
      if (TWI_bufPtr < (TWI_msgSize-1) )        // Detect the last byte to NACK it.
      {                                         // TWCR = TWINT TWEA TWSTA TWSTO TWWC TWEN - TWIE
        TWCR = 0b11000101;                      // (1<<TWEN)| TWI Interface enabled
        										// (1<<TWIE)|(1<<TWINT)| Enable TWI Interupt and clear the flag to read next byte
                          				  		// (1<<TWEA)|(0<<TWSTA)|(0<<TWSTO)|Send ACK after reception
                                  				// (0<<TWWC);  
      } else                    				// Send NACK after next reception
      {						          			// TWCR = TWINT TWEA TWSTA TWSTO TWWC TWEN - TWIE
        TWCR = 0b10000101;                      // (1<<TWEN)| TWI Interface enabled
        										// (1<<TWIE)|(1<<TWINT)| Enable TWI Interupt and clear the flag to read next byte
                          				  		// (0<<TWEA)|(0<<TWSTA)|(0<<TWSTO)| Send NACK after reception
                                			  	// (0<<TWWC); 
      }    
    break; 
      
    case TWI_MRX_DATA_NACK:     				// Data byte has been received and NACK tramsmitted
      TWI_buf[TWI_bufPtr] = TWDR;
      TWI_statusReg.lastTransOK = TRUE;         // Set status bits to completed successfully. 
      											// TWCR = TWINT TWEA TWSTA TWSTO TWWC TWEN - TWIE
      TWCR = 0b10010100;                        // (1<<TWEN)| TWI Interface enabled
                                  				// (0<<TWIE)|(1<<TWINT)| Disable TWI Interrupt and clear the flag
                       							// (0<<TWEA)|(0<<TWSTA)|(1<<TWSTO)| Initiate a STOP condition.
                              					// (0<<TWWC); 
    break;  
          
    case TWI_ARB_LOST:          				// Arbitration lost                             
    											// TWCR = TWINT TWEA TWSTA TWSTO TWWC TWEN - TWIE
      TWCR = 0b10100101;                        // (1<<TWEN)| TWI Interface enabled
                                   				// (1<<TWIE)|(1<<TWINT)| Enable TWI Interupt and clear the flag
                        						// (0<<TWEA)|(1<<TWSTA)|(0<<TWSTO)| Initiate a (RE)START condition.
                              					// (0<<TWWC);
    break;
      
    case TWI_MTX_ADR_NACK:      				// SLA+W has been tramsmitted and NACK received
    case TWI_MRX_ADR_NACK:      				// SLA+R has been tramsmitted and NACK received    
    case TWI_MTX_DATA_NACK:     				// Data byte has been tramsmitted and NACK received
//    case TWI_NO_STATE              			// No relevant state information available; TWINT = 0
    case TWI_BUS_ERROR:         				// Bus error due to an illegal START or STOP condition  
    
    default:     
      TWI_state = TWSR;                         // Store TWSR and automatically sets clears noErrors bit.
      											// Reset TWI Interface
                 								// TWCR = TWINT TWEA TWSTA TWSTO TWWC TWEN - TWIE
      TWCR = 0b00000100;                        // (1<<TWEN)| Enable TWI-interface and release TWI pins
                                   				// (0<<TWIE)|(0<<TWINT)| Disable Interupt
                       							// (0<<TWEA)|(0<<TWSTA)|(0<<TWSTO)| No Signal requests
                              					// (0<<TWWC);
  }
} 
#endif
