/*****************************************************************************************
******************************************************************************************
Nom du fichier: ISI.h
------------------------------------------------------------------------------------------
Auteur: Philippe MARIANO
------------------------------------------------------------------------------------------
Cre le : 27/6/2006
Dernire rvision le : 08/03/2009
------------------------------------------------------------------------------------------
Cross compilateur utilis: CodeVisionAVR
------------------------------------------------------------------------------------------
Composants cibles : ATMEL 8 bits  (ATMEGA8535)
------------------------------------------------------------------------------------------
REMARQUES:
Ce fichier est destin  un projet CVAVR utilisant la carte ISI.
Il doit tre plac dans le sous rpertoire CVAVR\\INC\ 
Placer le fichier isi.lib dans le rpertoire \CVAVR\LIB\ 
*****************************************************************************************
*****************************************************************************************/

#ifndef _ISI_INCLUDED_ // Evite que le fichier ne soit inclus plusieurs fois
#define _ISI_INCLUDED_


// ******************************************************************************************
// Dfinition du code des entres de la carte ISI
// ******************************************************************************************
#ifndef E0 
#define E0		0x0001   	// PD0  
#endif 
#ifndef E1 
#define E1		0x0002      	// PD1
#endif	
#ifndef E2 
#define E2		0x0004		// PA0	
#endif
#ifndef E3 
#define E3		0x0008      	// PA1
#endif
#ifndef E4 
#define E4		0x0010 	        // PA2
#endif
#ifndef E5 
#define E5		0x0020     	// PA3
#endif 
#ifndef E6 
#define E6		0x0040      	// PA4
#endif 
#ifndef E7 
#define E7		0x0080      	// PA5
#endif 
#ifndef E8 
#define E8		0x0100      	// PA6
#endif 
#ifndef E9 
#define E9		0x0200      	// PA7
#endif 
#ifndef Aucune 
#define Aucune		0x03ff      	// Pas de signal
#endif  
// ******************************************************************************************

// ******************************************************************************************
// ******************************************************************************************
// Codes de commande de l'afficheur LCD 2x16  processeur Hitachi type HD44780
// ******************************************************************************************
// ******************************************************************************************
// Utilisation: A envoyer dans le registre de contrle de l'afficheur
// avec une instruction _lcd_write_data(unsigned char data) de la librairie lcd.h
// ******************************************************************************************
// -----------------------------------------------------------------------------------------
// Initialisation du dplacement du curseur
// -----------------------------------------------------------------------------------------
#ifndef EntryMode0
#define EntryMode0      0b00000100         // Par dfaut dplacement du curseur vers la gauche
#endif 
#ifndef EntryMode1
#define EntryMode1      0b00000101         // Par dfaut dplacement de l'affichage vers la gauche
#endif 
#ifndef EntryMode2
#define EntryMode2      0b00000110         // Par dfaut dplacement du curseur vers la droite 
#endif 
#ifndef EntryMode3
#define EntryMode3      0b00000111         // Par dfaut dplacement de l'affichage vers la droite
#endif 
#ifndef clear
#define clear           0b00000001         // Efface l'cran et la DDRAM
#endif 
#ifndef home
#define home            0b00000010         // Ramne le curseur au dbut de la premire ligne
#endif
// -----------------------------------------------------------------------------------------
// Affichage             code       On/Off   curseur      clignotement 
// -----------------------------------------------------------------------------------------
#ifndef displayOff0
#define displayOff0     0b00001000  //  Off      invisible     non 
#endif 
#ifndef displayOff1
#define displayOff1     0b00001001  //  Off      invisible     oui
#endif 
#ifndef displayOff2
#define displayOff2     0b00001010  //  Off      visible       non
#endif 
#ifndef displayOff3
#define displayOff3     0b00001011  //  Off      visible       oui
#endif 
#ifndef displayOn0
#define displayOn0      0b00001100  //  On       invisible     non
#endif 
#ifndef displayOn1
#define displayOn1      0b00001101  //  On       invisible     oui
#endif 
#ifndef displayOn2
#define displayOn2      0b00001110  //  On       visible       non
#endif 
#ifndef displayOn3
#define displayOn3      0b00001111  //  On       visible       oui    
#endif  
// -----------------------------------------------------------------------------------------
// Dplacement du curseur ou de l'affichage
// -----------------------------------------------------------------------------------------
#ifndef curseurG
#define curseurG        0b00010000 // Dplacement du curseur vers la gauche 
#endif
#ifndef curseurD
#define curseurD        0b00010100 // Dplacement du curseur vers la droite
#endif
#ifndef fenetreG
#define fenetreG        0b00011000 // Dplacement de l'affichage vers la gauche
#endif
#ifndef fenetreD
#define fenetreD        0b00011100 // Dplacement de l'affichage vers la droite
#endif 
// -----------------------------------------------------------------------------------------
// -----------------------------------------------------------------------------------------
// Construction d'un caractre personalis. Codes  envoyer dans la CGRAM 
// aux adresses $40, $48, $50, $58, $60, $68, $70, $78 avec une instruction
// lcd_write_byte(unsigned char adresse, unsigned char data)
// -----------------------------------------------------------------------------------------
// Exemple de dclaration d'une matrice 5x7, le 8e caractre correspond au curseur
// const unsigned char flecheHaut[8] = {0x04, 0x0E, 0x15, 0x04, 0x04, 0x04, 0x04, 0x00};
// 00100
// 01110
// 10101
// 00100
// 00100
// 00100
// 00100
// 00000
// ******************************************************************************************
 

// ******************************************************************************************
// ******************************************************************************************
// Prototype des fonctions gnrales de la carte ATMEL ISI 
// ******************************************************************************************
// 1 - unsigned int Lire_Entrees(void);
// 2 - void Affiche_LCD(char *ligne1,char *ligne2);
// ******************************************************************************************

#pragma used+

unsigned int Lire_Entrees(void);
/*-----------------------------------------------------------------------------------------
Rle : Lit l'tat des Entres de la carte ATMEL ISI(PortA,PD0,PD1) 

Commentaires : La fonction renvoie le code de l'ente sur laquelle se trouve un signal TOR
lors du premier appel (E0 = 0x0001, E1 = Ox0002, E2 = 0x0004, E3 = 0x0008, E4 = 0x0010, E5=0x0020,
E6 = 0x0040, E7 = 0x0080, E8 = 0x0100, E9 = 0x0200) puis 0x00 si le signal est maintenu ou 0xFFFF 
si le signal est supprim. 

Librairie utilis : delay.h

Entres : aucunes 

Sorties : code de l'entre ou 0x00 ou 0xFF
-----------------------------------------------------------------------------------------*/


void Affiche_LCD(char *ligne1,char *ligne2);
/*-----------------------------------------------------------------------------------------
Rle : Gre l'affichage d'un LCD quip d'un contrleur Hitachi
       et command en mode 4 bits

Commentaires : Envoie le contenu de deux tableaux de 16 caractres sur les ligne 1 et
2 d'un afficheur LCD 2*16 caractres.
Chaque tableau doit pouvoir contenir les 16 caractres  afficher + \0

Librairie utilis : lcd.h  

Entres : ligne1, ligne2 = tableaux de 17 caractres

Sorties : Aucune
-----------------------------------------------------------------------------------------*/    

#pragma used-

#pragma library isi.lib

#endif    // termine la directive ifndef
