/*-----------------------------------------------------------------------
Nom du fichier: SISI2SVL.h
Auteur: Philippe MARIANO

Projet: Robot suiveur de ligne
Rle: fichier d'en-tte de la bibliothque "SISI2SVL.lib"
Cr le: 21/01/2010
Dernire rvision le:  22/02/2011

Cross compilateur utilis: CodeVisionAVR V2
Composant cible : ATMEL 8 bits sur carte "Robot SISI"

Remarque: Ce fichier est destin  un projet CVAVR utilisant la carte SSI
Il doit tre plac dans le rpertoire du projet 
------------------------------------------------------------------------*/

//---------------------------------------------------------------------------------------------------------------
#ifndef _SISI2SVL_INCLUDED_ 	
#define _SISI2SVL_INCLUDED_ 
   
// **************************************************************************************************************
// **************************************************************************************************************
// 										        DEFINITIONS
// ==============================================================================================================
// Definitions pour l'interface IHM de la carte ATMEL SISI (BP et Leds sur le bus I2C)   
// ==============================================================================================================
// Code des BPs 
//---------------------------------------------------------------------------------------------------------------
#ifndef ECHAP_I2C
#define ECHAP_I2C   	128  
#endif 
#ifndef ENTR_I2C
#define ENTR_I2C 		64 
#endif
#ifndef OK_I2C
#define OK_I2C			32  
#endif 
#ifndef SET_I2C
#define SET_I2C			16 
#endif
#ifndef MOINS_I2C
#define MOINS_I2C     	8 
#endif
#ifndef FlecheB_I2C
#define FlecheB_I2C 	4 
#endif  
#ifndef FlecheH_I2C
#define FlecheH_I2C 	2 
#endif 
#ifndef PLUS_I2C
#define PLUS_I2C     	1
#endif  
//---------------------------------------------------------------------------------------------------------------
// Adresses des Ports E/S I2C PCF8574 relis au BP et aux LED
//---------------------------------------------------------------------------------------------------------------
#ifndef Add_LED_I2C
#define Add_LED_I2C   	0x40    // SLA+W
#endif  

#ifndef Add_BP_I2C
#define Add_BP_I2C   	0x42  	// SLA+W
#endif
// ============================================================================================================== 
// Dfinitions pour le robot suiveur de ligne
// ==============================================================================================================
// Signaux de commande des capteurs IR (capteur  5 cellules)
//--------------------------------------------------------------------------------------------------------------- 
// PA7 | PA6 | PA5 | PA4  | PA3 | PA2 | PA1 | PA0
// Res | Res | Res | IRG  |IRCG | IRC |IRCD | IRD  connecteur vers l'avant
// Res | Res |  Res| IRD  |IRCD | IRC |IRCG | IRG  connecteur vers l'arrire 
// Res: utilis par capteur 8 cellules
//---------------------------------------------------------------------------------------------------------------
#ifndef CAPTEUR_IR
#define CAPTEUR_IR 	PORTA  
#endif   
//---------------------------------------------------------------------------------------------------------------
// Commande des moteurs 
//---------------------------------------------------------------------------------------------------------------  
#ifndef CDE_MOTD
#define CDE_MOTD	OCR1AL       	        // Commande du moteur Droit
#endif
#ifndef CDE_MOTG
#define CDE_MOTG	OCR1BL	    	        // Commande du moteur Gauche     
#endif
//---------------------------------------------------------------------------------------------------------------
// Commande des Servos
//---------------------------------------------------------------------------------------------------------------
#ifndef CDE_SERVO1
#define CDE_SERVO1	PORTD.6                 // Ecriture cde Servo1
#endif
#ifndef CDE_SERVO2                          // Ecriture cde Servo2
#define CDE_SERVO2	PORTD.7
#endif 
#ifndef Aff_Valeur_Cde_SERVO1
#define Aff_Valeur_Cde_SERVO1 	PIND.6      // Lecture cde Servo1
#endif    
#ifndef Aff_Valeur_Cde_SERVO2
#define Aff_Valeur_Cde_SERVO2 	PIND.7	    // Lecture cde Servo2 
#endif 
//---------------------------------------------------------------------------------------------------------------
// Adresses de la CGRAM de l'afficheur LCD  processeur Hitachi
//--------------------------------------------------------------------------------------------------------------- 
//@x : adresse dans la CGRAM  
#ifndef Add_FlecheH_CGRAM
#define Add_FlecheH_CGRAM           0x40              // @1 Caractre flche haut
#endif
#ifndef Add_FlecheB_CGRAM
#define Add_FlecheB_CGRAM           0x48              // @2 Caractre flche bas
#endif
//---------------------------------------------------------------------------------------------------------------
// Caractres spcifiques  afficher sur le LCD  
//--------------------------------------------------------------------------------------------------------------- 
#ifndef Caractere_FlecheH
#define Caractere_FlecheH	        0 
#endif
#ifndef Caractere_FlecheB
#define Caractere_FlecheB	        1
#endif
//---------------------------------------------------------------------------------------------------------------
// Mots de commande des Leds sur la carte SISI (visualisent la position du robot par rapport  la ligne)  
// --------------------------------------------------------------------------------------------------------------
#ifndef
#define VISUALISE_HORS_LIGNE 	    0b11111111
#endif
#ifndef
#define VISUALISE_GAUCHE_3PLUS	    0b11111110
#endif
#ifndef
#define VISUALISE_GAUCHE_2PLUS	    0b11111100
#endif
#ifndef
#define VISUALISE_CENTRE_1		    0b11111111
#endif
#ifndef
#define VISUALISE_GAUCHE_PLUS       0b11111000
#endif
#ifndef
#define VISUALISE_CENTRE_3          0b11111111
#endif
#ifndef
#define VISUALISE_GAUCHE            0b11110000
#endif
#ifndef
#define VISUALISE_DROITE_3PLUS	    0b11101111
#endif
#ifndef
#define VISUALISE_DROITE_2PLUS	    0b11100111
#endif
#ifndef
#define VISUALISE_DROITE_PLUS       0b11100011
#endif
#ifndef
#define VISUALISE_DROITE			0b11100001
#endif
#ifndef
#define VISUALISE_CENTRE_5		    0b11100000
#endif
//------------------------------------------------------------------------------------------------------------
// Position du connecteur du "Capteur ligne"
//------------------------------------------------------------------------------------------------------------
#ifndef AVANT
#define AVANT                       0
#endif

#ifndef ARRIERE
#define ARRIERE                     1
#endif
//------------------------------------------------------------------------------------------------------------
// Valeurs renvoyes par le capteur "ligne"
// Les valeurs ci-dessous sont renvoyes, si la mesure est correcte, par un capteur  5 cellules
enum ValeurPossiblesPourCapteurLigne{POS_HORS_LIGNE, AR_DROITE_OU_AV_GAUCHE_3PLUS, AR_DROITE_OU_AV_GAUCHE_2PLUS = 3, 
POS_CENTRE_1, AR_DROITE_OU_AV_GAUCHE_PLUS=7, POS_CENTRE_3=14, AR_DROITE_OU_AV_GAUCHE, AR_GAUCHE_OU_AV_DROITE_3PLUS,
AR_GAUCHE_OU_AV_DROITE_2PLUS=24, AR_GAUCHE_OU_AV_DROITE_PLUS=28, AR_GAUCHE_OU_AV_DROITE = 30, POS_CENTRE_5};
//------------------------------------------------------------------------------------------------------------
// Diffrents tats possibles pour la commandes des moteurs (capteur ligne  5 cellules)                                            
//------------------------------------------------------------------------------------------------------------
enum EtatCommandeMoteurProf {COMDE_DEPART, COMDE_CENTRE, COMDE_CENTRE2, COMDE_CENTRE3, COMDE_DROITE, 
COMDE_DROITE_PLUS, COMDE_DROITE_2PLUS, COMDE_DROITE_3PLUS, COMDE_GAUCHE, COMDE_GAUCHE_PLUS, COMDE_GAUCHE_2PLUS, 
COMDE_GAUCHE_3PLUS, COMDE_GAUCHE_4PLUS, COMDE_DROITE_4PLUS, COMDE_COUPURE };
//------------------------------------------------------------------------------------------------------------
// Boolens
//------------------------------------------------------------------------------------------------------------
#pragma warn-
#define ACO     ACSR.5      // Redfinition de la sortie du comparateur analogique
#pragma warn+
//------------------------------------------------------------------------------------------------------------
// ==============================================================================================================
// Dclarations externes
// --------------------------------------------------------------------------------------------------------------
extern bit Cible;
//extern unsigned char Position_Robot, Position_Robot_1; 
extern unsigned char PWM[11][2];
// ==============================================================================================================


// **************************************************************************************************************
// **************************************************************************************************************
// Prototypes des fonctions dveloppes pour la carte SISI (monte sur un robot suiveur de ligne)
// **************************************************************************************************************
// ----------------------------------------------- Rcapitulatif ------------------------------------------------
//              Prototype                                                        Destin  :
// --------------------------------------------------------------------------------------------------------------
// 1 unsigned char Lire_BP_I2C_Soft(void);                                      // Clavier carte IHM SISI
// 2 Affiche_LCD(char *ligne0,char *ligne1);                                    // Afficheur LCD carte IHM SISI
// 3 void Affiche_Fleche(void);
// 4 void Arret_Moteurs(void);                                                  // Robot (Gnrals)
// 5 void Active_Moteurs(void);
// 6 unsigned char CalculerValeurCapteurLigne(void);                            // FS11
// 7 unsigned char AdapterValeurCapteurLigneSiConnecteurAV(unsigned char ValeurCapteurLigneSVL);
// 8 unsigned char AfficherPositionRobotSVL(unsigned char PositionRobot);       // FS13
// 9 void CorrigerTrajectoireRobotSVL(unsigned char PositionRobot);             //FS12
// ==============================================================================================================

#pragma used+
//---------------------------------------------------------------------------------------------------------------
unsigned char Lire_BP_I2C_Soft(void);
/* --------------------------------------------------------------------------------------------------------------
1) Gestion du clavier I2C de la carte SISI
//---------------------------------------------------------------------------------------------------------------
Rle : Lit l'tat des boutons-poussoirs de l'IHM relie  la carte ATMEL SISI(PCF8574) 
et renvoie un code sur 8 bits. 

Remarque : I2C mul.

Commentaires : Dans un premier temps, la fonction renvoie le code du bouton-poussoir 
actionn (PLUS_I2C = 0x01, FlecheH=0x02, FlecheB=0x04, MOINS_I2C = Ox08, SET_I2C = 0x10, 
OK_I2C = 0x20, ENTR_I2C=0x40, ECHAP_I2C = 0x80) puis elle renvoie 0xFF si la touche est 
maintenue ou 0x00 si la touche est relche.

Entre(s) : aucunes

Sortie(s) : code de la touche ou 0x00(relche) ou 0xFF(maintenue)
---------------------------------------------------------------------------------------------------------------*/   
// ==============================================================================================================
void Affiche_LCD(char *ligne0,char *ligne1);
/* --------------------------------------------------------------------------------------------------------------
2) Gestion de l'afficheur LCD
//---------------------------------------------------------------------------------------------------------------
Rle : Gre l'affichage d'un LCD quip d'un processeur Hitachi (command en mode 4 bits)

Commentaires : Envoie le contenu de deux tableaux de 16 caractres sur les lignes 0 et 1 d'un 
afficheur LCD 2*16 caractres.
Chaque tableau doit pouvoir contenir 17 valeurs (les 16 caractres  afficher + \0)

Librairie utilise : lcd.h

Entre(s) : ligne0, ligne1 = tableaux de 17 caractres

Sorties : Aucune
---------------------------------------------------------------------------------------------------------------*/
// ==============================================================================================================
void Affiche_Fleche(void);
/* --------------------------------------------------------------------------------------------------------------
3) Affichage de caractres personaliss sur le LCD Hitachi
//---------------------------------------------------------------------------------------------------------------
Rle : Dessine les caractres personnaliss (flches), situs en CGRAM, aux positions (15,0) et (15,1) 
de l'afficheur LCD.

Librairie utilise : lcd.h

Entre(s) : aucune

Sortie(s) : Aucune
---------------------------------------------------------------------------------------------------------------*/
// ==============================================================================================================
 void Arret_Moteurs(void);
// 4) 
// ==============================================================================================================
void Active_Moteurs(void);
// 5)
// ============================================================================================================== 
unsigned char CalculerValeurCapteurLigne(void); 
//---------------------------------------------------------------------------------------------------------------
// 6) FS11: " Calculer la position du capteur par rapport  la ligne " 
/*---------------------------------------------------------------------------------------------------------------	        
Rle: Grer le multiplexage des leds IR (metteur IR) et calculer la valeur numrique reprsentative de la 
position du capteur par rapport  la ligne.

Entre(s) : 	ACO		            bit     Sortie du comparateur analogique (interne au C). 
(Interne)                                   Reprsentatif de la position d'une cellule IR par rapport  la ligne.

Sortie(s) :     Cde_Del_IR 		    octet   Permet de multiplexer la commande des LED IR.
										    Comme Cde_Del_IR est transfre dans le port A, on donne ci-dessous 
          								    le dtail des bits de commande des LED IR.
                                                
					   					    Emetteur IR connect  au bit      Remarque 
										    ----------------------------------------------------         
										    E_D_IR		    "      PA0    |   Emetteur IR droit
										    E_CD_IR         "      PA1    |   Emetteur IR centre droit
										    E_C_IR		    "      PA2    |	  Emetteur IR centre
										    E_CG_IR         "	   PA3	  |   Emetteur IR centre Gauche
										    E_G_IR 		    "      PA4    |	  Emetteur IR gauche 
					                                                
			    ValeurCapteurLigne	octet 	Image de la position du "Capteur ligne" par rapport  la ligne.
---------------------------------------------------------------------------------------------------------------*/
unsigned char AdapterValeurCapteurLigneSiConnecteurAV(unsigned char ValeurCapteurLigneSVL);
//---------------------------------------------------------------------------------------------------------------
// 7) FS11 suite Calcul de la position du capteur par rapport  la ligne 
/*---------------------------------------------------------------------------------------------------------------	        
Rle: Calcul la valeur reprsentative de la position du robot par rapport  la ligne lorsque le capteur est
      positionn avec son connecteur  l'avant.

Entre(s) :  ValeurCapteurLigneSVL      octet   Position du capteur par rapport  la ligne renvoye par FS11

Sortie(s) : ValeurCapteurLigneSVLCorr   octet   Position du capteur par rapport   la ligne, corrige pour
                                                tre exploitable par FS13 et FS12 lorsque le "Capteur ligne" est
                                                positionn avec son connecteur  l'avant.	
---------------------------------------------------------------------------------------------------------------*/  
//--------------------------------------------------------------------------------------------------------------- 
// ==============================================================================================================
unsigned char AfficherPositionRobotSVL(unsigned char ValeurCapteurLigneModif);
/*---------------------------------------------------------------------------------------------------------------
// 8) FS13 "Choisir la valeur  afficher sur les LEDs"				   		
//--------------------------------------------------------------------------------------------------------------- 
Rle: Choisir la valeur numrique ncessaire  la commande des leds rouge pour que leur clairage soit 
reprsentatif de la position du robot par rapport  la ligne.

Entres 
ValeurCapteurLigneModif :   octet 	Valeur renvoye par le capteur en fonction de sa position par rapport  
                                    la ligne.

Sortie
VisuPosition:               octet  	Reprsentatif des LED  clairer. Le bit 0 de VisuPosition commande la 
                                    Led D0 de l'interface IHM etc.
---------------------------------------------------------------------------------------------------------------*/
// ==============================================================================================================
void CorrigerTrajectoireRobotSVL(unsigned char PositionRobot);
/*--------------------------------------------------------------------------------------------------------------- 
// 9) FS12: " Choisir les valeurs des rapports cycliques "					
//---------------------------------------------------------------------------------------------------------------     
Rle: Choisir la valeur du rapport cyclique du signal de commande des moteurs du robot en fonction de
sa position par rapport  la ligne.

Entre(s):          Position_Robot           octet      (voir ci-dessus)    

Sortie(s):          CDE_MOTD                 octet		Correspond au registre (OCR1A). Rgle le rapport cyclique 
													    du signal de commande du moteur droit.
				    CDE_MOTG                 octet      Correspond au registre (OCR1B). Rgle le rapport cyclique
				 							 		    du signal de commande du moteur gauche.
---------------------------------------------------------------------------------------------------------------*/
// **************************************************************************************************************

#pragma used-

#pragma library SISI2SVL.lib

#endif    // termine la directive ifndef
// **************************************************************************************************************
// **************************************************************************************************************