/*=======================================================================
Nom du fichier: SISI2SVL.c
Auteur: Philippe MARIANO
// ----------------------------------------------------------------------
Rle: Source de la librairie SISI2SVL.lib  (PPE Robot Suiveur de Ligne)
// ----------------------------------------------------------------------
Cr le 23/01/2010
Dernire rvision le 22/02/2011
// ----------------------------------------------------------------------
Cross compilateur utilis: CodeVisionAVR V2.04.08a
Composant cible : Atmel 8 bits (Carte SISI I2C Soft)

Remarque: Une fois compil par -> file --> Convert library
le fichier SISI2SVL.lib est automatiquement plac dans le rpertoire 
CVAVR2\LIB.
-------------------------------------------------------------------------
A RECOPIER DANS LE REPERTOIRE DU PROJET
========================================================================*/


// ***************************************************************************************************************
// ***************************************************************************************************************
// Bibliothques   
// *************************************************************************************************************** 
// CVAVR
//----------------------------------------------------------------------------------------------------------------
#include <mega32.h>
#include <delay.h>
#include <lcd.h>
#include <stdio.h>      
#include <pcf8583.h>
//----------------------------------------------------------------------------------------------------------------
// Bibliothques dveloppes pour la carte SISI
//----------------------------------------------------------------------------------------------------------------
#include "SISI2SVL.h"
#include "PCF8574.h"
// ***************************************************************************************************************
// ***************************************************************************************************************
// Fonctions
// ***************************************************************************************************************
// ***************************************************************************************************************
// Fonctions pour la carte IHM SISI
//----------------------------------------------------------------------------------------------------------------
// 10 unsigned char Lire_BP_I2C_Soft(void)                   // Gestion clavier IHM 
// 11 void Affiche_LCD(char *ligne1, char *ligne2)           // Gestion afficheur IHM
// 12 void Affiche_Fleche(void)
//---------------------------------------------------------------------------------------------------------------
// Fonctions spcifiques au robot suiveur de ligne
//---------------------------------------------------------------------------------------------------------------
// 31 void Arret_Moteurs()                                                              // Gestion des moteurs 
// 32 void Active_Moteurs(void)
// 33 unsigned char CalculerValeurCapteurLigne(void)                                                // FS11
// 34 unsigned char AdapterValeurCapteurLigneSiConnecteurAV(unsigned char ValeurCapteurLigneSVL)
// 35 unsigned char AfficherPositionRobotSVL(unsigned char ValeurCapteurLigneModif)                 // FS13
// 36 void CorrigerTrajectoireRobotSVL(unsigned char PositionRobotSVL)                              // FS12
// 37 Gestion_Balle
// *************************************************************************************************************** 
// ***************************************************************************************************************
// =============================================================================================================================
// Carte IHM
// =============================================================================================================================  
/* 10) Gestion du clavier I2C de la carte SISI
//-----------------------------------------------------------------------------------------------------------------------------
// Cration : Mars 2009
// Dernire rvision: Mars 2009
//------------------------------------------------------------------------------------------------------------------------------ 
Rle : Lit l'tat des boutons-poussoirs de l'IHM relie  la carte ATMEL SISI(PCF8574) 
et renvoie un code sur 8 bits. 

Remarque : I2C mul.

Commentaires : Dans un premier temps, la fonction renvoie le code du bouton-poussoir 
actionn (PLUS_I2C = 0x01, FlecheH=0x02, FlecheB=0x04, MOINS_I2C = Ox08, SET_I2C = 0x10, 
OK_I2C = 0x20, ENTR_I2C=0x40, ECHAP_I2C = 0x80) puis elle renvoie 0xFF si la touche est 
maintenue ou 0x00 si la touche est relche.

Entre(s) : aucunes

Sortie(s) : code de la touche ou 0x00(relche) ou 0xFF(maintenue)
------------------------------------------------------------------------------------------------------------------------------*/  
#if funcused Lire_BP_I2C_Soft
unsigned char Lire_BP_I2C_Soft(void)
{ 
  #define AUCUN	0x00
  
  static enum Etat_I2C {Attente_Relache_BP_I2C,Attente_Appui_BP_I2C} Etat_BP_I2C=Attente_Appui_BP_I2C;
  
  unsigned char Quel_BP_I2C, Quel_BP_I2C_1; 
  
  Quel_BP_I2C = Lire_Port_I2C_Soft(Add_BP_I2C); // Lecture du clavier
  
  switch (Etat_BP_I2C)
   {
    case Attente_Relache_BP_I2C :		// Etat d'attente : relchement de la touche
              if (Quel_BP_I2C == AUCUN) 	// Si on dtecte le relchement de la touche
               {
                 Quel_BP_I2C_1 = Quel_BP_I2C; 	  
                 delay_ms(20); 		// On attend 20ms (traitement des rebonds du contact)
                 
                 Quel_BP_I2C = Lire_Port_I2C_Soft(Add_BP_I2C); // Lecture du clavier
                 
                 if (Quel_BP_I2C_1 == Quel_BP_I2C) 		// Si elle est bien relche
                  {
                   Etat_BP_I2C = Attente_Appui_BP_I2C; 	// On passe dans l'tat : Attente d'un appui
                   return 0x00; 					// et on sort de la fonction en renvoyant 0 
                  }
                 else return 0xff; // sinon la touche est toujours actionne, 
               } 		  // On sort de la fonction en renvoyant 0
              else return 0xff; 
    break;
    
    case Attente_Appui_BP_I2C : 	// Etat d'attente : appui sur la touche
    	      if (Quel_BP_I2C != AUCUN) // Si on dtecte qu'une touche est actionne
               {
                 Quel_BP_I2C_1 = Quel_BP_I2C; 
                 delay_ms(20);	    // On attend 20ms (traitement des rebonds du contact)   
                 
                 Quel_BP_I2C = Lire_Port_I2C_Soft(Add_BP_I2C); // Lecture du clavier 
                    
                 if (Quel_BP_I2C_1 == Quel_BP_I2C)       // Si elle est bien appuye
                  {		      		 
                   Etat_BP_I2C = Attente_Relache_BP_I2C; // on passe dans l'tat Attente_relache
                   return Quel_BP_I2C;		 		// et on renvoie son code
                  }
                 else return 0x00; 				// sinon la touche est relche,
               }                    			// On sort de la fonction en renvoyant 255
              else return 0x00; 
    break;
   }
} 
#endif 
// =============================================================================================================================     
// 11) Gestion de l'afficheur LCD 2x16 lignes (processeur Hitachi) de la carte SISI
//------------------------------------------------------------------------------------------------------------------------------ 
// Cration : Mars 2003
// Dernire rvision: Mars 2003 
/* -----------------------------------------------------------------------------------------------------------------------------
Rle : Gre l'affichage d'un LCD quip d'un processeur Hitachi (command en mode 4 bits)

Commentaires : Envoie le contenu de deux tableaux de 16 caractres sur les lignes 0 et 1 d'un 
afficheur LCD 2*16 caractres.
Chaque tableau doit pouvoir contenir 17 valeurs (les 16 caractres  afficher + \0)

Librairie utilise : lcd.h

Entre(s) : ligne0, ligne1 = tableaux de 17 caractres

Sorties : Aucune
------------------------------------------------------------------------------------------------------------------------------*/
#if funcused Affiche_LCD
void Affiche_LCD(char *ligne1,char *ligne2)
{
		lcd_clear();
        lcd_puts(ligne1);
        lcd_gotoxy(0,1);
        lcd_puts(ligne2);
}
#endif
// =============================================================================================================================
// 12) Affichage de caractres personnaliss (flches)
//------------------------------------------------------------------------------------------------------------------------------
// Cration : Mars 2009
// Dernire rvision: Mars 2009
//------------------------------------------------------------------------------------------------------------------------------
#if funcused Affiche_Fleche
void Affiche_Fleche(void)
{
  lcd_gotoxy(15,0);	// Affichage flecheHaut
  lcd_putchar(Caractere_FlecheH);	
  lcd_gotoxy(15,1);	// Affichage flecheBas
  lcd_putchar(Caractere_FlecheB);
}
#endif
// ============================================================================================================================= 
//  Spcifique au Robot suiveur de ligne
// ============================================================================================================================= 
// 31 Gestion des moteurs
//------------------------------------------------------------------------------------------------------------------------------ 
// Cration : Mars 2009
// Dernire rvision: Mars 2009
//------------------------------------------------------------------------------------------------------------------------------ 
#if funcused Arret_Moteurs
void Arret_Moteurs()
{
      TCCR1A = 0x00;    // Arrt PWM 
      TCCR1B = 0x00; 
      PORTD = 0x30;     // Arrt Moteur 
}                                     
#endif   
//------------------------------------------------------------------------------------------------------------------------------
#if funcused Active_Moteurs  
void Active_Moteurs(void)
{
      	TCCR1A=0xF1;    // 0xA1 pour robot 2008 0xF1 pour robot 2009 et +
		TCCR1B=0x01;
} 
#endif
//------------------------------------------------------------------------------------------------------------------------------
// Dbut FS11: "Calculer la position du robot par rapport  la ligne" 		           
//------------------------------------------------------------------------------------------------------------------------------          
/*------------------------------------------------------------------------------------------------------------------------------	        
Rle: Grer le multiplexage des leds IR (metteur IR) et calculer la valeur numrique reprsentative de la 
position du capteur par rapport  la ligne.

Entre(s) : 	ACO		            bit     Sortie du comparateur analogique (interne au C). 
(Interne)                                   Reprsentatif de la position d'une cellule IR par rapport  la ligne.

Sortie(s) :     Cde_Del_IR 		    octet   Permet de multiplexer la commande des LED IR.
										    Comme Cde_Del_IR est transfre dans le port A, on donne ci-dessous 
          								    le dtail des bits de commande des LED IR.
                                                
					   					    Emetteur IR connect  au bit      Remarque 
										    ----------------------------------------------------         
										    E_D_IR		    "      PA0    |   Emetteur IR droit
										    E_CD_IR         "      PA1    |   Emetteur IR centre droit
										    E_C_IR		    "      PA2    |	  Emetteur IR centre
										    E_CG_IR         "	   PA3	  |   Emetteur IR centre Gauche
										    E_G_IR 		    "      PA4    |	  Emetteur IR gauche 
					                                                
			    ValeurCapteurLigne	octet 	Image de la position du "Capteur ligne" par rapport  la ligne.
------------------------------------------------------------------------------------------------------------------------------*/
#if funcused CalculerValeurCapteurLigne
unsigned char CalculerValeurCapteurLigne(void)
{
        unsigned char i =0;
        unsigned char ValeurCapteurLigne = 0;  // Initialisation  0
        unsigned char Cde_Del_IR = 1; 
 
        for (i=0;i<5;i++)  // Dbut Acquisition de la position du robot par rapport  la ligne
        {
            CAPTEUR_IR = ~Cde_Del_IR;
      	    delay_us(30);	// Activation d'un capteur  ajuster   (19s par dfaut)
            if (ACSR.5 == 1) ValeurCapteurLigne = ValeurCapteurLigne | Cde_Del_IR;   // ACSR.5 = ACO
            PORTA = 0xFF;
            Cde_Del_IR = Cde_Del_IR << 1 ;
            delay_us(540);	//  ajuster   (540s par dfaut)
        } 
        return ValeurCapteurLigne;
// Fin FS11
//------------------------------------------------------------------------------------------------------------------------------ 
}
#endif
//------------------------------------------------------------------------------------------------------------------------------
// FS11 suite
/*------------------------------------------------------------------------------------------------------------------------------	        
Rle: Calcul la valeur reprsentative de la position du robot par rapport  la ligne lorsque le capteur est
      positionn avec son connecteur  l'avant.

Entre(s) :  ValeurCapteurLigneSVL      octet   Position du capteur par rapport  la ligne renvoye par FS11

Sortie(s) : ValeurCapteurLigneSVLCorr   octet   Position du capteur par rapport   la ligne, corrige pour
                                                tre exploitable par FS13 et FS12 lorsque le "Capteur ligne" est
                                                positionn avec son connecteur  l'avant.	
------------------------------------------------------------------------------------------------------------------------------*/ 
#if funcused AdapterValeurCapteurLigneSiConnecteurAV
unsigned char AdapterValeurCapteurLigneSiConnecteurAV(unsigned char ValeurCapteurLigneSVL)
{
    unsigned char  ValeurCapteurLigneSVLModif = POS_HORS_LIGNE;
    
    switch (ValeurCapteurLigneSVL)              
       {  
//------------------------------------------------------------------------------------------------------------------------------               
// 		    Position_Robot 			            Modification de la valeur de commande des Leds       				
//------------------------------------------------------------------------------------------------------------------------------
		case POS_HORS_LIGNE:  		        ValeurCapteurLigneSVLModif = POS_HORS_LIGNE; break;		        // Hors ligne 
        
        case POS_CENTRE_1:     		        ValeurCapteurLigneSVLModif = POS_CENTRE_1; break;		        // Centre1 non visualis
        
        case POS_CENTRE_3: 	   		        ValeurCapteurLigneSVLModif = POS_CENTRE_3; break;		        // Centre3 
        
        case POS_CENTRE_5: 			        ValeurCapteurLigneSVLModif = POS_CENTRE_5; break;		        // Centre5 
        
        case AR_DROITE_OU_AV_GAUCHE: 	    ValeurCapteurLigneSVLModif = AR_GAUCHE_OU_AV_DROITE; break;			 
        
        case AR_DROITE_OU_AV_GAUCHE_PLUS:  	ValeurCapteurLigneSVLModif = AR_GAUCHE_OU_AV_DROITE_PLUS; break;		 
   		
        case AR_DROITE_OU_AV_GAUCHE_2PLUS:  ValeurCapteurLigneSVLModif = AR_GAUCHE_OU_AV_DROITE_2PLUS; break;
        
        case AR_DROITE_OU_AV_GAUCHE_3PLUS: 	ValeurCapteurLigneSVLModif = AR_GAUCHE_OU_AV_DROITE_3PLUS; break;
        
        case AR_GAUCHE_OU_AV_DROITE: 	    ValeurCapteurLigneSVLModif = AR_DROITE_OU_AV_GAUCHE; break;
        
        case AR_GAUCHE_OU_AV_DROITE_PLUS:  	ValeurCapteurLigneSVLModif = AR_DROITE_OU_AV_GAUCHE_PLUS; break;
   		
        case AR_GAUCHE_OU_AV_DROITE_2PLUS:  ValeurCapteurLigneSVLModif = AR_DROITE_OU_AV_GAUCHE_2PLUS; break;
        
        case AR_GAUCHE_OU_AV_DROITE_3PLUS: 	ValeurCapteurLigneSVLModif = AR_DROITE_OU_AV_GAUCHE_3PLUS; break;
        	
        default :				            ValeurCapteurLigneSVLModif = 0b00011111; break;     // Visu_Erreur_mesure_ligne
       }     
       
	return ValeurCapteurLigneSVLModif;  		     
}
#endif
//------------------------------------------------------------------------------------------------------------------------------ 
// =============================================================================================================================
/*------------------------------------------------------------------------------------------------------------------------------
// FS13 "Choisir la valeur  afficher sur les LEDs"				   		
//------------------------------------------------------------------------------------------------------------------------------ 
Rle: Choisir la valeur numrique ncessaire  la commande des leds rouge pour que leur clairage soit 
reprsentatif de la position du robot par rapport  la ligne.

Entres 
ValeurCapteurLigneModif :   octet 	Valeur renvoye par le capteur en fonction de sa position par rapport  
                                    la ligne.

Sortie
VisuPosition:               octet  	Reprsentatif des LED  clairer. Le bit 0 de VisuPosition commande la 
                                    Led D0 de l'interface IHM etc.
------------------------------------------------------------------------------------------------------------------------------*/
#if funcused AfficherPositionRobotSVL
unsigned char AfficherPositionRobotSVL(unsigned char ValeurCapteurLigneModif)
{
    unsigned char VisuPositionSVL = 0;    
    
    switch (ValeurCapteurLigneModif)              
       {  
//------------------------------------------------------------------------------------------------------------------------------               
// 		Position_Robot 			Modification de la valeur de commande des Leds       				
//------------------------------------------------------------------------------------------------------------------------------
		case POS_HORS_LIGNE:  		        VisuPositionSVL = VISUALISE_HORS_LIGNE; break;		// Hors ligne 
        
        case POS_CENTRE_1:     		        VisuPositionSVL = VISUALISE_CENTRE_1; break;		// Centre1 non visualis
        
        case POS_CENTRE_3: 	   		        VisuPositionSVL = VISUALISE_CENTRE_3; break;		// Centre3 
        
        case POS_CENTRE_5: 			        VisuPositionSVL = VISUALISE_CENTRE_5; break;		// Centre5 
        
        case AR_DROITE_OU_AV_GAUCHE: 	    VisuPositionSVL = VISUALISE_DROITE; break;          // Droite
                                           
        case AR_DROITE_OU_AV_GAUCHE_PLUS:  	VisuPositionSVL = VISUALISE_DROITE_PLUS; break;		// Droite+ 
   		
        case AR_DROITE_OU_AV_GAUCHE_2PLUS:  VisuPositionSVL = VISUALISE_DROITE_2PLUS; break;	// Droite2+  
        
        case AR_DROITE_OU_AV_GAUCHE_3PLUS: 	VisuPositionSVL = VISUALISE_DROITE_3PLUS;  break;   // Droite3+
        
        case AR_GAUCHE_OU_AV_DROITE: 	    VisuPositionSVL = VISUALISE_GAUCHE; break;			// Gauche 
        
        case AR_GAUCHE_OU_AV_DROITE_PLUS:   VisuPositionSVL = VISUALISE_GAUCHE_PLUS; break;		// Gauche+ 
   		
        case AR_GAUCHE_OU_AV_DROITE_2PLUS:  VisuPositionSVL = VISUALISE_GAUCHE_2PLUS; break;	// Gauche2+  
        
        case AR_GAUCHE_OU_AV_DROITE_3PLUS:  VisuPositionSVL = VISUALISE_GAUCHE_3PLUS; break;    // Gauche3+

        default :				            VisuPositionSVL = 0b00011111; break; // Visu_Erreur_mesure_ligne
       }     
       
	return VisuPositionSVL;  		     
// Fin FS13   
//------------------------------------------------------------------------------------------------------------------------------
}
#endif
// =============================================================================================================================
/*------------------------------------------------------------------------------------------------------------------------------ 
// Dbut FS12: "Choisir les valeurs des rapports cycliques"					
//------------------------------------------------------------------------------------------------------------------------------     
Rle: Choisir la valeur du rapport cyclique du signal de commande des moteurs du robot en fonction de
sa position par rapport  la ligne.

Entre(s):          Position_Robot           octet      (voir ci-dessus)    

Sortie(s):          CDE_MOTD                 octet		Correspond au registre (OCR1A). Rgle le rapport cyclique 
													    du signal de commande du moteur droit.
				    CDE_MOTG                 octet      Correspond au registre (OCR1B). Rgle le rapport cyclique
				 							 		    du signal de commande du moteur gauche.
------------------------------------------------------------------------------------------------------------------------------*/ 
#if funcused CorrigerTrajectoireRobotSVL
void CorrigerTrajectoireRobotSVL(unsigned char PositionRobotSVL)
{
    static enum EtatCommandeMoteurProf EtatCdeMoteur = COMDE_DEPART;
//------------------------------------------------------------------------------------------------------------------------------
// Graphe d'tat du suivi de ligne
//------------------------------------------------------------------------------------------------------------------------------
// Dpart
      switch (EtatCdeMoteur)              
       { // Dbut switch (EtatCdeMot)                                 
        case COMDE_DEPART: Arret_Moteurs(); 
        		if ((PositionRobotSVL == POS_CENTRE_1)||(PositionRobotSVL == POS_CENTRE_3)||(PositionRobotSVL == POS_CENTRE_5))
        		    { 
        		      Active_Moteurs();
        		      EtatCdeMoteur = COMDE_CENTRE;
        		    }
        		    else EtatCdeMoteur = COMDE_DEPART;
        break;   

        case COMDE_CENTRE : CDE_MOTG = PWM[0][0]; CDE_MOTD = PWM[0][1];
                          if (PositionRobotSVL == AR_GAUCHE_OU_AV_DROITE) EtatCdeMoteur = COMDE_DROITE;
                          	else if (PositionRobotSVL == AR_DROITE_OU_AV_GAUCHE) EtatCdeMoteur = COMDE_GAUCHE;
                          		else if (PositionRobotSVL == POS_HORS_LIGNE) EtatCdeMoteur = COMDE_COUPURE;
                          			else EtatCdeMoteur = COMDE_CENTRE;
        break;  
        
        
        case COMDE_DROITE:CDE_MOTG = PWM[1][0]; CDE_MOTD = PWM[1][1]; 
                         if (PositionRobotSVL == POS_CENTRE_5) EtatCdeMoteur = COMDE_CENTRE;
                          	else if (PositionRobotSVL == AR_GAUCHE_OU_AV_DROITE_PLUS) EtatCdeMoteur = COMDE_DROITE_PLUS;
                           		else if (PositionRobotSVL == POS_HORS_LIGNE) EtatCdeMoteur = COMDE_COUPURE;
                          			else EtatCdeMoteur = COMDE_DROITE;
        break;   
        
        case COMDE_DROITE_PLUS:CDE_MOTG = PWM[2][0]; CDE_MOTD = PWM[2][1];
        		        if (PositionRobotSVL == AR_GAUCHE_OU_AV_DROITE) EtatCdeMoteur = COMDE_DROITE;
                             else if (PositionRobotSVL == AR_GAUCHE_OU_AV_DROITE_2PLUS) EtatCdeMoteur = COMDE_DROITE_2PLUS;
                        		else EtatCdeMoteur = COMDE_DROITE_PLUS;
        break;  
        
        case COMDE_DROITE_2PLUS: CDE_MOTG = PWM[3][0]; CDE_MOTD = PWM[3][1];
        		        if (PositionRobotSVL == AR_GAUCHE_OU_AV_DROITE_PLUS) EtatCdeMoteur = COMDE_DROITE_PLUS; 
        	       		    else if (PositionRobotSVL == AR_GAUCHE_OU_AV_DROITE_3PLUS) EtatCdeMoteur = COMDE_DROITE_3PLUS;
        			   		    else EtatCdeMoteur = COMDE_DROITE_2PLUS;
        break;
             
        case COMDE_DROITE_3PLUS: CDE_MOTG = PWM[4][0]; CDE_MOTD = PWM[4][1];
        		        if (PositionRobotSVL == AR_GAUCHE_OU_AV_DROITE_2PLUS) EtatCdeMoteur = COMDE_DROITE_2PLUS; 
        	       		    else if (PositionRobotSVL == POS_HORS_LIGNE) EtatCdeMoteur = COMDE_DROITE_4PLUS;
        					    else EtatCdeMoteur = COMDE_DROITE_3PLUS;
        break;
        
        case COMDE_DROITE_4PLUS : CDE_MOTG = PWM[5][0]; CDE_MOTD = PWM[5][1];
        		        if (PositionRobotSVL == AR_GAUCHE_OU_AV_DROITE_3PLUS) EtatCdeMoteur = COMDE_DROITE_3PLUS;
        				    else EtatCdeMoteur = COMDE_DROITE_4PLUS;
        break;
        			  			  
        case COMDE_GAUCHE: CDE_MOTG = PWM[6][0]; CDE_MOTD = PWM[6][1]; 
                        if (PositionRobotSVL == POS_CENTRE_5) EtatCdeMoteur = COMDE_CENTRE;
                          	else if (PositionRobotSVL == AR_DROITE_OU_AV_GAUCHE_PLUS) EtatCdeMoteur = COMDE_GAUCHE_PLUS;  
                          		else if (PositionRobotSVL == POS_HORS_LIGNE) EtatCdeMoteur = COMDE_COUPURE;
                          			else EtatCdeMoteur = COMDE_GAUCHE;
        break;  
        
        case COMDE_GAUCHE_PLUS: CDE_MOTG = PWM[7][0]; CDE_MOTD = PWM[7][1]; 
                        if  (PositionRobotSVL == AR_DROITE_OU_AV_GAUCHE) EtatCdeMoteur = COMDE_GAUCHE;
        	              else if (PositionRobotSVL == AR_DROITE_OU_AV_GAUCHE_2PLUS) EtatCdeMoteur = COMDE_GAUCHE_2PLUS;
                               		else EtatCdeMoteur = COMDE_GAUCHE_PLUS;
        break; 
        
        case COMDE_GAUCHE_2PLUS: CDE_MOTG = PWM[8][0]; CDE_MOTD = PWM[8][1];
        		        if (PositionRobotSVL == AR_DROITE_OU_AV_GAUCHE_PLUS) EtatCdeMoteur = COMDE_GAUCHE_PLUS;
        		            else if (PositionRobotSVL == AR_DROITE_OU_AV_GAUCHE_3PLUS) EtatCdeMoteur = COMDE_GAUCHE_3PLUS;
        					    else EtatCdeMoteur = COMDE_GAUCHE_2PLUS;
        break;
        
        case COMDE_GAUCHE_3PLUS: CDE_MOTG = PWM[9][0]; CDE_MOTD = PWM[9][1];
        		        if (PositionRobotSVL == AR_DROITE_OU_AV_GAUCHE_2PLUS) EtatCdeMoteur = COMDE_GAUCHE_2PLUS;
        	       		    else if (PositionRobotSVL == POS_HORS_LIGNE) EtatCdeMoteur = COMDE_GAUCHE_4PLUS; 
        					    else EtatCdeMoteur = COMDE_GAUCHE_3PLUS;
        break;
        
        case COMDE_GAUCHE_4PLUS: CDE_MOTG = PWM[10][0]; CDE_MOTD = PWM[10][1];
        		        if (PositionRobotSVL == AR_DROITE_OU_AV_GAUCHE_3PLUS) EtatCdeMoteur = COMDE_GAUCHE_3PLUS;
        				    else EtatCdeMoteur = COMDE_GAUCHE_4PLUS;
        break;
        
        case COMDE_COUPURE: CDE_MOTG = PWM[0][0]; CDE_MOTD = PWM[0][1];
        
                          switch(PositionRobotSVL)
                          {
                            case POS_CENTRE_5:                  EtatCdeMoteur = COMDE_CENTRE; break;   
                            case AR_GAUCHE_OU_AV_DROITE:        EtatCdeMoteur = COMDE_DROITE; break;
                            case AR_GAUCHE_OU_AV_DROITE_PLUS:   EtatCdeMoteur = COMDE_DROITE_PLUS; break;
                            case AR_GAUCHE_OU_AV_DROITE_2PLUS:  EtatCdeMoteur = COMDE_DROITE_2PLUS; break;
                            case AR_GAUCHE_OU_AV_DROITE_3PLUS:  EtatCdeMoteur = COMDE_DROITE_3PLUS; break;
                            case AR_DROITE_OU_AV_GAUCHE:        EtatCdeMoteur = COMDE_GAUCHE ; break;
                            case AR_DROITE_OU_AV_GAUCHE_PLUS:   EtatCdeMoteur = COMDE_GAUCHE_PLUS; break;
                            case AR_DROITE_OU_AV_GAUCHE_2PLUS:  EtatCdeMoteur = COMDE_GAUCHE_2PLUS; break;
                            case AR_DROITE_OU_AV_GAUCHE_3PLUS:  EtatCdeMoteur = COMDE_GAUCHE_3PLUS; break;
                            default: EtatCdeMoteur = COMDE_COUPURE; break;  
                          }
        
        break;
//------------------------------------------------------------------------------------------------------------------------------        
// Fin FS12 
//------------------------------------------------------------------------------------------------------------------------------        
       }// Fin switch (EtatCdeMot)        
//------------------------------------------------------------------------------------------------------------------------------
#endif   
}
// =============================================================================================================================
