/*==============================================================================
Nom du fichier source : TrameIBM.h
Auteur: Philippe MARIANO

Cr le 23/04/2011
Dernire rvision le : 28/04/2011

Rle: Fichier d'en-tte de la bibliothque TrameIBM.lib
Description : Dsrialiser et dcoder une trame IBM (type clavier PS2)
Sources : Note d'application ATMEL AVR313 "interfacing the PC AT Keyboard" 
adaptes au cross compilateur CVAVR V2.

Cross compilateur utilis: CodeVisionAVR V2
Composant cible : Atmel 8 bits (ATiny861)

A placer dans le rpertoire du projet
================================================================================*/


#ifndef _TrameIBM_INCLUDED_
#define _TrameIBM_INCLUDED_

#pragma used+

//******************************************************************************
//******************************************************************************
// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
// Fichier d'origine: GESTION d'un clavier de PC type PS2
// Adaptation pour la carte Micro Design
// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
//******************************************************************************
//******************************************************************************

// Sur la carte Micro Design, le signal "DATA" est reu par la broche PB4
#ifndef DATA_CLAV
#define DATA_CLAV 	    PINB.4
#endif

#ifndef SORTIE
#define SORTIE		    1
#endif
#ifndef ENTREE
#define ENTREE		    0
#endif

//--------------------------------------------------------------------------------------------
/* Communication : Le programme principal se synchronise avec la routine d'interruption
situe dans la bibliothque TrameIBM.lib par l'intermdiaire des variables globales ci-dessous
---------------------------------------------------------------------------------------------*/ 
extern bit g_flag_char;			        // g_flag_char = 1 lorsqu'une touche est appuye
					                    // g_flag_char = 0 lorsqu'une touche a t relche
extern unsigned int g_Trame_TX; 
extern unsigned char g_Code_IBM;        // Code IBM Transmis 
// ------------------------------------------------------------------------------------------
// Sous programme d'interruption dclench lors de la capture d'un front sur INT0
// ------------------------------------------------------------------------------------------
interrupt [EXT_INT0] void ext_int0_isr(void);
/*
Rle : Dcoder et dsrialiser la trame IBM .
// ------------------------------------------------------------------------------------------
Description du fonctionnement:
// ------------------------------------------------------------------------------------------
Acquisition des 11 bits d'une trame IBM , dsrialisation, et avertissement de la routine  
consommatrice du caractre en positionnant  1 le drapeau <g_flag_char>.
// ------------------------------------------------------------------------------------------
Entre :
- Trame IBM  (signal "clock" reli  la broche INT0 du C et signal "DATA" reli  la broche 
dfinie plus haut.
// ------------------------------------------------------------------------------------------
Sorties :
- <g_Code_IBM> : variable globale de type unsigned char contenant le code IBM dsrialis.

- <g_flag_char> : variables globales de type unsigned char
		<g_flag_char> = 1 lorsqu'un caratre est reu
		<g_flag_char> = 0 lorsque le caractre a t consomm

//============================================================================================
REMARQUE IMPORTANTE : LES VARIABLES DEFINIES CI-DESSUS DOIVENT OBLIGATOIREMENT ETRE PLACEES
DANS LE CHAMP "VARIABLES GLOBALES" DU PROGRAMME FAISANT APPEL A LA ROUTINE D'INTERRUPTION.
//============================================================================================
*/

#pragma used-

#pragma library TrameIBM.lib

#endif