/*-----------------------------------------------------------------------
Nom du fichier: LibRobSuiv.h
Auteur: Philippe MARIANO

Rle: fichier d'en-tte de la bibliothque "LibRobSuiv.lib"
Cr le: 21/01/2010
Dernire rvision le:

Cross compilateur utilis: CodeVisionAVR
Composant cible : ATMEL 8 bits sur carte "Robot SISI"

Remarque: Ce fichier est destin  un projet CVAVR utilisant la carte SSI
Il doit tre plac dans le sous rpertoire \CVAVR\INC\ 
------------------------------------------------------------------------*/

// -----------------------------------------------------------------------------------------
#ifndef _LibRobSuiv_INCLUDED_ 	
#define _LibRobSuiv_INCLUDED_    


#define ACO 	ACSR.5      // Sortie du comparateur analogique      

// Signaux de commande des capteurs IR (capteur 5 cellules)
// ----------------------------------------------------------------------------------------------- 
// PA7 | PA6 | PA5 | PA4  | PA3 | PA2 | PA1 | PA0
// Res | Res | Res | IRG  |IRCG | IRC |IRCD | IRD  connecteur vers l'avant
// Res | Res|  Res | IRD  |IRCD | IRC |IRCG | IRG  connecteur vers l'arrire 
// Res: utilis par capteur 8 cellules
#define CAPTEUR_IR 	PORTA     



// Signaux de commande des moteurs 
// -----------------------------------------------------------------------------------------------  
#define CDE_MOTD	OCR1AL       // Cde moteur Droit
#define CDE_MOTG	OCR1BL	    // Cde moteur Gauche

// Adresses de la CGRAM de l'afficheur LCD type Hitachi
// ----------------------------------------------------------------------------------------------- 
//@ : adresse 
#define Add_FlecheH_CGRAM 0x40 // @1 Caractre flche haut
#define Add_FlecheB_CGRAM 0x48 // @2 Caractre flche bas

// Signaux de commande des Servos
// ----------------------------------------------------------------------------------------------- 
#ifndef CDE_SERVO1
#define CDE_SERVO1	PORTB.6
#endif
#ifndef CDE_SERVO2
#define CDE_SERVO2	PORTB.7
#endif
// Caractres spcifiques  afficher sur le LCD  
// ----------------------------------------------------------------------------------------------- 
#ifndef Caractere_FlecheH
#define Caractere_FlecheH	0 
#endif
#ifndef Caractere_FlecheB
#define Caractere_FlecheB	1
#endif
// -----------------------------------------------------------------------------------------
// Adresses des Ports E/S I2C PCF8574
// -----------------------------------------------------------------------------------------
#ifndef Add_LED_I2C
#define Add_LED_I2C   	0x40    // SLA+W
#endif  

#ifndef Add_BP_I2C
#define Add_BP_I2C   	0x42  	// SLA+W
#endif
// -----------------------------------------------------------------------------------------

// -----------------------------------------------------------------------------------------
// Codes des BPs de l'IHM I2C destin  la carte ATMEL S_ISI
// -----------------------------------------------------------------------------------------
#ifndef ECHAP_I2C
#define ECHAP_I2C   	128  
#endif 
#ifndef ENTR_I2C
#define ENTR_I2C 		64 
#endif
#ifndef OK_I2C
#define OK_I2C			32  
#endif 
#ifndef SET_I2C
#define SET_I2C			16 
#endif
#ifndef MOINS_I2C
#define MOINS_I2C     	8 
#endif
#ifndef FlecheB_I2C
#define FlecheB_I2C 	4 
#endif  
#ifndef FlecheH_I2C
#define FlecheH_I2C 	2 
#endif 
#ifndef PLUS_I2C
#define PLUS_I2C     	1
#endif  
// -----------------------------------------------------------------------------------------

// *****************************************************************************************
//
// Prototype des fonctions de la carte SISI 
// 
// *****************************************************************************************
// -------------------------------------------- Rcapitulatif ------------------------------ 
// 1 unsigned char Lire_BP_I2C_Soft(void);
// 2 void Arret_Moteurs(void);
// 3 void Active_Moteurs(void);
// 4 void Affiche_Fleche(void);
// 5 void Prise_Balle(void);
// -----------------------------------------------------------------------------------------
unsigned char Lire_BP_I2C_Soft(void);
/* -----------------------------------------------------------------------------------------
Rle : Lit l'tat des boutons-poussoirs de l'IHM relie  la carte ATMEL S_ISI(PCF8574) 
et renvoie un code sur 8 bits. Remarque : I2C mul.

Commentaires : Dans un premier temps, la fonction renvoie le code du bouton-poussoir 
actionn (PLUS_I2C = 0x01, FlecheH=0x02, FlecheB=0x04, MOINS_I2C = Ox08, SET_I2C = 0x10, 
OK_I2C = 0x20, ENTR_I2C=0x40, ECHAP_I2C = 0x80) puis elle renvoie 0xFF si la touche est 
maintenue ou 0x00 si la touche est relche.

Entres : aucunes

Sortie : code de la touche ou 0x00(relche) ou 0xFF(maintenue)
------------------------------------------------------------------------------------------*/   
void Arret_Moteurs(void);	// Dsactivation des moteurs
// -----------------------------------------------------------------------------------------
void Active_Moteurs(void);
// -----------------------------------------------------------------------------------------
void Affiche_Fleche(void);
// -----------------------------------------------------------------------------------------  

// -----------------------------------------------------------------------------------------
void Prise_Balle(void);
// -----------------------------------------------------------------------------------------

#pragma used-

#pragma library LibRobSuiv.lib

#endif    // termine la directive ifndef