/*****************************************************************************************
******************************************************************************************
Nom du fichier:SSI.h
------------------------------------------------------------------------------------------
Auteur: Philippe MARIANO
------------------------------------------------------------------------------------------
Rle: fichier d'en-tte de la librairie ssi.lib
------------------------------------------------------------------------------------------
Cr le : 10/03/2003
Dernire rvision le : 03/01/2010
------------------------------------------------------------------------------------------
Cross compilateur utilis: CodeVisionAVR
------------------------------------------------------------------------------------------
Composants cibles : ATMEL 8 bits
------------------------------------------------------------------------------------------
Remarques:
Ce fichier est destin  un projet CVAVR utilisant la carte SSI
Il doit tre plac dans le sous rpertoire \CVAVR\INC\
Placer le fichier ssi.lib dans le rpertoire \CVAVR\LIB\
*****************************************************************************************
*****************************************************************************************/

#ifndef _SSI_INCLUDED_ 		// Evite que le fichier ne soit inclus plusieurs fois
#define _SSI_INCLUDED_

// -----------------------------------------------------------------------------------------
//Interrupt vectors definitions
// -----------------------------------------------------------------------------------------
#ifndef EXT_INT0
#define EXT_INT0	2
#endif


// -----------------------------------------------------------------------------------------
// Dfinition du code des BPs de la carte ATMEL SSI
// -----------------------------------------------------------------------------------------
#ifndef INC
#define INC			0b00011111   	// 0x1f
#endif
#ifndef DEC
#define DEC			0b00101111      // 0x2f
#endif
#ifndef OK
#define OK			0b00110111		// 0x37
#endif
#ifndef ECHAP
#define ECHAP		0b00111011      // 0x3b
#endif
#ifndef SET
#define SET			0b00111101      // 0x3d
#endif
#ifndef ENTR
#define ENTR		0b00111110      // 0x3e
#endif

// -----------------------------------------------------------------------------------------
// Dfinition du code des BPs de l'IHM I2C destin  la carte ATMEL S_ISI
// -----------------------------------------------------------------------------------------
#ifndef ECHAP_I2C
#define ECHAP_I2C   	128  
#endif 
#ifndef ENTR_I2C
#define ENTR_I2C 		64 
#endif
#ifndef OK_I2C
#define OK_I2C			32  
#endif 
#ifndef SET_I2C
#define SET_I2C			16 
#endif
#ifndef MOINS_I2C
#define MOINS_I2C     	8 
#endif
#ifndef FlecheB_I2C
#define FlecheB_I2C 	4 
#endif  
#ifndef FlecheH_I2C
#define FlecheH_I2C 	2 
#endif 
#ifndef PLUS_I2C
#define PLUS_I2C     	1
#endif  

// ******************************************************************************************
// ******************************************************************************************
// Codes de commande de l'afficheur LCD 2x16  processeur Hitachi type HD44780
// ******************************************************************************************
// ******************************************************************************************
// Utilisation: A crire dans le registre de contrle de l'afficheur
// avec une instruction _lcd_write_data(unsigned char data) prcde d'une instruction
// _lcd_ready(void) de la librairie lcd.h
// ******************************************************************************************
// -----------------------------------------------------------------------------------------
// Initialisation du dplacement du curseur
// -----------------------------------------------------------------------------------------
#ifndef EntryMode0
#define EntryMode0      0b00000100 	// Par dfaut dplacement du curseur vers la gauche
#endif
#ifndef EntryMode1
#define EntryMode1      0b00000101 	// Par dfaut dplacement de l'affichage vers la gauche
#endif
#ifndef EntryMode2
#define EntryMode2      0b00000110 	// Par dfaut dplacement du curseur vers la droite
#endif
#ifndef EntryMode3
#define EntryMode3      0b00000111 	// Par dfaut dplacement de l'affichage vers la droite
#endif
#ifndef clear
#define clear           0b00000001 	// Efface l'cran et la DDRAM
#endif
#ifndef home
#define home            0b00000010 	// Ramne le curseur au dbut de la premire ligne
#endif
// -----------------------------------------------------------------------------------------
// Affichage             Code       	On/Off         curseur      	clignotement
// -----------------------------------------------------------------------------------------
#ifndef displayOff0
#define displayOff0     0b00001000  	//  Off      invisible     		non
#endif
#ifndef displayOff1
#define displayOff1     0b00001001  	//  Off      invisible     		oui
#endif
#ifndef displayOff2
#define displayOff2     0b00001010  	//  Off      visible       		non
#endif
#ifndef displayOff3
#define displayOff3     0b00001011  	//  Off      visible       		oui
#endif
#ifndef displayOn0
#define displayOn0      0b00001100  	//  On       invisible     		non
#endif
#ifndef displayOn1
#define displayOn1      0b00001101  	//  On       invisible     		oui
#endif
#ifndef displayOn2
#define displayOn2      0b00001110  	//  On       visible       		non
#endif
#ifndef displayOn3
#define displayOn3      0b00001111  	//  On       visible       		oui
#endif
// -----------------------------------------------------------------------------------------
// Dplacement du curseur ou de l'affichage
// -----------------------------------------------------------------------------------------
#ifndef curseurG
#define curseurG        0b00010000 	// Dplacement du curseur vers la gauche
#endif
#ifndef curseurD
#define curseurD        0b00010100 	// Dplacement du curseur vers la droite
#endif
#ifndef fenetreG
#define fenetreG        0b00011000 	// Dplacement de l'affichage vers la gauche
#endif
#ifndef fenetreD
#define fenetreD        0b00011100 	// Dplacement de l'affichage vers la droite
#endif
// -----------------------------------------------------------------------------------------
// -----------------------------------------------------------------------------------------
// Construction d'un caractre personalis. Codes  crire dans la CGRAM
// aux adresses $40, $48, $50, $58, $60, $68, $70, $78 avec une instruction
// lcd_write_byte(unsigned char adresse, unsigned char data)
// -----------------------------------------------------------------------------------------
// Exemple de dclaration d'une matrice 5x7, le 8e caractre correspond au curseur
// const unsigned char flecheHaut[8] = {0x04, 0x0E, 0x15, 0x04, 0x04, 0x04, 0x04, 0x00};
// 00100
// 01110
// 10101
// 00100
// 00100
// 00100
// 00100
// 00000
// ******************************************************************************************


// ******************************************************************************************
// ******************************************************************************************
// Prototype des fonctions gnrales de la carte SSI
// ******************************************************************************************
// ******************************************************************************************
// 1 - unsigned char Lire_BP(void);
// 2 - void Affiche_LCD(char *ligne1,char *ligne2);
// 3 - unsigned char eeprom_read(unsigned char addcase, unsigned int adressmap);
// 4 - void eeprom_write(unsigned char addcase, unsigned char adressmap,
// unsigned char data);
// 5 - void eeprom_page_read(unsigned char addcase, unsigned int adressmap,
// unsigned char *display_buffer);
// 6 - int regle_HTR(unsigned char adresse,unsigned char Heure_ou_Date, char H_J,
// char mn_mois, int sec_annee);
// ******************************************************************************************

#pragma used+
// --------------------------------------------------------------------------------------------------------
unsigned char Lire_BP(void);
/* --------------------------------------------------------------------------------------------------------
Rle : Lit l'tat des BP de la carte ATMEL SSI(PortA) et renvoie un code sur 8 bits.

Commentaires : Dans un premier temps, la fonction renvoie le code de la touche actionne
(INC = 0x1F, DEC = Ox2f, OK = 0x37, ECHAP = 0x3B, SET = 0x3D, ENTR=0x3E)
puis elle renvoie 0x00 si la touche est maintenue ou 0xFF si la touche est relche.

Entres : aucunes

Sortie : code de la touche ou 0x00 ou 0xFF
---------------------------------------------------------------------------------------------------------*/

// --------------------------------------------------------------------------------------------------------
void Affiche_LCD(char *ligne0,char *ligne1);
/* --------------------------------------------------------------------------------------------------------
Rle : Gre l'affichage d'un LCD quip d'un contrleur Hitachi (command en mode 4 bits)

Commentaires : Envoie le contenu de deux tableaux de 16 caractres sur les lignes 0 et
1 d'un afficheur LCD 2*16 caractres.
Chaque tableau doit pouvoir contenir 17 valeurs (les 16 caractres  afficher + \0)

Librairie utilis : lcd.h

Entres : ligne0, ligne1 = tableaux de 17 caractres

Sorties : Aucune
---------------------------------------------------------------------------------------------------------*/

// --------------------------------------------------------------------------------------------------------
unsigned char eeprom_read(unsigned char addcase, unsigned int adressmap);
/* --------------------------------------------------------------------------------------------------------
Rle : Lit un octet dans une mmoire srie gre par le protocole I2C

Commentaires : A utiliser avec les mmoires > 256 octets

Librairie utilise : I2C.h

Entres :
      addcase 	: Octet de commande du botier mmoire. Construit par 1 0 1 0 A2 A1 A0 R/W
                remarque (R/W doit tre mis  zro)
      adressmap : adresse  atteindre dans le botier

Sortie : contenu de l'adresse adressmap du botier situ en addcase
---------------------------------------------------------------------------------------------------------*/

// --------------------------------------------------------------------------------------------------------
void eeprom_write(unsigned char addcase, unsigned char adressmap, unsigned char data);
/* --------------------------------------------------------------------------------------------------------
Rle : Ecrit un octet dans une mmoire srie gre par le protocole I2C

Commentaires : A utiliser avec les mmoires > 256 octets

Librairie utilise : I2C.h et delay.h

Entres :
      addcase 	: adresse du botier mmoire construit par 1 0 1 0 A2 A1 A0 R/W
                remarque (R/W doit tre mis  zro)
      adressmap : adresse  atteindre dans le botier
      data 	: octet  crire  la position adressmap du botier situ en addcase

Sorties : aucune
---------------------------------------------------------------------------------------------------------*/

// --------------------------------------------------------------------------------------------------------
void eeprom_page_read(unsigned char addcase, unsigned int adressmap, unsigned char *display_buffer);
/* --------------------------------------------------------------------------------------------------------
Rle : Lit 32 octets dans une mmoire srie gre par le protocole I2C

Commentaires : A utiliser avec les mmoires > 256 octets

Librairie utilise : I2C.h

Entres :
      addcase 	: adresse du botier mmoire construit par 1 0 1 0 A2 A1 A0 R/W
                remarque (R/W doit tre mis  zro)
      adressmap : adresse  atteindre dans le botier

Sorties : contenu des 32 adresses  partir de adressmap du botier situ en addcase
---------------------------------------------------------------------------------------------------------*/

// --------------------------------------------------------------------------------------------------------
int regle_HTR(unsigned char adresse,unsigned char Heure_ou_Date, char H_J, char mn_mois, int sec_annee);
// --------------------------------------------------------------------------------------------------------
// Etats du graphe des transitions "REGLAGE"
// --------------------------------------------------------------------------------------------------------
#ifndef Regle_Heure_ou_date
#define Regle_Heure_ou_date	0
#endif
#ifndef Regle_min_mois
#define Regle_min_mois		1
#endif
#ifndef Regle_seconde_annee
#define Regle_seconde_annee	2
#endif
#ifndef Mise_a_jour_HTR
#define Mise_a_jour_HTR		3
#endif
/* --------------------------------------------------------------------------------------------------------
Rle : Rgle la date et l'heure d'une HTR PCF8583 situe  adresse (0 ou 1)

Commentaires :
La fonction rgle l'heure si Heure_ou_Date = 0 ou de la date si Heure_ou_Date = 1.
Les paramtres H_J, mn_mois, sec_annee servent de base aux rglages.
Celui-ci s'effectue avec les BP :
- INC pour augmenter une valeur,
- DEC pour diminuer une valeur,
- OK  pour valider la valeur modifie et passer au rglage suivant
- EChap pour transfrer la valeur rgle et sortir de la fonction

Librairie utilise : PCF8583.h

Entres :
	adresse : adresse du boitier (0 ou 1 selon A0)
	Si Heure_ou_Date = 0 (rglage de l'heure) alors -1 < H_J < 24, -1 < mn_mois < 60
							-1 < sec_annee < 60
						  sinon -1 < H_J < 32, 0 < mn_mois < 13
							1999 < sec_annee < 2050
Sortie : la fonction renvoie 0
---------------------------------------------------------------------------------------------------------*/


// ********************************************************************************************************
// Prototype des fonctions destines aux PPE et aux TP
// ********************************************************************************************************
// ********************************************************************************************************
// PPE Acces lyce: D2000_read, D2000_write
// PPE Pousse seringue: Menu_Select_Seringue, Regdebit
// PPE Doppler: RegVitesse
// ********************************************************************************************************

// ********************************************************************************************************
// Fonctions dveloppes pour le PPE Accs lyce
// --------------------------------------------------------------------------------------------------------
unsigned char D2000read(unsigned char adreemap);
/* --------------------------------------------------------------------------------------------------------
Rle : Lit un octet dans une carte  puce D2000 (gre par le protocole I2C)

Commentaires : Mmoire eeprom de type PCF8582 (256 octets)
		@botier fig en 0xa0

Librairie utilise : I2C.h

Entres : adressmap = adresse  atteindre dans le botier

Sorties : contenu de l'adresse adressmap du botier situ en 0xa0
---------------------------------------------------------------------------------------------------------*/
// --------------------------------------------------------------------------------------------------------
void D2000_write(unsigned char adressmap, unsigned char data);
/* --------------------------------------------------------------------------------------------------------
Rle : Ecrit un octet dans une carte  puce D2000 (gre par le protocole I2C)

Commentaires : Mmoire eeprom de type PCF8582 (256 octets)
               Adresse du botier fige en 0xa0

Librairie utilise : I2C.h

Entres :
          adressmap = adresse  atteindre dans le botier
          data = caractre  crire

Sorties : aucunes
---------------------------------------------------------------------------------------------------------*/

// ********************************************************************************************************
// Fonctions dveloppes pour le PPE/TP Pousse seringue
//--------------------------------------------------------------------------------------------------------
// 1 int Regdebit(unsigned int *dizaines,unsigned int *unites, unsigned int *diziemes);
// 2 unsigned char Select_Seringue(void);
//
// ********************************************************************************************************
// --------------------------------------------------------------------------------------------------------
int Regdebit(unsigned int *dizaines,unsigned int *unites, unsigned int *diziemes);
/* --------------------------------------------------------------------------------------------------------
Rle : Renvoie la valeur de la consigne de dbit rgle sous la forme dizaine, unit, dizime

Commentaires : fonction crite pour le pousse seringue

Librairie utilise : lcd.h et stdio.h

Entres / sortie : dizaine de ml/h, unit ml/h, dizime ml/h
---------------------------------------------------------------------------------------------------------*/
// --------------------------------------------------------------------------------------------------------
unsigned char Menu_Select_Seringue(void);
/* --------------------------------------------------------------------------------------------------------
Rle : Renvoie le type de la seringue slectionne
	 0 : TERUMO 50CC	1 : MONOJECT/ BD 50CC	        2 : BD 20CC

Commentaires : fonction crite pour le pousse seringue

Librairie utilise : lcd.h et stdio.h

sortie : seringue slectionne
---------------------------------------------------------------------------------------------------------*/

// ********************************************************************************************************
// Fonctions dveloppes pour les PPE Doppler
//--------------------------------------------------------------------------------------------------------
// 1 int RegVitesse(unsigned int *unites,unsigned int *diziemes, unsigned int *centiemes);
// 2 void ActiveTimer(void);
// 3 void DesactiveTimer(void);
// *******************************************************************************************************
// --------------------------------------------------------------------------------------------------------
int RegVitesse(unsigned int *unites,unsigned int *diziemes, unsigned int *centiemes);
/* --------------------------------------------------------------------------------------------------------
Rle : Renvoie la valeur de la consigne de Vitesse rgle sous la forme unit, dizime, centime
de mm

Commentaires : fonction crite pour le PPE Doppler

Librairie utilise : lcd.h et stdio.h

Entres / sortie : unit mm/s, dizime mm/s, centime de mm/s,
---------------------------------------------------------------------------------------------------------*/
// --------------------------------------------------------------------------------------------------------
unsigned char Menu_Select_Sens(void);
/* --------------------------------------------------------------------------------------------------------
Rle : Renvoie le sens de dplacement choisi
	0: Rentrer	1: Sortir

Commentaires : fonction crite pour le PPE Doppler

Librairie utilise : lcd.h et stdio.h

Entres : rien 		Sortie: sens
---------------------------------------------------------------------------------------------------------*/
// --------------------------------------------------------------------------------------------------------
void ActiveTimer(void);
/* --------------------------------------------------------------------------------------------------------
Rle : Autoriser le fonctionnement du timer1

Commentaires : fonction crite pour le PPE Doppler

Entres / sortie : rien
---------------------------------------------------------------------------------------------------------*/
// --------------------------------------------------------------------------------------------------------
void DesactiveTimer(void);
//--------------------------------------------------------------------------------------------------------
/* --------------------------------------------------------------------------------------------------------
Rle : Inhiber le fonctionnement du timer1

Commentaires : fonction crite pour le PPE Doppler

Entres / sortie : rien
---------------------------------------------------------------------------------------------------------*/   


// ********************************************************************************************************
// Fonctions dveloppes pour les PPE Robot solaire 12/2009
//--------------------------------------------------------------------------------------------------------
// 1) void Init_LCD_I2C_BATRON(void);
// 2) void LCD_I2C_BATRON_gotoxy(unsigned char x, unsigned char y);  
// 3) void Built_Strng_Fram_I2C_LCDBATRON(unsigned char FrameI2C, unsigned char Tstring, int Tstringsize);
// 4) void Displ_2Lines_On_I2C_LCDBATRON(char *Buffer_for_LCD_Line0, char *Buffer_for_LCD_Line1);  
// 5) void Display_Arrow_0n_I2C_LCDBATRON(void);
// *******************************************************************************************************
// -------------------------------------------------------------------------------------------------------
void Init_LCD_I2C_BATRON(void);
/* -------------------------------------------------------------------------------------------------------
// Description des commandes d'initialisation de l'afficheur LCD I2C BATRON (voir doc PCF2119x p22  p25)
/* -------------------------------------------------------------------------------------------------------
Ordre   Dsignation				   				Valeur				Remarques
// -------------------------------------------------------------------------------------------------------
1 	Adresse de l'afficheur 					=	0x76 			(SA0 = 1) [ envoyer en premier!!!]
2 	Select function setting		   			=	0x00 			Doit prcder une ou plusieurs commandes  
																dans la trameI2C ! (accs au reg IR ) 
3 	Command : Function set					=	0x34            2 lignes de 16 caractres 
4 	Command : Display control				=	0x0c            Display on, curseur off
5 	Command : Entry mode set	   			=   0x06  			Incrment, no shift
6	Command : Extended instruction set 		= 	0x35            -------------------------------------------
7	Command : Set display configuration		= 	0x04  			left-to-right, top to bottom 
8	Command : Set coefficient temperature	= 	0x10            TC1 = 0, TC2 = 0 (Par default)
9	Command : Set Internal HVgen stages		=	0x42            HV stage 3  ???
10	Command : Set VLCD						= 	0x9F            set VLCD, store VA (Rglage contraste)
11	Command : Normal instruction set		= 	0x34            -------------------------------------------
12	Command : Set DDRAM address				= 	0x80            DDRAM address = 0x00 
// --------------------------------------------------------------------------------------------------------
Autres commandes
 	Command : Clear display					= 	0x01 
 	Command : Write to DDRAM				=	0x40			Doit prcder une ou plusieurs donnes  
 																dans la trame 2C ! (accs au registre DR)  
---------------------------------------------------------------------------------------------------------*/ 
void LCD_I2C_BATRON_gotoxy(unsigned char x, unsigned char y);
/* --------------------------------------------------------------------------------------------------------
Rle : Positonner le curseur sur l'afficheur LCD BATRON

Commentaires : fonction crite pour le PPE Robot solaire

Entres : x=position dans la ligne [0,15], y=n de la ligne [0,1] 

---------------------------------------------------------------------------------------------------------*/  
void Built_Strng_Fram_I2C_LCDBATRON(unsigned char FrameI2C, unsigned char Tstring, int Tstringsize); 
/* --------------------------------------------------------------------------------------------------------
Rle : Construire une trame de texte de seize caractres maximum destine  tre affiche sur le LCD BATRON. 

Commentaires : Les caractres ASCII, passs dans le tableau "Tstring", sont transcods au format 
BATRON (ASCII+0x80) avant d'tre placs  la suite des codes SLA+W=0x76 et cde=write to DDRAM = 0x40 dans 
le tableau "FrameI2C".

Entres :
	Tstring: Tableau de 16 caractres ASCII  (termin par Nul)
	Tstringsize: longeur du tableau de caractres "Tstring"
	
Entre/sortie 
	FrameI2C: Tableau de 19 caractres, reprsentatif de la trame de texte qui sera envoye  l'afficheur avec
			  la fonction TWI_Start_Transc_With_Data(). Ce tableau doit tre initialis avec (SLA+W=0x76) et 
			  (cde=write to DDRAM=0x40) lors de sa dclaration.
     					Exemple : unsigned char Frame_I2C_Lcd_Line[19]={0x76,0x40};
	       	  A l'entre dans la fonction, FrameI2C={0x76,Ox40,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x}
	       	  A la sortie de la fonction, FrameI2C={SLA+W=0x76, cde=write to DDRAM=0x40, Contenu de Tstring=  
			  16 caractres max,  Nul } 

---------------------------------------------------------------------------------------------------------*/ 
void Displ_2Lines_On_I2C_LCDBATRON(char *Buffer_for_LCD_Line0, char *Buffer_for_LCD_Line1); 
/* --------------------------------------------------------------------------------------------------------
Rle : Afficher 2x16 caractres sur le LCD BATRON

Commentaires : Cette fonction construit une trame de texte au format BATRON (ASCII+0x80)   partir des 
tableaux de caractres ASCII "Buffer_for_LCD_Line0" et "Buffer_for_LCD_Line1" et la transmet  l'afficheur. 

Entres :  
	Buffer_for_LCD_Line0, Buffer_for_LCD_Line1 : Tableaux de caractres contenant les deux lignes de texte 
			(au format ASCII)  envoyer  l'afficheur {16 caractres ASCII  max, Nul}  
               Exemple de dclaration : char Buffer_for_LCD_Line0[17],Buffer_for_LCD_Line1[17];     

---------------------------------------------------------------------------------------------------------*/  
void Display_Arrow_0n_I2C_LCDBATRON(void);
/* --------------------------------------------------------------------------------------------------------
Rle : Afficher les flches "flche haute" et "flche basse"  droite de l'cran LCD.

Commentaires : fonction crite pour le PPE Robot solaire

Entres / Sortie: rien
---------------------------------------------------------------------------------------------------------*/

// --------------------------------------------------------------------------------------------------------
unsigned char Lire_BP_I2C(void);
/* --------------------------------------------------------------------------------------------------------
Rle : Lit l'tat des boutons-poussoirs de l'IHM relie  la carte ATMEL S_ISI(PCF8574) 
et renvoie un code sur 8 bits.

Commentaires : Dans un premier temps, la fonction renvoie le code du bouton-poussoir actionn
(PLUS_I2C = 0x01, FlecheH=0x02, FlecheB=0x04, MOINS_I2C = Ox08, SET_I2C = 0x10, OK_I2C = 0x20,  
ENTR_I2C=0x40, ECHAP_I2C = 0x80) puis elle renvoie 0xFF si la touche est maintenue ou 0x00 si la 
touche est relche.

Entres : aucunes

Sortie : code de la touche ou 0x00 ou 0xFF
---------------------------------------------------------------------------------------------------------*/

#pragma used-

#pragma library ssi.lib

#endif    // termine la directive ifndef
