/*-----------------------------------------------------------------------------
Nom du fichier:AVRTWIDRV.h
Auteur: Philippe MARIANO

Cr le 13/02/2010
Dernire rvision le 13/02/2010

Rle: Fonctions du drivers TWI (I2C)
Source : Note d'application AVR315, adaptes au cross compilateur CVAVR.

Cross compilateur utilis : CodeVisionAVR
Composant cible : ATMEL 8 bits

Remarque: Ce fichier est destin  un projet CVAVR utilisant la carte SSI
Il doit tre plac dans le sous rpertoire \CVAVR\INC\ 
-----------------------------------------------------------------------------*/

#ifndef _AVRTWIDRV_INCLUDED_
#define _AVRTWIDRV_INCLUDED_

#pragma used+


/************************************************************************************************************************************** 
	Paramtres  redfinir si ncessaire
**************************************************************************************************************************************/
#ifndef TWI_BUFFER_SIZE
#define TWI_BUFFER_SIZE 	4   	// Set this to the largest message size that will be sent including address byte.  
#endif

#ifndef TWI_TWBR
#define TWI_TWBR	   		0x20	// Pour FQ = 8MHz, Frquence de l'horloge I2C : 0x20 = 100kHz0k ;  0x02 pour 400kHz
#endif
//*************************************************************************************************************************************


#ifndef TWI_NO_STATE
#define TWI_NO_STATE            0xF8  	// No relevant state information available; TWINT = 0
#endif

// Interrupt vectors definitions
#ifndef TWI
#define TWI 			18
#endif

#ifndef TRUE
#define TRUE          		1 
#endif
#ifndef FALSE
#define FALSE         		0
#endif

#ifndef TWI_READ_BIT
#define TWI_READ_BIT  		0       // Bit position for R/W bit in "address byte".   
#endif

#ifndef TWI_ADR_BITS 
#define TWI_ADR_BITS  		1       // Bit position for LSB of the slave address bits in the init byte.
#endif

/**************************************************************************************************************************************
  TWI State codes
**************************************************************************************************************************************/
// General TWI Master status codes                      
#ifndef TWI_START
#define TWI_START                  0x08  // START has been transmitted  
#endif
#ifndef TWI_REP_START
#define TWI_REP_START              0x10  // Repeated START has been transmitted
#endif
#ifndef TWI_ARB_LOST
#define TWI_ARB_LOST               0x38  // Arbitration lost
#endif

// TWI Master Transmitter status codes   
#ifndef TWI_MTX_ADR_ACK                  
#define TWI_MTX_ADR_ACK            0x18  // SLA+W has been tramsmitted and ACK received
#endif
#ifndef TWI_MTX_ADR_NACK
#define TWI_MTX_ADR_NACK           0x20  // SLA+W has been tramsmitted and NACK received 
#endif 
#ifndef TWI_MTX_DATA_ACK  
#define TWI_MTX_DATA_ACK           0x28  // Data byte has been tramsmitted and ACK received
#endif 
#ifndef TWI_MTX_DATA_NACK
#define TWI_MTX_DATA_NACK          0x30  // Data byte has been tramsmitted and NACK received 
#endif 

// TWI Master Receiver status codes  
#ifndef TWI_MRX_ADR_ACK
#define TWI_MRX_ADR_ACK            0x40  // SLA+R has been tramsmitted and ACK received
#endif 
#ifndef TWI_MRX_ADR_NACK
#define TWI_MRX_ADR_NACK           0x48  // SLA+R has been tramsmitted and NACK received
#endif 
#ifndef TWI_MRX_DATA_ACK
#define TWI_MRX_DATA_ACK           0x50  // Data byte has been received and ACK tramsmitted
#endif 
#ifndef TWI_MRX_DATA_NACK 
#define TWI_MRX_DATA_NACK          0x58  // Data byte has been received and NACK tramsmitted
#endif 

// TWI Slave Transmitter status codes  
#ifndef TWI_STX_ADR_ACK 
#define TWI_STX_ADR_ACK            0xA8  // Own SLA+R has been received; ACK has been returned    
#endif 
#ifndef TWI_STX_ADR_ACK_M_ARB_LOST
#define TWI_STX_ADR_ACK_M_ARB_LOST 0xB0  // Arbitration lost in SLA+R/W as Master; own SLA+R has been received; ACK has been returned 
#endif 
#ifndef TWI_STX_ADR_ACK_M_ARB_LOST
#define TWI_STX_DATA_ACK           0xB8  // Data byte in TWDR has been transmitted; ACK has been received     
#endif 
#ifndef TWI_STX_DATA_NACK
#define TWI_STX_DATA_NACK          0xC0  // Data byte in TWDR has been transmitted; NOT ACK has been received  
#endif 
#ifndef TWI_STX_DATA_ACK_LAST_BYTE
#define TWI_STX_DATA_ACK_LAST_BYTE 0xC8  // Last data byte in TWDR has been transmitted (TWEA = 0); ACK has been received
#endif 

// TWI Slave Receiver status codes
#ifndef TWI_SRX_ADR_ACK 
#define TWI_SRX_ADR_ACK            0x60  // Own SLA+W has been received ACK has been returned   
#endif 
#ifndef TWI_SRX_ADR_ACK_M_ARB_LOST
#define TWI_SRX_ADR_ACK_M_ARB_LOST 0x68  // Arbitration lost in SLA+R/W as Master; own SLA+W has been received; ACK has been returned     
#endif 
#ifndef TWI_SRX_GEN_ACK
#define TWI_SRX_GEN_ACK            0x70  // General call address has been received; ACK has been returned       
#endif 
#ifndef TWI_SRX_GEN_ACK_M_ARB_LOST
#define TWI_SRX_GEN_ACK_M_ARB_LOST 0x78  // Arbitration lost in SLA+R/W as Master; General call address has been received; ACK has been returned  
#endif 
#ifndef TWI_SRX_ADR_DATA_ACK
#define TWI_SRX_ADR_DATA_ACK       0x80  // Previously addressed with own SLA+W; data has been received; ACK has been returned
#endif 
#ifndef TWI_SRX_ADR_DATA_NACK 
#define TWI_SRX_ADR_DATA_NACK      0x88  // Previously addressed with own SLA+W; data has been received; NOT ACK has been returned
#endif 
#ifndef TWI_SRX_GEN_DATA_ACK
#define TWI_SRX_GEN_DATA_ACK       0x90  // Previously addressed with general call; data has been received; ACK has been returned  
#endif 
#ifndef TWI_SRX_GEN_DATA_NACK
#define TWI_SRX_GEN_DATA_NACK      0x98  // Previously addressed with general call; data has been received; NOT ACK has been returned
#endif 
#ifndef TWI_SRX_STOP_RESTART
#define TWI_SRX_STOP_RESTART       0xA0  // A STOP condition or repeated START condition has been received while still addressed as Slave
#endif 

// TWI Miscellaneous status codes
#ifndef TWI_BUS_ERROR
#define TWI_BUS_ERROR              0x00  // Bus error due to an illegal START or STOP condition     
#endif


void TWI_Master_Initialise(void);

unsigned char TWI_Transceiver_Busy(void);

void TWI_Start_Transc_With_Data( unsigned char *msg, unsigned char msgSize );

unsigned char TWI_Get_Data_From_Transceiver( unsigned char *msg, unsigned char msgSize );

interrupt [TWI] void twi_isr(void);


#pragma used-

#pragma library AVRTWIDRV.lib

#endif