/*=======================================================================
Nom du fichier:ssi.c
Auteur: Philippe MARIANO

Rle: Source de la librairie ssi.lib 
Cr le 10/03/2003
Dernire rvision le 23/01/2010

Cross compilateur utilis: CodeVisionAVR
Composant cible : Atmel 8 bits (ATMega8535)

Remarque: Une fois compil par -> file --> Convert library
le fichier ssi.lib est automatiquement plac dans le rpertoire CVAVR\LIB 
========================================================================*/


#include <ssi.h>	
#include <stdio.h>
#include <delay.h>
#include <mega8535.h>
#include <i2c.h>
#include <lcd.h>
#include <pcf8583.h>

// ***************************************************************************************************************
// ***************************************************************************************************************
// 				Fonctions gnrales de la carte SSI 
// ***************************************************************************************************************
// Rcapitulatif
// 1) Lire_BP 
// 2) Affiche_LCD
// 3) eeprom_read, eeprom_write, eeprom_page_read
// 4) Regle_HTR
// ***************************************************************************************************************
//---------------------------------------------------------------------------------------------------------------- 
// Acquisition de l'tat des touches du clavier de la carte SSI
//---------------------------------------------------------------------------------------------------------------- 
// Cration : Mars 2003
// Dernire rvision: Juin 2006
//---------------------------------------------------------------------------------------------------------------- 
#if funcused Lire_BP
unsigned char Lire_BP(void)
{ 
  #define AUCUN	0x3f
  #define MASQUE_BP 0x3f
  
  static enum Etat {Attente_Relache_BP,Attente_Appui_BP} Etat_BP=Attente_Appui_BP;
  
  unsigned char Quel_BP_1, Quel_BP; 
  
  
  Quel_BP = PINA & MASQUE_BP; // lecture de l'tat des touches de la carte SSI
                           // prise en compte d'une seule touche
  switch (Etat_BP)
   {
    case Attente_Relache_BP :// Etat d'attente : relchement de la touche
              if (Quel_BP == AUCUN) // Si on dtecte le relchement de la touche
               {
                 Quel_BP_1 = Quel_BP; 	  // On attend 20ms (traitement des rebonds du contact)
                 delay_ms(20);             
                 Quel_BP = PINA & MASQUE_BP; // avant de la relire
                 
                 if (Quel_BP_1 == Quel_BP) // Si elle est bien relche
                  {
                   Etat_BP = Attente_Appui_BP; // On passe dans l'tat : Attente d'un appui
                   return 0xff; // et on sort de la fonction en renvoyant 255 
                  }
                 else return 0x00; // sinon la touche est toujours actionne, 
               } 		  // On sort de la fonction en renvoyant 0
              else return 0x00; 
    break;
    
    case Attente_Appui_BP : // Etat d'attente : appui sur la touche
    	      if (Quel_BP != AUCUN) // Si on dtecte qu'une touche est actionne
               {
                 Quel_BP_1 = Quel_BP; // On attend 20ms (traitement des rebonds du contact)
                 delay_ms(20);	      // avant de la relire 
                 Quel_BP = Quel_BP & MASQUE_BP;      
                 if (Quel_BP_1 == Quel_BP)       // Si elle est bien appuye
                  {		      		 
                   Etat_BP = Attente_Relache_BP; // on passe dans l'tat Attente_relache
                   return Quel_BP;		 // et on renvoie son code
                  }
                 else return 0xff; // sinon la touche est relche,
               }                    // On sort de la fonction en renvoyant 255
              else return 0xff; 
    break;
   }
} 
#endif 
//----------------------------------------------------------------------------------------------------------------     
// Gestion de l'afficheur LCD 2x16 lignes (processeur Hitachi) de la carte SSI
//---------------------------------------------------------------------------------------------------------------- 
// Cration : Mars 2003
// Dernire rvision: Mars 2003
//---------------------------------------------------------------------------------------------------------------- 
#if funcused Affiche_LCD
void Affiche_LCD(char *ligne1,char *ligne2)
{
		lcd_clear();
        lcd_puts(ligne1);
        lcd_gotoxy(0,1);
        lcd_puts(ligne2);
}
#endif
//---------------------------------------------------------------------------------------------------------------- 
// Gestion d'une mmoire eeprom I2C implante sur la carte SSI (mulation software)
//---------------------------------------------------------------------------------------------------------------- 
// Cration : Mars 2003
// Dernire rvision: Mars 2003
//---------------------------------------------------------------------------------------------------------------- 
#if funcused eeprom_read
unsigned char eeprom_read(unsigned char addcase, unsigned int adressmap)
{
 unsigned char data;
 unsigned char addhigh, addlow;
 addlow = adressmap;
 addhigh = adressmap /256;
 i2c_start();                       // rponse mmoire non traiter
 i2c_write(addcase);                //  terminer ....
 i2c_write(addhigh);
 i2c_write(addlow);
 i2c_start();
 i2c_write(addcase | 1);
 data = i2c_read(0);
 i2c_stop();
 return data;
 }
#endif   
//----------------------------------------------------------------------------------------------------------------
#if funcused eeprom_write
void eeprom_write(unsigned char addcase, unsigned char adressmap, unsigned char data)
{
 i2c_start();                       // rponse mmoire non traiter
 i2c_write(addcase);                //  terminer ....
 i2c_write(adressmap);
 i2c_write(data);
 i2c_stop();
// 30ms pour permettre  la mmoire de terminer son criture
 delay_ms(30);
 }
#endif    
//----------------------------------------------------------------------------------------------------------------      
#if funcused eeprom_page_read
void eeprom_page_read(unsigned char addcase, unsigned int adressmap, unsigned char *display_buffer)
{
 unsigned char i;
 unsigned char addhigh, addlow;
 addlow = adressmap;
 addhigh = adressmap /256;
 i2c_start();                       // rponse mmoire non traiter
 i2c_write(addcase);                //  terminer ....
 i2c_write(addhigh);
 i2c_write(addlow);
 i2c_start();
 i2c_write(addcase | 1);
 for (i=0;i<31;i++)
   {
     *display_buffer = i2c_read(1);
     *display_buffer++;
   }
   *display_buffer = i2c_read(0);
 i2c_stop();
 }
#endif 
//---------------------------------------------------------------------------------------------------------------- 
// Acquisition des paramtres d'une HTR I2C PCF8583
//---------------------------------------------------------------------------------------------------------------- 
// Cration : Mars 2003
// Dernire rvision: Mars 2003
//----------------------------------------------------------------------------------------------------------------    
#if funcused regle_HTR
int regle_HTR(unsigned char adresse,unsigned char Heure_ou_Date, char H_J, char mn_mois, int sec_annee)
{
 char BP, H_J_1, mn_mois_1;
 int  sec_annee_1;
 char Etat_reglage,Etat_reglage_1;
 char display_buffer_ligne0[17]; // tampon ligne 0 de l'afficheur
 char display_buffer_ligne1[17]; // tampon ligne 1 de l'afficheur

 Etat_reglage = Regle_Heure_ou_date;
      
 while(1)
 {
  BP = Lire_BP();  
    
  switch(Etat_reglage){
    
    case Regle_Heure_ou_date :   if (Heure_ou_Date == 0)    // Rglage de l'heure
        			 {
        			  if (H_J == 24) H_J = 0;
        			  if (H_J == -1) H_J = 23;
        			  if ((H_J_1 != H_J) || (Etat_reglage_1 != Etat_reglage))
        			   {
        			    sprintf(display_buffer_ligne0,"I>+ D>- O>mn E>S");
        	                    sprintf(display_buffer_ligne1,"h: %-uh %-umn %-us ",H_J, mn_mois,sec_annee);
        	         	    Affiche_LCD(display_buffer_ligne0,display_buffer_ligne1);
        	      		    H_J_1 = H_J;
        	      		   }
        	      		  }
        	      		else                       // Rglage du jour
        	      		 {
        	      		  if (H_J == 32) H_J = 0;
        			  if (H_J == 0) H_J = 31;
        			  if ((H_J_1 != H_J) || (Etat_reglage_1 != Etat_reglage))
        			   {
        			    sprintf(display_buffer_ligne0,"I>+ D>- O>M E>S");
        	                    sprintf(display_buffer_ligne1,"J: %-u %-u %-i", H_J, mn_mois,sec_annee);
        	         	    Affiche_LCD(display_buffer_ligne0,display_buffer_ligne1);
        	      		    H_J_1 = H_J;
        	      		   }
        	      		  } 
        	      		 
        	      		 switch(BP)
        	      		 {
        	      		  case INC   : H_J = H_J + 1; break;
        	      		  case DEC   : H_J = H_J - 1; break;
        	      		  case OK    : Etat_reglage = Regle_min_mois; break;
        	      		  case ECHAP : Etat_reglage = Mise_a_jour_HTR; break;
        	      		  default    : Etat_reglage = Regle_Heure_ou_date;
        	      		 }
        	      		 
        	      		 Etat_reglage_1 = Regle_Heure_ou_date;
    break;
        
    case Regle_min_mois    :    if (Heure_ou_Date == 0)	// Rglage des minutes
        			 {
        			  if (mn_mois == 60) mn_mois = 0;
        			  if (mn_mois == -1) mn_mois = 59;
        			  if ((mn_mois_1 != mn_mois) || (Etat_reglage_1 != Etat_reglage))
        			   {
        			    sprintf(display_buffer_ligne0,"I>+ D>- O>s E>S");
        	                    sprintf(display_buffer_ligne1,"mn: %-uh %-umn %-us ",H_J, mn_mois,sec_annee);
        	         	    Affiche_LCD(display_buffer_ligne0,display_buffer_ligne1);
        	      		    mn_mois_1 = mn_mois;
        	      		   }
        	      		 }
        	      		else
        	      		 {
        	      		  if (mn_mois == 13) mn_mois = 1;   // Rglage des mois
        			  if (mn_mois == 0) mn_mois = 12;
        			  if ((mn_mois_1 != mn_mois) || (Etat_reglage_1 != Etat_reglage))
        			   {
        			    sprintf(display_buffer_ligne0,"I>+ D>- O>A E>S");
        	                    sprintf(display_buffer_ligne1,"M: %-u %-u %-i", H_J, mn_mois,sec_annee);
        	         	    Affiche_LCD(display_buffer_ligne0,display_buffer_ligne1);
        	      		    mn_mois_1 = mn_mois;
        	      		   }
        	      		 }
        	      		 switch(BP)
        	      		 {
        	      		  case INC   : mn_mois = mn_mois + 1; break;
        	      		  case DEC   : mn_mois = mn_mois - 1; break;
        	      		  case OK    : Etat_reglage = Regle_seconde_annee; break;
        	      		  case ECHAP : Etat_reglage = Mise_a_jour_HTR; break;
        	      		  default    : Etat_reglage = Regle_min_mois;
        	      		 }
        	      		 Etat_reglage_1 = Regle_min_mois;
        
    break;
        
    case Regle_seconde_annee:    if (Heure_ou_Date == 0)     // Rglage des secondes
        			 {
        			  if (sec_annee == 60) sec_annee = 0;
        			  if (sec_annee == -1) sec_annee = 59;
        			  if ((sec_annee_1 != sec_annee) || (Etat_reglage_1 != Etat_reglage))
        			   {
        			    sprintf(display_buffer_ligne0,"I>+ D>- O>h E>S");
        	                    sprintf(display_buffer_ligne1,"s: %-uh %-umn %-us ",H_J, mn_mois,sec_annee);
        	         	    Affiche_LCD(display_buffer_ligne0,display_buffer_ligne1);
        	      		    sec_annee_1 = sec_annee;
        	      		   }
        	      		 }
        	      		else
        	      		 {
        	      		  if (sec_annee == 2100) mn_mois = 2000; // Rglage des annes
        			  if (sec_annee == 1999) mn_mois = 2000;
        			  if ((sec_annee_1 != sec_annee) || (Etat_reglage_1 != Etat_reglage))
        			   {
        			    sprintf(display_buffer_ligne0,"I>+ D>- O>J E>S");
        	                    sprintf(display_buffer_ligne1,"A: %-u %-u %-i", H_J, mn_mois,sec_annee);
        	         	    Affiche_LCD(display_buffer_ligne0,display_buffer_ligne1);
        	      		    sec_annee_1 = sec_annee;
        	      		   }
        	      		 }
        	      		 switch(BP)
        	      		 {
        	      		  case INC : sec_annee = sec_annee + 1; break;
        	      		  case DEC : sec_annee = sec_annee - 1; break;
        	      		  case OK  : Etat_reglage = Regle_Heure_ou_date; break;
        	      		  case ECHAP : Etat_reglage = Mise_a_jour_HTR; break;
        	      		  default  : Etat_reglage = Regle_seconde_annee;
        	      		 }
        	      		 Etat_reglage_1 = Regle_seconde_annee;
        
  break;    
  
  case Mise_a_jour_HTR  : if (Heure_ou_Date == 1)
  				rtc_set_date(adresse,H_J,mn_mois,sec_annee);
  			  else
  			  	rtc_set_time(adresse,H_J,mn_mois,sec_annee,00);
  			  return 0; 
  break;
     }//fin switch
   } //fin while 
} // fin SP  
#endif
//----------------------------------------------------------------------------------------------------------------
//     		Fin de la liste des fonctions gnrales de la carte SSI
// ***************************************************************************************************************
// ***************************************************************************************************************

// ***************************************************************************************************************
// ***************************************************************************************************************
// 		       		Fonctions cres pour les PPE 
// ***************************************************************************************************************
// Rcapitulatif
// PPE Acces lyce: D2000_read, D2000_write
// PPE Pousse seringue: Menu_Select_Seringue, Regdebit
// PPE Doppler: RegVitesse
//----------------------------------------------------------------------------------------------------------------
// 				PPE Accs Lyce
//----------------------------------------------------------------------------------------------------------------
// Gestion d'une mmoire I2C implant sur une carte type tlphonique
//---------------------------------------------------------------------------------------------------------------- 
// Cration : Mars 2003
// Dernire rvision: Mars 2003
//----------------------------------------------------------------------------------------------------------------
#if funcused D2000_read  
unsigned char D2000_read(unsigned char adressmap)
{
 unsigned char data;
 i2c_start();                    // rponse mmoire non traiter
 i2c_write(0xa0);                //  terminer ....
 i2c_write(adressmap);
 i2c_start();
 i2c_write(0xa1);
 data = i2c_read(0);
 i2c_stop();
 return data;
}
#endif
//----------------------------------------------------------------------------------------------------------------
#if funcused D2000_write
void D2000_write(unsigned char adressmap, unsigned char data)
{
 i2c_start();                    // rponse mmoire non traiter
 i2c_write(0xa0);                //  terminer ....
 i2c_write(adressmap);
 i2c_write(data);
 i2c_stop();
// 30ms pour permettre  la mmoire de terminer son criture
 delay_ms(30);
}
#endif
//----------------------------------------------------------------------------------------------------------------

//----------------------------------------------------------------------------------------------------------------
// 				PPE Pousse seringue 
//----------------------------------------------------------------------------------------------------------------
// Cration : Mars 2003
// Dernire rvision: Juin 2006  
//----------------------------------------------------------------------------------------------------------------
#if funcused Regdebit
int Regdebit(unsigned int *dizaines,unsigned int *unites, unsigned int *diziemes)
{    
 unsigned char BP, etat=0, etat_1=1; 
 unsigned int dizaines_1, unites_1,diziemes_1;
 char display_buffer_ligne0[17]; // tampon ligne 0 de l'afficheur
 char display_buffer_ligne1[17]; // tampon ligne 1 de l'afficheur
   
 while(1)
  {
   BP = Lire_BP();
   switch (etat)
	{
	  case 0 : // Rglage des dizaines
                   if (*dizaines==-1) *dizaines = 9;
        		else if (*dizaines == 10) *dizaines = 0;
   		   if ((dizaines_1 != *dizaines) || (etat_1 != etat))
        		{
        		  sprintf(display_buffer_ligne0,"inc/dec=+/- ->Ok");
        	          sprintf(display_buffer_ligne1,"%-u%-u.%-u ml/h ->ENTR",*dizaines, *unites,*diziemes);
        	          Affiche_LCD(display_buffer_ligne0,display_buffer_ligne1);
        	          dizaines_1 = *dizaines;
        	   	}
        	   switch(BP)
        	   	{
        	    	  case INC   : *dizaines = *dizaines + 1; break;
        	    	  case DEC   : *dizaines = *dizaines - 1; break;
        	    	  case OK    : etat = 1; break;
        	   	  case ENTR  : etat = 3; break;
        	    	  default    : etat = 0;
        	    	}
        	    	  etat_1 = 0; 	   
	  break;
	  
	  case 1 : // Rglage des unites
                   if (*unites==-1) *unites = 9;
        		else if (*unites == 10) *unites = 0;
   		   if ((unites_1 != *unites) || (etat_1 != etat))
        		{
        		  sprintf(display_buffer_ligne0,"inc/dec=+/- ->Ok");
        	          sprintf(display_buffer_ligne1,"%-u%-u.%-u ml/h ->ENTR",*dizaines, *unites,*diziemes);
        	          Affiche_LCD(display_buffer_ligne0,display_buffer_ligne1);
        	          unites_1 = *unites;
        	   	}
        	   switch(BP)
        	   	{
        	    	  case INC   : *unites = *unites + 1; break;
        	    	  case DEC   : *unites = *unites - 1; break;
        	    	  case OK    : etat = 2; break;
        	   	  case ENTR  : etat = 3; break;
        	    	  default    : etat = 1;
        	    	}
        	    	  etat_1 = 1; 
	  break;
	  
	  case 2 : // Rglage des dizimes
                   if (*diziemes==-1) *diziemes = 9;
        		else if (*diziemes == 10) *diziemes = 0;
   		   if ((diziemes_1 != *diziemes) || (etat_1 != etat))
        		{
        		  sprintf(display_buffer_ligne0,"inc/dec=+/- ->Ok");
        	          sprintf(display_buffer_ligne1,"%-u%-u.%-u ml/h ->ENTR",*dizaines, *unites,*diziemes);
        	          Affiche_LCD(display_buffer_ligne0,display_buffer_ligne1);
        	          diziemes_1 = *diziemes;
        	   	}
        	   switch(BP)
        	   	{
        	    	  case INC   : *diziemes = *diziemes + 1; break;
        	    	  case DEC   : *diziemes = *diziemes - 1; break;
        	    	  case OK    : etat = 0; break;
        	   	  case ENTR  : etat = 3; break;
        	    	  default    : etat = 2;
        	    	}
        	    	  etat_1 = 2; 
	  break; 
	  
	  case 3 :  return 0;
	  break;
	}
   }
}
#endif
//----------------------------------------------------------------------------------------------------------------
// Cration : Mars 2003
// Dernire rvision:Juin 2006       
//----------------------------------------------------------------------------------------------------------------
#if funcused Menu_Select_Seringue
unsigned char Menu_Select_Seringue(void)
{ 
char display_buffer_ligne0[17]; // tampon ligne 0 de l'afficheur
char display_buffer_ligne1[17]; // tampon ligne 1 de l'afficheur
unsigned char BP; 
int Choix_seringue=2, Choix_seringue_1=1; 

sprintf(display_buffer_ligne0,"inc/dec=+/- ->Ok");  

while(1)
  { 
  if (Choix_seringue_1 != Choix_seringue) 
    {
       	switch(Choix_seringue)     
        {
          case 0 : sprintf(display_buffer_ligne1,"    TERUMO 50CC"); break;
          case 1 : sprintf(display_buffer_ligne1,"   MONO/BD 50CC"); break;
          case 2 : sprintf(display_buffer_ligne1,"        BD 20CC"); break;
        } 
       Affiche_LCD(display_buffer_ligne0,display_buffer_ligne1);
       Choix_seringue_1 = Choix_seringue;
    }
    
   BP = Lire_BP();
   
   switch(BP)
    {
      case INC   : Choix_seringue = Choix_seringue + 1; break;
      case DEC   : Choix_seringue = Choix_seringue - 1; break;
      case OK    : return Choix_seringue; 
    }   
   
   if (Choix_seringue<=-1) Choix_seringue = 2;
       else if (Choix_seringue >= 3) Choix_seringue = 0;
  } 
}
#endif   
//-----------------------------------------------------------------------------------------------
//-----------------------------------------------------------------------------------------------
// 					PPE Doppler
//-----------------------------------------------------------------------------------------------
// Cration : Dcembre 2009
// Dernire rvision : Dcembre 2009 
//-----------------------------------------------------------------------------------------------
#if funcused RegVitesse
int RegVitesse(unsigned int *unites,unsigned int *diziemes, unsigned int *centiemes)
{    
 unsigned char BP, etat=0, etat_1=1; 
 unsigned int unites_1,diziemes_1, centiemes_1;
 char display_buffer_ligne0[17]; // tampon ligne 0 de l'afficheur
 char display_buffer_ligne1[17]; // tampon ligne 1 de l'afficheur
   
 while(1)
  {
   BP = Lire_BP();
   switch (etat)
	{
	  case 0 : // Rglage des units
                   if (*unites==-1) *unites = 9;
        		else if (*unites == 10) *unites = 0;
   		   if ((unites_1 != *unites) || (etat_1 != etat))
        		{ 
        		  sprintf(display_buffer_ligne0,"inc/dec=+/- ->Ok");
        	          sprintf(display_buffer_ligne1,"%-u%-u.%-u mm/s ->ENTR",*unites, *diziemes,*centiemes);
        	          Affiche_LCD(display_buffer_ligne0,display_buffer_ligne1); 
        	          
        	          unites_1 = *unites;
        	   	}
        	   switch(BP)
        	   	{
        	    	  case INC   : *unites = *unites + 1; break;
        	    	  case DEC   : *unites = *unites - 1; break;
        	    	  case OK    : etat = 1; break;
        	   	  case ENTR  : etat = 3; break;
        	    	  default    : etat = 0;
        	    	}
        	    	  etat_1 = 0; 	   
	  break;
	  
	  case 1 : // Rglage des dizimes
                   if (*diziemes==-1) *diziemes = 9;
        		else if (*diziemes == 10) *diziemes = 0;
   		   if ((diziemes_1 != *diziemes) || (etat_1 != etat))
        		{ 
        		  sprintf(display_buffer_ligne0,"inc/dec=+/- ->Ok");
        	          sprintf(display_buffer_ligne1,"%-u%-u.%-u mm/s ->ENTR",*unites, *diziemes,*centiemes);
        	          Affiche_LCD(display_buffer_ligne0,display_buffer_ligne1);
        	          diziemes_1 = *diziemes;
        	   	}
        	   switch(BP)
        	   	{
        	    	  case INC   : *diziemes = *diziemes + 1; break;
        	    	  case DEC   : *diziemes = *diziemes - 1; break;
        	    	  case OK    : etat = 2; break;
        	   	  case ENTR  : etat = 3; break;
        	    	  default    : etat = 1;
        	    	}
        	    	  etat_1 = 1; 
	  break;
	  
	  case 2 : // Rglage des centimes
                   if (*centiemes==-1) *centiemes = 9;
        		else if (*centiemes == 10) *centiemes = 0;
   		   if ((centiemes_1 != *centiemes) || (etat_1 != etat))
        		{ 
        		  sprintf(display_buffer_ligne0,"inc/dec=+/- ->Ok");
        	          sprintf(display_buffer_ligne1,"%-u%-u.%-u mm/s ->ENTR",*unites, *diziemes,*centiemes);
        	          Affiche_LCD(display_buffer_ligne0,display_buffer_ligne1);
        	          centiemes_1 = *centiemes;
        	   	}
        	   switch(BP)
        	   	{
        	    	  case INC   : *centiemes = *centiemes + 1; break;
        	    	  case DEC   : *centiemes = *centiemes - 1; break;
        	    	  case OK    : etat = 0; break;
        	   	  case ENTR  : etat = 3; break;
        	    	  default    : etat = 2;
        	    	}
        	    	  etat_1 = 2; 
	  break; 
	  
	  case 3 :  return 0;
	  break;
	}
   }
}
#endif 

//----------------------------------------------------------------------------------------------------------------
// Cration : Dcembre 2009
// Dernire rvision :  Dcembre 2009      
//----------------------------------------------------------------------------------------------------------------
#if funcused Menu_Select_Sens
unsigned char Menu_Select_Sens(void)
{
#define RENTRER 	0
#define SORTIR  	1    
  
// Variables locales
//----------------------------------------------------------------------------------------------------------------
// type 	nom              				Description
//----------------------------------------------------------------------------------------------------------------   
char display_buffer_ligne0[17]; 		// Tampon ligne 0 de l'afficheur
char display_buffer_ligne1[17]; 		// Tampon ligne 1 de l'afficheur
unsigned char BP; 				// Code des BP de la carte SSI
int Choix_sens=RENTRER, Choix_sens_1=SORTIR; 

sprintf(display_buffer_ligne0,"inc/dec=+/- ->Ok");  

  while(1)
   { 
    if (Choix_sens_1 != Choix_sens) 
    {
       	switch(Choix_sens)     
        {
          case RENTRER : sprintf(display_buffer_ligne1,"         Rentrer"); break;
          case SORTIR  : sprintf(display_buffer_ligne1,"          Sortir"); break;
        } 
       Affiche_LCD(display_buffer_ligne0,display_buffer_ligne1);
       Choix_sens_1 = Choix_sens;
    }
    
   BP = Lire_BP();
   
   switch(BP)
    {
      case INC   : Choix_sens = Choix_sens + 1; break;
      case DEC   : Choix_sens = Choix_sens - 1; break;
      case OK    : return Choix_sens; 
    }   
   
   if (Choix_sens<=-1) Choix_sens = 1;
       else if (Choix_sens >= 2) Choix_sens = 0;
  } 
}
#endif

//----------------------------------------------------------------------------------------------------------------
// Cration : Dcembre 2009
// Dernire rvision : Dcembre 2009 
//----------------------------------------------------------------------------------------------------------------
#if funcused ActiveTimer
void ActiveTimer(void)
{
TCCR1A= 0x40;TCCR1B=0x04; TIMSK=0x04;
} 
#endif 

//----------------------------------------------------------------------------------------------------------------
// Cration : Dcembre 2009
// Dernire rvision : Dcembre 2009 
//----------------------------------------------------------------------------------------------------------------
#if funcused DesactiveTimer
void DesactiveTimer(void)
{
TCCR1A=0x00; TCCR1B=0x00; TIMSK=0x00;
}
#endif 
//-----------------------------------------------------------------------------------------------
//-----------------------------------------------------------------------------------------------

