/****************************************************************************
Nom du fichier:LitClav102.c
Auteur: Philippe MARIANO

Cr le 15/03/08
Dernire rvision le 15/03/08

Rle: Dsrialiser et dcoder une trame issue d'un clavier de PC type PS2

Cross compilateur utilis: CodeVisionAVR
Composant cible : ATMEL 8bits

Remarque: Une fois compil par -> file --> Convert library
le fichier LitClav.lib est automatiquement plac dans le rpertoire CVAVR\LIB
******************************************************************************/

#include <LitClav102.h>


#if funcused ext_int0_isr
interrupt [EXT_INT0] void ext_int0_isr(void)
{
//--------------------------------------------------------------------------------------------------------
// Variables
//--------------------------------------------------------------------------------------------------------
//  type 			    Dsignation			            Commentaires
//--------------------------------------------------------------------------------------------------------
//Remarques g_ : variables globales
//--------------------------------------------------------------------------------------------------------
static unsigned int 	g_data = 0; 	  	// Trame transmise par le clavier
static unsigned char 	g_data_aff;         // Caractre extrait de la trame transmise par le clavier

static unsigned char 	edge = 0; 		    // edge = 0 si front descendant; edge =  1 si front montant
					  	                    // (du signal CLK provenant du clavier)
static char 		    bitcount_RX = 11;	// Permet de mmoriser le nombre de bits reus du clavier
static char 		    bitcount_TX = 10;   // Permet de mmoriser le nombre de bits transmis au clavier

static unsigned char 	is_up=0;		    // Etat de la touche
					  	                    // is_up = 0 : touche relche
					                        // is_up = 1 : touche actionne

static unsigned char    shift = 0;		    // Dtection action sur la touche shift
unsigned char 		    i;                  // Compteur d'usage gnral


/* Pour mmoire ----------------------------------------------------------------------------------------------
Le programme principal se synchronise avec cette routine d'interruption grace aux quatre variables ci-dessous:

bit g_Sens_transfert = TRANSMISSION;	// Indique le sens de la communication C <--> Clavier

// En rception (clavier -> C)
unsigned char 	g_key_ASCII='E'; 		// Contient le code ASCII de la touche presse ( initialiser avec un
							            // caractre n'existant pas sur le clavier utilis)
bit             g_flag_char = 0;		// drapeau reprsentatif de l'tat de la dernire touche appuye
							            // g_flag_char = 1 lorsqu'une touche est appuye
                                        // g_flag_char = 0 lorsqu'une touche a t relche
// En transmission (C -> clavier)
unsigned int    g_Trame_TX = REINITIALISATION_CLAVIER;     // Contient le code  transmettre au clavier
------------------------------------------------------------------------------------------------------------*/


switch (g_Sens_transfert)
{// Debut switch1
// ----------------------------------------- Rception trame PS2 --------------------------------------------
  case 0 :
// ------------------------------------------- Dsrialisation ----------------------------------------------

  if (!edge)                                    // Si front descendant
  {// dbut if1
    if (bitcount_RX < 12 && bitcount_RX > 0)    // Acquisition d'un bit du code
    {                                           // dbut if2 sur le front descendant de clk
      g_data = (g_data >> 1);
      if (DATA_CLAV)
        g_data = g_data | 0x8000;

    }// fin if2
    MCUCR = 3;                                  // INT0 actif sur le prochain front montant
    edge = 1;
  }//fin if1

 else                                           // si front descendant: dcomptage du nombre de bits
  {                                             // Dbut sinon1	reus sur le front montant
    MCUCR = 2;                                  // INT0 actif sur le prochain front descendant
    edge = 0;
    if (--bitcount_RX == 0)
     { // dbut if3
       g_data = (g_data >> 5);                  // Les 11 bits reus sont positionns dans g_data
                                                // Extraction du code caractre dans
       g_data_aff = (g_data>>1);                // la trame


// ---------------------------------- Dcodage du caractre reu ----------------------------------------------

      if (!is_up)                               // si dernier caractre reu = touche relche
        {                                       // dbut if4
          switch (g_data_aff)
           {                                    // dbut switch2
             case 0xf0 :                        // touche relche
               is_up = 1;
               g_flag_char = 0;
             break;

             case 0x12 :                        // dtection shift gauche
               shift = 1;
             break;

             case 0x59 :                        // dtection shift droite
               shift = 1;
             break;

             default:
               if (!shift)                      // shift non appuy
                 {
                  for (i = 0; unshifted[i][0] != g_data_aff && unshifted[i][0]; i++);
                  if (unshifted[i][0] == g_data_aff)
                   {
                     g_key_ASCII = unshifted[i][1];
                     if (g_flag_char==0)
                 		g_flag_char = 1;
                   }
                 }
                 else                           // si shift appuy
                 {
                  for (i = 0; shifted[i][0] != g_data_aff && shifted[i][0]; i++);
                  if (shifted[i][0] == g_data_aff)
                   {
                     g_key_ASCII = shifted[i][1];
                     if (g_flag_char==0)
                       		g_flag_char = 1;
                   }
                 }
             break;
          }                                     // fin switch 2
       }                                        // fin if4

       else
         {
          is_up = 0;
          switch (g_data_aff)
           {
             case 0x12 :                        // dtection shift gauche
               shift = 0;
             break;

             case 0x59 :                        // dtection shift droite
              shift = 0;
             break;
          }
         }
          bitcount_RX = 11;                     // Initialisation du compteur de rception
     }                                          // fin if3
   }                                            // fin sinon 1
 break;                                         // fin case 0

 case 1:  // ------------------------ Emmission trame PS2 ----------------------------------------------

         if (bitcount_TX != 0)
             {
              DATA_CLAV = g_Trame_TX;
              bitcount_TX -= 1;
              g_Trame_TX = (g_Trame_TX >> 1);
             }
         else
             {
              bitcount_TX = 10;                 // Initialisation du compteur de rception
              g_Sens_transfert = RECEPTION;     // Mode rception en fin d'mmission
              SENS_DATA_CLAV = ENTREE;          // Broche du signal Data en entre
             }
 break;                                         // fin case 1
 }                                              // fin switch 1
}
#endif

