/*****************************************************************************************
******************************************************************************************
Nom du fichier:LCDBATRON.h
------------------------------------------------------------------------------------------
Auteur: Philippe MARIANO
------------------------------------------------------------------------------------------
Rle: fichier d'en-tte de la librairie LCDBATRON.lib
------------------------------------------------------------------------------------------
Cr le : 23/1/2010
Dernire rvision le :
------------------------------------------------------------------------------------------
Cross compilateur utilis: CodeVisionAVR
------------------------------------------------------------------------------------------
Composants cibles : ATMEL 8 bits
------------------------------------------------------------------------------------------
Remarques:
Ce fichier est destin  un projet CVAVR utilisant la carte SSI
Il doit tre plac dans le sous rpertoire \CVAVR\INC\
Placer le fichier LCDBATRON.lib dans le rpertoire \CVAVR\LIB\
*****************************************************************************************
*****************************************************************************************/

#ifndef _LCDBATRON_INCLUDED_ 		// Evite que le fichier ne soit inclus plusieurs fois
#define _LCDBATRON_INCLUDED_

#define	LCD_BUSY_FLAG			0x80		// Bit position for display Busyflag
#define	LCD_DDRAM_ADR			0x80		// Write to DDRAM AC
#define LCD_DDRAM_WR			0x40		// Write to DDRAM
#define	LCD_FUNC_SET			0x00		// Enter LCD Function settings
#define LCD_NR_ROW  	   		2		// Number of display rows
#define LCD_NR_CHAR_PER_ROW  		16		// Number of characters on a row
#define LCD_ASCII_OFFSET		0x80		// The driver(Philips 2119) offset
							// according to the ASCII table
#define LCD_ADR 			0x76  		// LCD display adr, SA0 = HIGH
#define LCD_RS_DATA 			0xC0  		// Register Select data  Write
							// or read LCD DDRAMs data
#define LCD_RS_CONT 			0x80  		// Register Select Control Write
							// or read LCD Control reg
#define LCD_CLR_ADR 			0x02  		// Set DDRAM AC to 0 and return
							// shifted display to it's
							// Clear DDRAM and set DDRAM
							// AC to 0
#define LCD_SHIFT_LEFT			0x18		// Shift the displayed text once
							// to the left
#define LCD_READ_CONT_REG		0x00		// Setup for reading Busy Flag and
							// DDRAM address counter

#pragma used+

void Init_LCD_I2C_BATRON(void);
/* -------------------------------------------------------------------------------------------------------
// Description des commandes d'initialisation de l'afficheur LCD I2C BATRON (voir doc PCF2119x p22  p25)
-------------------------------------------------------------------------------------------------------
Ordre   Dsignation				   				Valeur				Remarques
// -------------------------------------------------------------------------------------------------------
1 	Adresse de l'afficheur 					=	0x76 			(SA0 = 1) [ envoyer en premier!!!]
2 	Select function setting		   			=	0x00 			Doit prcder une ou plusieurs commandes
																dans la trameI2C ! (accs au reg IR )
3 	Command : Function set					=	0x34            2 lignes de 16 caractres
4 	Command : Display control				=	0x0c            Display on, curseur off
5 	Command : Entry mode set	   			=   0x06  			Incrment, no shift
6	Command : Extended instruction set 		= 	0x35            -------------------------------------------
7	Command : Set display configuration		= 	0x04  			left-to-right, top to bottom
8	Command : Set coefficient temperature	= 	0x10            TC1 = 0, TC2 = 0 (Par default)
9	Command : Set Internal HVgen stages		=	0x42            HV stage 3  ???
10	Command : Set VLCD						= 	0x9F            set VLCD, store VA (Rglage contraste)
11	Command : Normal instruction set		= 	0x34            -------------------------------------------
12	Command : Set DDRAM address				= 	0x80            DDRAM address = 0x00
// --------------------------------------------------------------------------------------------------------
Autres commandes
 	Command : Clear display					= 	0x01
 	Command : Write to DDRAM				=	0x40			Doit prcder une ou plusieurs donnes
 																dans la trame 2C ! (accs au registre DR)
---------------------------------------------------------------------------------------------------------*/
void LCD_I2C_BATRON_gotoxy(unsigned char x, unsigned char y);
/* --------------------------------------------------------------------------------------------------------
Rle : Positonner le curseur sur l'afficheur LCD BATRON

Commentaires : fonction crite pour le PPE Robot solaire

Entres : x=position dans la ligne [0,15], y=n de la ligne [0,1]

---------------------------------------------------------------------------------------------------------*/
void Built_Strng_Fram_I2C_LCDBATRON(unsigned char *FrameI2C, unsigned char *Tstring, int Tstringsize);
/* --------------------------------------------------------------------------------------------------------
Rle : Construire une trame de texte de seize caractres maximum destine  tre affiche sur le LCD BATRON.

Commentaires : Les caractres ASCII, passs dans le tableau "Tstring", sont transcods au format
BATRON (ASCII+0x80) avant d'tre placs  la suite des codes SLA+W=0x76 et cde=write to DDRAM = 0x40 dans
le tableau "FrameI2C".

Entres :
	Tstring: Tableau de 16 caractres ASCII  (termin par Nul)
	Tstringsize: longeur du tableau de caractres "Tstring"

Entre/sortie
	FrameI2C: Tableau de 19 caractres, reprsentatif de la trame de texte qui sera envoye  l'afficheur avec
			  la fonction TWI_Start_Transc_With_Data(). Ce tableau doit tre initialis avec (SLA+W=0x76) et
			  (cde=write to DDRAM=0x40) lors de sa dclaration.
     					Exemple : unsigned char Frame_I2C_Lcd_Line[19]={0x76,0x40};
	       	  A l'entre dans la fonction, FrameI2C={0x76,Ox40,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x,x}
	       	  A la sortie de la fonction, FrameI2C={SLA+W=0x76, cde=write to DDRAM=0x40, Contenu de Tstring=
			  16 caractres max,  Nul }

---------------------------------------------------------------------------------------------------------*/
void Displ_2Lines_On_I2C_LCDBATRON(unsigned char *Buffer_for_LCD_Line0, unsigned char *Buffer_for_LCD_Line1);
/* --------------------------------------------------------------------------------------------------------
Rle : Afficher 2x16 caractres sur le LCD BATRON

Commentaires : Cette fonction construit une trame de texte au format BATRON (ASCII+0x80)   partir des
tableaux de caractres ASCII "Buffer_for_LCD_Line0" et "Buffer_for_LCD_Line1" et la transmet  l'afficheur.

Entres :
	Buffer_for_LCD_Line0, Buffer_for_LCD_Line1 : Tableaux de caractres contenant les deux lignes de texte
			(au format ASCII)  envoyer  l'afficheur {16 caractres ASCII  max, Nul}
               Exemple de dclaration : char Buffer_for_LCD_Line0[17],Buffer_for_LCD_Line1[17];

---------------------------------------------------------------------------------------------------------*/
void Display_Arrow_0n_I2C_LCDBATRON(void);
/* --------------------------------------------------------------------------------------------------------
Rle : Afficher les flches "flche haute" et "flche basse"  droite de l'cran LCD.

Commentaires : fonction crite pour le PPE Robot solaire

Entres / Sortie: rien
---------------------------------------------------------------------------------------------------------*/
#pragma used-

#pragma library LCDBATRON.lib

#endif    // termine la directive ifndef