/*=======================================================================
Nom du fichier: SISI2SVL.c
Auteur: Philippe MARIANO
// ----------------------------------------------------------------------
Rle: Source de la librairie SISI2SVL.lib  (PPE Robot Suiveur de Ligne)
// ----------------------------------------------------------------------
Cr le 23/01/2010
Dernire rvision le 27/12/2010
// ----------------------------------------------------------------------
Cross compilateur utilis: CodeVisionAVR V2.04.08a
Composant cible : Atmel 8 bits (Carte SISI I2C Soft)

Remarque: Une fois compil par -> file --> Convert library
le fichier SISI2SVL.lib est automatiquement plac dans le rpertoire 
CVAVR2\LIB 
========================================================================*/


//============================================================================================================
// Bibliothques   
//------------------------------------------------------------------------------------------------------------ 
// CVAVR
//------------------------------------------------------------------------------------------------------------
#include <mega32.h>
#include <delay.h>
#include <lcd.h>
#include <stdio.h>      
#include <pcf8583.h>
//------------------------------------------------------------------------------------------------------------
// Bibliothques dveloppes pour la carte SISI
//------------------------------------------------------------------------------------------------------------
#include "SISI2SVL.h"
#include "PCF8574.h"
//------------------------------------------------------------------------------------------------------------
// ***************************************************************************************************************
// ***************************************************************************************************************
// 				Fonctions pour le robot suiveur de ligne 
// ***************************************************************************************************************
// 1 Lire_BP_I2C_Soft 
// 2 Affiche_LCD
// 3 Arret_Moteurs 
// 4 Active_Moteurs
// 5 Affiche_Fleche
// 6 Gestion_Balle
// 7 RegleHTR
// *************************************************************************************************************** 
// ***************************************************************************************************************
// ===============================================================================================================
#if funcused Lire_BP_I2C_Soft
unsigned char Lire_BP_I2C_Soft(void)
{ 
  #define AUCUN	0x00
  
  static enum Etat_I2C {Attente_Relache_BP_I2C,Attente_Appui_BP_I2C} Etat_BP_I2C=Attente_Appui_BP_I2C;
  
  unsigned char Quel_BP_I2C, Quel_BP_I2C_1; 
  
  Quel_BP_I2C = Lire_Port_I2C_Soft(Add_BP_I2C); // Lecture du clavier
  
  switch (Etat_BP_I2C)
   {
    case Attente_Relache_BP_I2C :		// Etat d'attente : relchement de la touche
              if (Quel_BP_I2C == AUCUN) 	// Si on dtecte le relchement de la touche
               {
                 Quel_BP_I2C_1 = Quel_BP_I2C; 	  
                 delay_ms(20); 		// On attend 20ms (traitement des rebonds du contact)
                 
                 Quel_BP_I2C = Lire_Port_I2C_Soft(Add_BP_I2C); // Lecture du clavier
                 
                 if (Quel_BP_I2C_1 == Quel_BP_I2C) 		// Si elle est bien relche
                  {
                   Etat_BP_I2C = Attente_Appui_BP_I2C; 	// On passe dans l'tat : Attente d'un appui
                   return 0x00; 					// et on sort de la fonction en renvoyant 0 
                  }
                 else return 0xff; // sinon la touche est toujours actionne, 
               } 		  // On sort de la fonction en renvoyant 0
              else return 0xff; 
    break;
    
    case Attente_Appui_BP_I2C : 	// Etat d'attente : appui sur la touche
    	      if (Quel_BP_I2C != AUCUN) // Si on dtecte qu'une touche est actionne
               {
                 Quel_BP_I2C_1 = Quel_BP_I2C; 
                 delay_ms(20);	    // On attend 20ms (traitement des rebonds du contact)   
                 
                 Quel_BP_I2C = Lire_Port_I2C_Soft(Add_BP_I2C); // Lecture du clavier 
                    
                 if (Quel_BP_I2C_1 == Quel_BP_I2C)       // Si elle est bien appuye
                  {		      		 
                   Etat_BP_I2C = Attente_Relache_BP_I2C; // on passe dans l'tat Attente_relache
                   return Quel_BP_I2C;		 		// et on renvoie son code
                  }
                 else return 0x00; 				// sinon la touche est relche,
               }                    			// On sort de la fonction en renvoyant 255
              else return 0x00; 
    break;
   }
} 
#endif 
// =============================================================================================================================     
// Gestion de l'afficheur LCD 2x16 lignes (processeur Hitachi) de la carte SSI
//------------------------------------------------------------------------------------------------------------------------------ 
// Cration : Mars 2003
// Dernire rvision: Mars 2003
//------------------------------------------------------------------------------------------------------------------------------ 
#if funcused Affiche_LCD
void Affiche_LCD(char *ligne1,char *ligne2)
{
		lcd_clear();
        lcd_puts(ligne1);
        lcd_gotoxy(0,1);
        lcd_puts(ligne2);
}
#endif 
// ============================================================================================================================= 
#if funcused Arret_Moteurs
void Arret_Moteurs()
{
      TCCR1A = 0x00; // Arrt PWM 
      TCCR1B = 0x00; 
      PORTD = 0x30;     // Arrt Moteur 
}                                     
#endif   
// =============================================================================================================================
#if funcused Active_Moteurs  
void Active_Moteurs(void)
{
      	TCCR1A=0xF1; // 0xA1 pour robot 2008 0xF1 pour robot 2009
		TCCR1B=0x01;
} 
#endif
 // =============================================================================================================================
#if funcused Affiche_Fleche
void Affiche_Fleche(void)
{
  lcd_gotoxy(15,0);	// Affichage flecheHaut
  lcd_putchar(Caractere_FlecheH);	
  lcd_gotoxy(15,1);	// Affichage flecheBas
  lcd_putchar(Caractere_FlecheB);
}
#endif 
// =============================================================================================================================
//----------------------------------------------------------------------------------------------------------------
// Rglages de l'heure et de la date dans une HTR I2C PCF8583
//----------------------------------------------------------------------------------------------------------------
// Cration : Mars 2003
// Dernire rvision : Dcembre 2010
//----------------------------------------------------------------------------------------------------------------
#if funcused RegleHTR
int RegleHTR(unsigned char AddPCF8583, unsigned char HeureOuDate, unsigned char HeureOuJour,
unsigned char MinutesOuMois, unsigned int SecondeOuAnnee)
{
#define RegleHeureOuDate            0
#define RegleMinMois                1
#define RegleSecondeAnnee           2
#define MiseAJourHTR                3
//------------------------------------------------------------------------------------------------------------------------------
// Type                     Nom                                    Description
//------------------------------------------------------------------------------------------------------------------------------
// Buffer pour l'afficheur LCD  processeur HITACHI
 char DisplayBufferLigne0[17];                                  // Buffer ligne 0 de l'afficheur
 char DisplayBufferLigne1[17];                                  // Buffer ligne 1 de l'afficheur
//------------------------------------------------------------------------------------------------------------------------------
 unsigned char BpSSI = 0;                                       // Bouton-poussoir activ sur la carte ATMEL SSI
 unsigned char HeureOuJour_1 = 0, MinutesOuMois_1 = 0;          // Assurent la stabilit de l'affichage sur le LCD
 unsigned int SecondeOuAnnee_1 = 0;
 unsigned char EtatGraphe = RegleHeureOuDate;                   // Permet de faire voluer le graphe des transitions
 unsigned char EtatGraphe_1 = RegleMinMois;
//------------------------------------------------------------------------------------------------------------------------------
// Boucle infinie
 while(1)
 {
  BpSSI = Lire_BP_I2C_Soft();

  switch(EtatGraphe){

    case RegleHeureOuDate :
                    if (HeureOuDate == 0)     // Rglage de l'heure
                        {
                            if ((HeureOuJour_1 != HeureOuJour) || (EtatGraphe_1 != EtatGraphe))
                            {
                                sprintf(DisplayBufferLigne0,"[+] [-] O>mn E>S");
                                sprintf(DisplayBufferLigne1,"h: %-uh/%-umn/%-us ",HeureOuJour, MinutesOuMois,SecondeOuAnnee);
                                 Affiche_LCD(DisplayBufferLigne0,DisplayBufferLigne1);
                                  HeureOuJour_1 = HeureOuJour;
                              }
                          }
                      else                       // Rglage de la date
                          {
                            if ((HeureOuJour_1 != HeureOuJour) || (EtatGraphe_1 != EtatGraphe))
                            {
                                sprintf(DisplayBufferLigne0,"[+] [-] Ok>M E>S");
                                sprintf(DisplayBufferLigne1,"J: %-u/%-u/%-i",HeureOuJour, MinutesOuMois,SecondeOuAnnee);
                                 Affiche_LCD(DisplayBufferLigne0,DisplayBufferLigne1);
                                  HeureOuJour_1 = HeureOuJour;
                              }
                          }

                      switch(BpSSI)
                          {
                              case PLUS_I2C   : HeureOuJour = HeureOuJour + 1;
                                         if (HeureOuDate == 0)
                                         {
                                           if (HeureOuJour == 24) HeureOuJour = 0;
                                         }
                                         else
                                         {
                                          if (HeureOuJour == 32) HeureOuJour = 1;
                                         }
                            break;

                              case MOINS_I2C   : HeureOuJour = HeureOuJour - 1;
                                        if (HeureOuDate == 0)
                                         {
                                          if ((signed char)HeureOuJour == -1) HeureOuJour = 23;
                                         }
                                         else
                                         {
                                          if (HeureOuJour == 0) HeureOuJour = 31;
                                         }
                            break;
                              case OK_I2C    : EtatGraphe = RegleMinMois; break;
                              case ECHAP_I2C : EtatGraphe = MiseAJourHTR; break;
                              default    : EtatGraphe = RegleHeureOuDate;
                          }

                       EtatGraphe_1 = RegleHeureOuDate;
    break;
//------------------------------------------------------------------------------------------------------------------------------
    case RegleMinMois    :
                    if (HeureOuDate == 0)	// Rglage des minutes
        			    {
                            if ((MinutesOuMois_1 != MinutesOuMois) || (EtatGraphe_1 != EtatGraphe))
        			        {
        			            sprintf(DisplayBufferLigne0,"[+] [-] Ok>s E>S");
        	                    sprintf(DisplayBufferLigne1,"mn: %-uh/%-umn/%-us ",HeureOuJour, MinutesOuMois, SecondeOuAnnee);
        	         	        Affiche_LCD(DisplayBufferLigne0,DisplayBufferLigne1);
        	      		        MinutesOuMois_1 = MinutesOuMois;
        	      		    }
        	      		 }

        	      	else
        	      		 {                  // Rglage du mois
        			        if ((MinutesOuMois_1 != MinutesOuMois) || (EtatGraphe_1 != EtatGraphe))
        			        {
        			            sprintf(DisplayBufferLigne0,"[+] [-] Ok>A E>S");
        	                    sprintf(DisplayBufferLigne1,"M: %-u/%-u/%-i",HeureOuJour, MinutesOuMois, SecondeOuAnnee);
        	         	        Affiche_LCD(DisplayBufferLigne0,DisplayBufferLigne1);
        	      		        MinutesOuMois_1 = MinutesOuMois;
        	      		    }
        	      		 }

        	      	switch(BpSSI)
        	      	{
        	      	    case PLUS_I2C   : MinutesOuMois = MinutesOuMois + 1;
                                     if (HeureOuDate == 0)
                                         {
                                          if (MinutesOuMois == 60) MinutesOuMois = 0;
                                         }
                                         else
                                         {
                                           if (MinutesOuMois == 13) MinutesOuMois = 1;
                                         }
                        break;

        	      		case MOINS_I2C   : MinutesOuMois = MinutesOuMois - 1;
                                     if (HeureOuDate == 0)
                                         {
                                          if ((signed char)MinutesOuMois == -1) MinutesOuMois = 59;
                                         }
                                         else
                                         {
                                          if (MinutesOuMois == 0) MinutesOuMois = 12;
                                         }
                        break;
        	      		case OK_I2C    : EtatGraphe = RegleSecondeAnnee; break;
        	      		case ECHAP_I2C : EtatGraphe = MiseAJourHTR; break;
        	      		default    : EtatGraphe = RegleMinMois;
        	      	}

        	      	EtatGraphe_1 = RegleMinMois;

    break;
//------------------------------------------------------------------------------------------------------------------------------
    case RegleSecondeAnnee:
                    if (HeureOuDate == 0)     // Rglage des secondes
        			 {
        			  if ((SecondeOuAnnee_1 != SecondeOuAnnee) || (EtatGraphe_1 != EtatGraphe))
        			    {
        			        sprintf(DisplayBufferLigne0,"[+] [-] Ok>h E>S");
        	                sprintf(DisplayBufferLigne1,"s: %-uh/%-umn/%-us ",HeureOuJour, MinutesOuMois,SecondeOuAnnee);
        	         	    Affiche_LCD(DisplayBufferLigne0,DisplayBufferLigne1);
        	      		    SecondeOuAnnee_1 = SecondeOuAnnee;
        	      	    }
        	      	 }

        	      	else
        	      	{                       // Rglage des annes
        			    if ((SecondeOuAnnee_1 != SecondeOuAnnee) || (EtatGraphe_1 != EtatGraphe))
        			    {
        			        sprintf(DisplayBufferLigne0,"[+] [-] Ok>J E>S");
        	                sprintf(DisplayBufferLigne1,"A: %-u/%-u/%-i",HeureOuJour, MinutesOuMois, SecondeOuAnnee);
        	         	    Affiche_LCD(DisplayBufferLigne0,DisplayBufferLigne1);
        	      		    SecondeOuAnnee_1 = SecondeOuAnnee;
        	      		}
        	      	}

        	      	switch(BpSSI)
        	      	 {
        	      	   case PLUS_I2C : SecondeOuAnnee = SecondeOuAnnee + 1;
                                    if (HeureOuDate == 0)
                                         {
                                          if (SecondeOuAnnee == 60) SecondeOuAnnee = 0;
                                         }
                                         else
                                         {
                                           if (SecondeOuAnnee == 2021) SecondeOuAnnee = 2010;
                                         }
                        break;

        	      		case MOINS_I2C : SecondeOuAnnee = SecondeOuAnnee - 1;
                                    if (HeureOuDate == 0)
                                         {
                                          if (SecondeOuAnnee == -1) SecondeOuAnnee = 59;
                                         }
                                         else
                                         {
                                           if (SecondeOuAnnee == 2009) SecondeOuAnnee = 2020;
                                         }
                        break;
        	      		case OK_I2C  : EtatGraphe = RegleHeureOuDate; break;
        	      		case ECHAP_I2C : EtatGraphe = MiseAJourHTR; break;
        	      		default  : EtatGraphe = RegleSecondeAnnee;
        	      	 }

                     EtatGraphe_1 = RegleSecondeAnnee;

  break;
//------------------------------------------------------------------------------------------------------------------------------
  case MiseAJourHTR  :  // Ecriture des rglages dans l'HTR PCF8583
                   if (HeureOuDate == 1)
  				            rtc_set_date(AddPCF8583,HeureOuJour,MinutesOuMois,SecondeOuAnnee);
  			        else
  			  	            rtc_set_time(AddPCF8583,HeureOuJour,MinutesOuMois,SecondeOuAnnee,0);
  			        return 0;
  break;
//------------------------------------------------------------------------------------------------------------------------------
     }//fin switch
//------------------------------------------------------------------------------------------------------------------------------
   } //fin while
//------------------------------------------------------------------------------------------------------------------------------
} // fin SP
#endif
//----------------------------------------------------------------------------------------------------------------
