/*-----------------------------------------------------------------------
Nom du fichier: SISI2SVL.h
Auteur: Philippe MARIANO
// ----------------------------------------------------------------------
Projet: Robot suiveur de ligne
Rle: fichier d'en-tte de la bibliothque "SISI2SVL.lib"
// ----------------------------------------------------------------------
Cr le: 21/01/2010
Dernire rvision le:  27/12/2010
// ----------------------------------------------------------------------
Cross compilateur utilis: CodeVisionAVR V2
Composant cible : ATMEL 8 bits sur carte "SISI"
// ----------------------------------------------------------------------
Remarque: Ce fichier est destin  un projet CVAVR utilisant la carte SISI
(I2C soft) Il doit tre plac dans le rpertoire du projet 
------------------------------------------------------------------------*/

// -----------------------------------------------------------------------------------------------
#ifndef _SISI2SVL_INCLUDED_ 	
#define _SISI2SVL_INCLUDED_ 
   
// ***********************************************************************************************

// ***********************************************************************************************
// 										DEFINITIONS
// ===============================================================================================
// Definitions pour l'interface IHM de la carte ATMEL SISI  
// BP et Leds sur le bus I2C 
// ===============================================================================================
// Code des BPs 
// -----------------------------------------------------------------------------------------------
#ifndef ECHAP_I2C
#define ECHAP_I2C   	128  
#endif 
#ifndef ENTR_I2C
#define ENTR_I2C 		64 
#endif
#ifndef OK_I2C
#define OK_I2C			32  
#endif 
#ifndef SET_I2C
#define SET_I2C			16 
#endif
#ifndef MOINS_I2C
#define MOINS_I2C     	8 
#endif
#ifndef FlecheB_I2C
#define FlecheB_I2C 	4 
#endif  
#ifndef FlecheH_I2C
#define FlecheH_I2C 	2 
#endif 
#ifndef PLUS_I2C
#define PLUS_I2C     	1
#endif  
// -----------------------------------------------------------------------------------------------
// Adresses des Ports E/S I2C PCF8574 relis au BP et aux LED
// -----------------------------------------------------------------------------------------------
#ifndef Add_LED_I2C
#define Add_LED_I2C   	0x40    // SLA+W
#endif  

#ifndef Add_BP_I2C
#define Add_BP_I2C   	0x42  	// SLA+W
#endif
// ===============================================================================================
// =============================================================================================== 
// Dfinitions pour le robot suiveur de ligne
// ===============================================================================================
// -----------------------------------------------------------------------------------------------
// Signaux de commande des capteurs IR (capteur  5 cellules)
// ----------------------------------------------------------------------------------------------- 
// PA7 | PA6 | PA5 | PA4  | PA3 | PA2 | PA1 | PA0
// Res | Res | Res | IRG  |IRCG | IRC |IRCD | IRD  connecteur vers l'avant
// Res | Res|  Res | IRD  |IRCD | IRC |IRCG | IRG  connecteur vers l'arrire 
// Res: utilis par capteur 8 cellules
#ifndef CAPTEUR_IR
#define CAPTEUR_IR 	PORTA  
#endif   
// -----------------------------------------------------------------------------------------------
// Signaux de commande des moteurs 
// -----------------------------------------------------------------------------------------------  
#ifndef CDE_MOTD
#define CDE_MOTD	OCR1AL       	// Cde moteur Droit
#endif
#ifndef CDE_MOTG
#define CDE_MOTG	OCR1BL	    	// Cde moteur Gauche     
#endif
// -----------------------------------------------------------------------------------------------
// Signaux de commande des Servos
// ----------------------------------------------------------------------------------------------- 
#ifndef CDE_SERVO1
#define CDE_SERVO1	PORTD.6
#endif
#ifndef CDE_SERVO2
#define CDE_SERVO2	PORTD.7
#endif 
#ifndef Aff_Valeur_Cde_SERVO1
#define Aff_Valeur_Cde_SERVO1 	PIND.6    // Lecture cde Servo1
#endif    
#ifndef Aff_Valeur_Cde_SERVO2
#define Aff_Valeur_Cde_SERVO2 	PIND.7	 // Lecture cde Servo2 
#endif 
// -----------------------------------------------------------------------------------------------
// Adresses de la CGRAM de l'afficheur LCD type Hitachi
// ----------------------------------------------------------------------------------------------- 
//@ : adresse  
#ifndef Add_FlecheH_CGRAM
#define Add_FlecheH_CGRAM 0x40 // @1 Caractre flche haut
#endif
#ifndef Add_FlecheB_CGRAM
#define Add_FlecheB_CGRAM 0x48 // @2 Caractre flche bas
#endif
// -----------------------------------------------------------------------------------------------
// Caractres spcifiques  afficher sur le LCD  
// ----------------------------------------------------------------------------------------------- 
#ifndef Caractere_FlecheH
#define Caractere_FlecheH	0 
#endif
#ifndef Caractere_FlecheB
#define Caractere_FlecheB	1
#endif
// -----------------------------------------------------------------------------------------------
// ===============================================================================================
// ***********************************************************************************************
// ***********************************************************************************************
// Prototype des fonctions dveloppes pour la carte SISI monte sur un robot suiveur de ligne
// ***********************************************************************************************
// ***********************************************************************************************
// ----------------------------------------------- Rcapitulatif --------------------------------- 
// 1 unsigned char Lire_BP_I2C_Soft(void);
// 2 Affiche_LCD(char *ligne0,char *ligne1);
// 3 void Arret_Moteurs(void);
// 4 void Active_Moteurs(void);
// 5 void Affiche_Fleche(void);
// 6 void Gestion_Balle(void);
// -----------------------------------------------------------------------------------------------
#pragma used+
// -----------------------------------------------------------------------------------------------
unsigned char Lire_BP_I2C_Soft(void);
/* -----------------------------------------------------------------------------------------------
Rle : Lit l'tat des boutons-poussoirs de l'IHM relie  la carte ATMEL S_ISI(PCF8574) 
et renvoie un code sur 8 bits. Remarque : I2C mul.

Commentaires : Dans un premier temps, la fonction renvoie le code du bouton-poussoir 
actionn (PLUS_I2C = 0x01, FlecheH=0x02, FlecheB=0x04, MOINS_I2C = Ox08, SET_I2C = 0x10, 
OK_I2C = 0x20, ENTR_I2C=0x40, ECHAP_I2C = 0x80) puis elle renvoie 0xFF si la touche est 
maintenue ou 0x00 si la touche est relche.

Entres : aucunes

Sortie : code de la touche ou 0x00(relche) ou 0xFF(maintenue)
-----------------------------------------------------------------------------------------------*/   
// --------------------------------------------------------------------------------------------------------
void Affiche_LCD(char *ligne0,char *ligne1);
/* --------------------------------------------------------------------------------------------------------
Rle : Gre l'affichage d'un LCD quip d'un contrleur Hitachi (command en mode 4 bits)

Commentaires : Envoie le contenu de deux tableaux de 16 caractres sur les lignes 0 et
1 d'un afficheur LCD 2*16 caractres.
Chaque tableau doit pouvoir contenir 17 valeurs (les 16 caractres  afficher + \0)

Librairie utilis : lcd.h

Entres : ligne0, ligne1 = tableaux de 17 caractres

Sorties : Aucune
---------------------------------------------------------------------------------------------------------*/
void Arret_Moteurs(void);
// ----------------------------------------------------------------------------------------------

// ----------------------------------------------------------------------------------------------
void Active_Moteurs(void);
// ----------------------------------------------------------------------------------------------

// ----------------------------------------------------------------------------------------------
void Affiche_Fleche(void);
// ---------------------------------------------------------------------------------------------- 
int RegleHTR(unsigned char AddPCF8583, unsigned char HeureOuDate, unsigned char HeureOuJour,
unsigned char MinutesOuMois, unsigned int SecondeOuAnnee);
// --------------------------------------------------------------------------------------------------------
// Etats du graphe des transitions "REGLAGE"
// --------------------------------------------------------------------------------------------------------
#ifndef Regle_Heure_ou_date
#define Regle_Heure_ou_date	    0
#endif
#ifndef Regle_min_mois
#define Regle_min_mois		    1
#endif
#ifndef Regle_seconde_annee
#define Regle_seconde_annee 	2
#endif
#ifndef Mise_a_jour_HTR
#define Mise_a_jour_HTR		    3
#endif
/* --------------------------------------------------------------------------------------------------------
Rle : Rgle la date et l'heure d'une HTR PCF8583 situe  adresse (0 ou 1)

Commentaires :
La fonction rgle l'heure si Heure_ou_Date = 0 ou de la date si Heure_ou_Date = 1.
Les paramtres H_J, mn_mois, sec_annee servent de base aux rglages.
Celui-ci s'effectue avec les BP :
- INC pour augmenter une valeur,
- DEC pour diminuer une valeur,
- OK  pour valider la valeur modifie et passer au rglage suivant
- EChap pour transfrer la valeur rgle et sortir de la fonction

Librairie utilise : PCF8583.h

Entres :
	adresse : adresse du boitier (0 ou 1 selon A0)
	Si Heure_ou_Date = 0 (rglage de l'heure) alors -1 < H_J < 24, -1 < mn_mois < 60
							-1 < sec_annee < 60
						  sinon -1 < H_J < 32, 0 < mn_mois < 13
							1999 < sec_annee < 2050
Sortie : la fonction renvoie 0
---------------------------------------------------------------------------------------------------------*/

#pragma used-

#pragma library SISI2SVL.lib

#endif    // termine la directive ifndef