/*-----------------------------------------------------------------------
Nom du fichier:Stkx00.h
Auteur: Philippe MARIANO

Rle: fichier d'en-tte de la librairie stk200.lib 
Cr le 22/07/06
Dernire rvision le 7/10/06

Cross compilateur utilis: CodeVisionAVR
Composant cible : AT90S8535

Remarque: Ce fichier est destin  un projet CVAVR utilisant la carte STK200
Il doit tre plac dans le sous rpertoire \CVAVR\INC\ 
------------------------------------------------------------------------*/
 
 
#ifndef _Stkx00_INCLUDED_
#define _Stkx00_INCLUDED_

#pragma used+

//******************************************************************************
//******************************************************************************
// GESTION d'un clavier de PC type PS2
//******************************************************************************
//******************************************************************************


// Interrupt vectors definitions
// La broche PIND.2 reoit le signal CLOCK du clavier
#ifndef EXT_INT0
#define EXT_INT0 	2         
#endif

// Broche recevant le signal DATA du clavier
#ifndef SENS_DATA_CLAV
#define SENS_DATA_CLAV	DDRD.3     // A configurer selon la carte utilise
#endif
#ifndef DATA_CLAV
#define DATA_CLAV 	PIND.3	   		
#endif

// Configuration de la broche recevant le signal Data
#ifndef SORTIE
#define SORTIE		1
#endif
#ifndef ENTREE
#define ENTREE		0
#endif

// Rglage du sens de la transmission dans la routine d'interruption
#ifndef RECEPTION
#define RECEPTION		0
#endif

#ifndef TRANSMISSION
#define TRANSMISSION		1
#endif

// bits de contrle du clavier PS2
//--------------------------------------------Trame------------Code  ---------------------------        
#ifndef REINITIALISATION_CLAVIER
#define REINITIALISATION_CLAVIER 	0b0000001111111111 //  0xFF parit impaire 1 bit de stop
#endif


// -----------------------------------------------------------------------------
// Sous programme d'interruption dclench lors de la capture d'un front sur INT0
// -----------------------------------------------------------------------------
interrupt [EXT_INT0] void ext_int0_isr(void);
/*
Rle : Dcoder et dsrialiser la trame IBM issue du clavier type PS2 ou transmettre 
des caractres de contrle au clavier pour dtecter sa prsence et le configurer.

Description : 
EN RECEPTION: Acquire les 11 bits de la trame IBM transmis par le clavier, les
dsrialise, dcode la caractre reu grace  la table situe dans le fichier
scancoden.h et place le caractre ASCII correspondant dans une variable globale 
<g_key_ASCII>. Previent la routine consommatrice du caractre en positionnant  1 le
drapeau <g_flag_char>.

EN EMMISSION : Transmet les 10 bits de la trame contenu dans la variable globale de type
entier <g_trame_TX> sur les fronts montants du signal d'horloge (fourni par le clavier)
repasse en rception

Librairie utilis :Tpavnum.h  

Entres : 
- Trame IBM issue d'un clavier PS2 (signal clk reli  la broche INT0 du C
et signal DATA reli  la broche dfinie plus haut.
 
- <g_Sens_transfert> : variable globale de type unsigned char indiquant le sens de 
communication C <---> clavier  que doit grer la routine d'interruption
		<g_Sens_transfert>  = 0  => RECEPTION (C <--- clavier)
		<g_Sens_transfert>  = 1  => Transmission (C ---> clavier)
		
- <g_Trame_TX>  : variable globale de type unsigned int contenant la trame  
transmettre au clavier (transmission des 10 bits de poids faible).
Compossition de la trame :0 0 0 0 0 0  stop=1 parit d7 d6 d5 d4 d3 d2 d1 d0
Remarque: la parit est impaire par dfaut.

Sorties : 
- <g_key_ASCII> :variables globales de type unsigned char contient le code ASCII du caractre
correspondant  la touche dtect. Ce code est obtenu dans la table de transcodage situe dans <scancoden.h>

- <g_flag_char> :variables globales de type unsigned char  
		<g_flag_char> = 1 lorsqu'une touche est presse
		<g_flag_char> = 0 lorsqu'une touche a t relche 

REMARQUE IMPORTANTE: LES VARIABLES DEFINIES CI-DESSUS DOIVENT ETRE OBLIGATOIREMENT PLACEES 
DANS LE PROGRAMME FAISANT APPEL A LA ROUTINE D'INTERRUPTION

Exemple: 
bit g_Sens_transfert = TRANSMISSION;			// Indique le sens de la communication C <--> Clavier
                                                        // Initialis pour que le C dtecte le clavier--
// En rception (clavier -> C)
unsigned char 	g_key_ASCII= 'E'; 		       	// Contient le code ASCII de la touche presse ( initialiser avec un 
							// caractre n'existant pas sur le clavier utilis)
bit   g_flag_char = 0;					// drapeau reprsentatif de l'tat de la dernire touche appuye
							// g_flag_char = 1 lorsqu'une touche est appuye 
                                                        // g_flag_char = 0 lorsqu'une touche a t relche
// En transmission (YC -> clavier)							
unsigned int g_Trame_TX = REINITIALISATION_CLAVIER;     // Contient le code  transmettre au clavier
*/     


//******************************************************************************
//******************************************************************************
// GESTION d'un aficheur LCD
//******************************************************************************
//******************************************************************************
void Affiche_LCD(char *ligne1,char *ligne2);
/*
Rle : Gre l'affichage d'un LCD quip d'un contrleur Hitachi
       et command en mode 4 bits

Commentaires : Envoie le contenu de deux tableaux de 16 caractres sur les ligne 1 et
2 d'un afficheur LCD 2*16 caractres.
Chaque tableau doit pouvoir contenir les 16 caractres  afficher + \0

Librairie utilis : lcd.h  

Entres : ligne1, ligne2 = tableaux de 17 caractres

Sorties : Aucune
*/     
#pragma used-

#pragma library Stkx00.lib

#endif