/*=======================================================================
Nom du fichier:ssi2.c
Auteur: Philippe MARIANO

Rle: Source de la librairie ssi2.lib
Cr le 10/03/2003
Dernire rvision le 26/10/2010

Cross compilateur utilis: CodeVisionAVR V2.04.09
Composant cible : Atmel 8 bits (ATMega8535)

Cible Hardware  : Carte ATMEL SSI V1 et V2

Remarque: Une fois compil par -> file --> Convert library
le fichier ssi2.lib est automatiquement plac dans le rpertoire CVAVR\LIB
========================================================================*/

#include <mega8535.h>
#include <i2c.h>
#include <lcd.h>
#include <pcf8583.h>
#include <ssi2.h>
#include <stdio.h>
#include <delay.h>

// ***************************************************************************************************************
// ***************************************************************************************************************
// 				Fonctions gnrales de la carte SSI
// ***************************************************************************************************************
// Rcapitulatif
// 1) Lire_BP
// 2) Affiche_LCD
// 3) eeprom_read, eeprom_write, eeprom_page_read
// 4) RegleHTR
// ***************************************************************************************************************
//----------------------------------------------------------------------------------------------------------------
// Acquisition de l'tat des touches du clavier de la carte SSI
//----------------------------------------------------------------------------------------------------------------
// Cration : Mars 2003
// Dernire rvision: Juin 2006
//----------------------------------------------------------------------------------------------------------------
#if funcused Lire_BP
unsigned char Lire_BP(void)
{
  #define AUCUN	0x3f
  #define MASQUE_BP 0x3f

  static enum Etat {Attente_Relache_BP,Attente_Appui_BP} Etat_BP=Attente_Appui_BP;

  unsigned char Quel_BP_1, Quel_BP;


  Quel_BP = PINA & MASQUE_BP;   // lecture de l'tat des touches de la carte SSI
                                // prise en compte d'une seule touche
  switch (Etat_BP)
   {
    case Attente_Relache_BP :// Etat d'attente : relchement de la touche
              if (Quel_BP == AUCUN) // Si on dtecte le relchement de la touche
               {
                 Quel_BP_1 = Quel_BP; 	  // On attend 50ms (traitement des rebonds du contact)
                 delay_ms(50);
                 Quel_BP = PINA & MASQUE_BP; // avant de la relire

                 if (Quel_BP_1 == Quel_BP) // Si elle est bien relche
                  {
                   Etat_BP = Attente_Appui_BP; // On passe dans l'tat : Attente d'un appui
                   return 0xff; // et on sort de la fonction en renvoyant 255
                  }
                 else return 0x00; // sinon la touche est toujours actionne,
               } 		  // On sort de la fonction en renvoyant 0
              else return 0x00;
    break;

    case Attente_Appui_BP : // Etat d'attente : appui sur la touche
    	      if (Quel_BP != AUCUN) // Si on dtecte qu'une touche est actionne
               {
                 Quel_BP_1 = Quel_BP; // On attend 50ms (traitement des rebonds du contact)
                 delay_ms(50);	      // avant de la relire
                 Quel_BP = Quel_BP & MASQUE_BP;
                 if (Quel_BP_1 == Quel_BP)       // Si elle est bien appuye
                  {
                   Etat_BP = Attente_Relache_BP; // on passe dans l'tat Attente_relache
                   return Quel_BP;		 // et on renvoie son code
                  }
                 else return 0xff; // sinon la touche est relche,
               }                    // On sort de la fonction en renvoyant 255
              else return 0xff;
    break;
   }
}
#endif
//----------------------------------------------------------------------------------------------------------------
// Gestion de l'afficheur LCD 2x16 lignes (processeur Hitachi) de la carte SSI
//----------------------------------------------------------------------------------------------------------------
// Cration : Mars 2003
// Dernire rvision: Mars 2003
//----------------------------------------------------------------------------------------------------------------
#if funcused Affiche_LCD
void Affiche_LCD(char *ligne1,char *ligne2)
{
		lcd_clear();
        lcd_puts(ligne1);
        lcd_gotoxy(0,1);
        lcd_puts(ligne2);
}
#endif
//----------------------------------------------------------------------------------------------------------------
// Gestion d'une mmoire eeprom I2C implante sur la carte SSI (mulation software)
//----------------------------------------------------------------------------------------------------------------
// Cration : Mars 2003
// Dernire rvision: Mars 2003
//----------------------------------------------------------------------------------------------------------------
#if funcused eeprom_read
unsigned char eeprom_read(unsigned char addcase, unsigned int adressmap)
{
 unsigned char data;
 unsigned char addhigh, addlow;
 addlow = adressmap;
 addhigh = adressmap /256;
 i2c_start();                       // rponse mmoire non traiter
 i2c_write(addcase);                //  terminer ....
 i2c_write(addhigh);
 i2c_write(addlow);
 i2c_start();
 i2c_write(addcase | 1);
 data = i2c_read(0);
 i2c_stop();
 return data;
 }
#endif
//----------------------------------------------------------------------------------------------------------------
#if funcused eeprom_write
void eeprom_write(unsigned char addcase, unsigned char adressmap, unsigned char data)
{
 i2c_start();                       // rponse mmoire non traiter
 i2c_write(addcase);                //  terminer ....
 i2c_write(adressmap);
 i2c_write(data);
 i2c_stop();
// 30ms pour permettre  la mmoire de terminer son criture
 delay_ms(30);
 }
#endif
//----------------------------------------------------------------------------------------------------------------
#if funcused eeprom_page_read
void eeprom_page_read(unsigned char addcase, unsigned int adressmap, unsigned char *display_buffer)
{
 unsigned char i;
 unsigned char addhigh, addlow;
 addlow = adressmap;
 addhigh = adressmap /256;
 i2c_start();                       // rponse mmoire non traiter
 i2c_write(addcase);                //  terminer ....
 i2c_write(addhigh);
 i2c_write(addlow);
 i2c_start();
 i2c_write(addcase | 1);
 for (i=0;i<31;i++)
   {
     *display_buffer = i2c_read(1);
     *display_buffer++;
   }
   *display_buffer = i2c_read(0);
 i2c_stop();
 }
#endif
//----------------------------------------------------------------------------------------------------------------
// Rglages de l'heure et de la date dans une HTR I2C PCF8583
//----------------------------------------------------------------------------------------------------------------
// Cration : Mars 2003
// Dernire rvision : Dcembre 2010
//----------------------------------------------------------------------------------------------------------------
#if funcused RegleHTR
int RegleHTR(unsigned char AddPCF8583, unsigned char HeureOuDate, unsigned char HeureOuJour,
unsigned char MinutesOuMois, unsigned int SecondeOuAnnee)
{
#define RegleHeureOuDate	    0
#define RegleMinMois 		    1
#define RegleSecondeAnnee	    2
#define MiseAJourHTR		    3
//------------------------------------------------------------------------------------------------------------------------------
// Type 		            Nom 				       		    Description
//------------------------------------------------------------------------------------------------------------------------------
// Buffer pour l'afficheur LCD  processeur HITACHI
 char DisplayBufferLigne0[17];                                  // Buffer ligne 0 de l'afficheur
 char DisplayBufferLigne1[17];                                  // Buffer ligne 1 de l'afficheur
//------------------------------------------------------------------------------------------------------------------------------
 unsigned char BpSSI = 0;                                       // Bouton-poussoir activ sur la carte ATMEL SSI
 unsigned char HeureOuJour_1 = 0, MinutesOuMois_1 = 0;          // Assurent la stabilit de l'affichage sur le LCD
 unsigned int SecondeOuAnnee_1 = 0;
 unsigned char EtatGraphe = RegleHeureOuDate;                   // Permet de faire voluer le graphe des transitions
 unsigned char EtatGraphe_1 = RegleMinMois;
//------------------------------------------------------------------------------------------------------------------------------
// Boucle infinie
 while(1)
 {
  BpSSI = Lire_BP();

  switch(EtatGraphe){

    case RegleHeureOuDate :
                    if (HeureOuDate == 0)     // Rglage de l'heure
        			    {
        			        if ((HeureOuJour_1 != HeureOuJour) || (EtatGraphe_1 != EtatGraphe))
        			        {
        			            sprintf(DisplayBufferLigne0,"I>+ D>- O>mn E>S");
        	                    sprintf(DisplayBufferLigne1,"h: %-uh/%-umn/%-us ",HeureOuJour, MinutesOuMois,SecondeOuAnnee);
        	         	        Affiche_LCD(DisplayBufferLigne0,DisplayBufferLigne1);
        	      		        HeureOuJour_1 = HeureOuJour;
        	      	        }
        	      	    }
        	      	else                       // Rglage de la date
        	      	    {
        			        if ((HeureOuJour_1 != HeureOuJour) || (EtatGraphe_1 != EtatGraphe))
        			        {
        			            sprintf(DisplayBufferLigne0,"I>+ D>- O>M E>S");
        	                    sprintf(DisplayBufferLigne1,"J: %-u/%-u/%-i",HeureOuJour, MinutesOuMois,SecondeOuAnnee);
        	         	        Affiche_LCD(DisplayBufferLigne0,DisplayBufferLigne1);
        	      		        HeureOuJour_1 = HeureOuJour;
        	      		    }
        	      	    }

        	      	switch(BpSSI)
        	      	    {
        	      	        case INC   : HeureOuJour = HeureOuJour + 1;
                                         if (HeureOuDate == 0)
                                         {
                                           if (HeureOuJour == 24) HeureOuJour = 0;
                                         }
                                         else
                                         {
                                          if (HeureOuJour == 32) HeureOuJour = 1;
                                         }
                            break;

        	      		    case DEC   : HeureOuJour = HeureOuJour - 1;
                                        if (HeureOuDate == 0)
                                         {
                                          if ((signed char)HeureOuJour == -1) HeureOuJour = 23;
                                         }
                                         else
                                         {
                                          if (HeureOuJour == 0) HeureOuJour = 31;
                                         }
                            break;
        	      		    case OK    : EtatGraphe = RegleMinMois; break;
        	      		    case ECHAP : EtatGraphe = MiseAJourHTR; break;
        	      		    default    : EtatGraphe = RegleHeureOuDate;
        	      	    }

        	      	 EtatGraphe_1 = RegleHeureOuDate;
    break;
//------------------------------------------------------------------------------------------------------------------------------
    case RegleMinMois    :
                    if (HeureOuDate == 0)	// Rglage des minutes
        			    {
                            if ((MinutesOuMois_1 != MinutesOuMois) || (EtatGraphe_1 != EtatGraphe))
        			        {
        			            sprintf(DisplayBufferLigne0,"I>+ D>- O>s E>S");
        	                    sprintf(DisplayBufferLigne1,"mn: %-uh/%-umn/%-us ",HeureOuJour, MinutesOuMois, SecondeOuAnnee);
        	         	        Affiche_LCD(DisplayBufferLigne0,DisplayBufferLigne1);
        	      		        MinutesOuMois_1 = MinutesOuMois;
        	      		    }
        	      		 }

        	      	else
        	      		 {                  // Rglage du mois
        			        if ((MinutesOuMois_1 != MinutesOuMois) || (EtatGraphe_1 != EtatGraphe))
        			        {
        			            sprintf(DisplayBufferLigne0,"I>+ D>- O>A E>S");
        	                    sprintf(DisplayBufferLigne1,"M: %-u/%-u/%-i",HeureOuJour, MinutesOuMois, SecondeOuAnnee);
        	         	        Affiche_LCD(DisplayBufferLigne0,DisplayBufferLigne1);
        	      		        MinutesOuMois_1 = MinutesOuMois;
        	      		    }
        	      		 }

        	      	switch(BpSSI)
        	      	{
        	      	    case INC   : MinutesOuMois = MinutesOuMois + 1;
                                     if (HeureOuDate == 0)
                                         {
                                          if (MinutesOuMois == 60) MinutesOuMois = 0;
                                         }
                                         else
                                         {
                                           if (MinutesOuMois == 13) MinutesOuMois = 1;
                                         }
                        break;

        	      		case DEC   : MinutesOuMois = MinutesOuMois - 1;
                                     if (HeureOuDate == 0)
                                         {
                                          if ((signed char)MinutesOuMois == -1) MinutesOuMois = 59;
                                         }
                                         else
                                         {
                                          if (MinutesOuMois == 0) MinutesOuMois = 12;
                                         }
                        break;
        	      		case OK    : EtatGraphe = RegleSecondeAnnee; break;
        	      		case ECHAP : EtatGraphe = MiseAJourHTR; break;
        	      		default    : EtatGraphe = RegleMinMois;
        	      	}

        	      	EtatGraphe_1 = RegleMinMois;

    break;
//------------------------------------------------------------------------------------------------------------------------------
    case RegleSecondeAnnee:
                    if (HeureOuDate == 0)     // Rglage des secondes
        			 {
        			  if ((SecondeOuAnnee_1 != SecondeOuAnnee) || (EtatGraphe_1 != EtatGraphe))
        			    {
        			        sprintf(DisplayBufferLigne0,"I>+ D>- O>h E>S");
        	                sprintf(DisplayBufferLigne1,"s: %-uh/%-umn/%-us ",HeureOuJour, MinutesOuMois,SecondeOuAnnee);
        	         	    Affiche_LCD(DisplayBufferLigne0,DisplayBufferLigne1);
        	      		    SecondeOuAnnee_1 = SecondeOuAnnee;
        	      	    }
        	      	 }

        	      	else
        	      	{                       // Rglage des annes
        			    if ((SecondeOuAnnee_1 != SecondeOuAnnee) || (EtatGraphe_1 != EtatGraphe))
        			    {
        			        sprintf(DisplayBufferLigne0,"I>+ D>- O>J E>S");
        	                sprintf(DisplayBufferLigne1,"A: %-u/%-u/%-i",HeureOuJour, MinutesOuMois, SecondeOuAnnee);
        	         	    Affiche_LCD(DisplayBufferLigne0,DisplayBufferLigne1);
        	      		    SecondeOuAnnee_1 = SecondeOuAnnee;
        	      		}
        	      	}

        	      	switch(BpSSI)
        	      	 {
        	      	   case INC : SecondeOuAnnee = SecondeOuAnnee + 1;
                                    if (HeureOuDate == 0)
                                         {
                                          if (SecondeOuAnnee == 60) SecondeOuAnnee = 0;
                                         }
                                         else
                                         {
                                           if (SecondeOuAnnee == 2021) SecondeOuAnnee = 2010;
                                         }
                        break;

        	      		case DEC : SecondeOuAnnee = SecondeOuAnnee - 1;
                                    if (HeureOuDate == 0)
                                         {
                                          if (SecondeOuAnnee == -1) SecondeOuAnnee = 59;
                                         }
                                         else
                                         {
                                           if (SecondeOuAnnee == 2009) SecondeOuAnnee = 2020;
                                         }
                        break;
        	      		case OK  : EtatGraphe = RegleHeureOuDate; break;
        	      		case ECHAP : EtatGraphe = MiseAJourHTR; break;
        	      		default  : EtatGraphe = RegleSecondeAnnee;
        	      	 }

                     EtatGraphe_1 = RegleSecondeAnnee;

  break;
//------------------------------------------------------------------------------------------------------------------------------
  case MiseAJourHTR  :  // Ecriture des rglages dans l'HTR PCF8583
                   if (HeureOuDate == 1)
  				            rtc_set_date(AddPCF8583,HeureOuJour,MinutesOuMois,SecondeOuAnnee);
  			        else
  			  	            rtc_set_time(AddPCF8583,HeureOuJour,MinutesOuMois,SecondeOuAnnee,0);
  			        return 0;
  break;
//------------------------------------------------------------------------------------------------------------------------------
     }//fin switch
//------------------------------------------------------------------------------------------------------------------------------
   } //fin while
//------------------------------------------------------------------------------------------------------------------------------
} // fin SP
#endif
//----------------------------------------------------------------------------------------------------------------
//     		Fin de la liste des fonctions gnrales de la carte SSI
// ***************************************************************************************************************
// ***************************************************************************************************************

// ***************************************************************************************************************
// ***************************************************************************************************************
// 		       		Fonctions cres pour les PPE
// ***************************************************************************************************************
// Rcapitulatif
// PPE Acces lyce: D2000_read, D2000_write
// PPE Pousse seringue: Menu_Select_Seringue, Regdebit
// PPE Doppler: RegVitesse
//----------------------------------------------------------------------------------------------------------------
// 				PPE Accs Lyce
//----------------------------------------------------------------------------------------------------------------
// Gestion d'une mmoire I2C implant sur une carte type tlphonique
//----------------------------------------------------------------------------------------------------------------
// Cration : Mars 2003
// Dernire rvision: Mars 2003
//----------------------------------------------------------------------------------------------------------------
#if funcused D2000_read
unsigned char D2000_read(unsigned char adressmap)
{
 unsigned char data;
 i2c_start();                    // rponse mmoire non traiter
 i2c_write(0xa0);                //  terminer ....
 i2c_write(adressmap);
 i2c_start();
 i2c_write(0xa1);
 data = i2c_read(0);
 i2c_stop();
 return data;
}
#endif
//----------------------------------------------------------------------------------------------------------------
#if funcused D2000_write
void D2000_write(unsigned char adressmap, unsigned char data)
{
 i2c_start();                    // rponse mmoire non traiter
 i2c_write(0xa0);                //  terminer ....
 i2c_write(adressmap);
 i2c_write(data);
 i2c_stop();
// 30ms pour permettre  la mmoire de terminer son criture
 delay_ms(30);
}
#endif
//----------------------------------------------------------------------------------------------------------------

//----------------------------------------------------------------------------------------------------------------
// 				PPE Pousse seringue
//----------------------------------------------------------------------------------------------------------------
// Cration : Mars 2003
// Dernire rvision: 26 Octobre 2010
//----------------------------------------------------------------------------------------------------------------
#if funcused Regdebit
unsigned char Regdebit(unsigned int *dizaines,unsigned int *unites, unsigned int *diziemes)
{
// -----------------------------------------------------------------------------------------------------
// type 	    nom              				Description
// -----------------------------------------------------------------------------------------------------
 unsigned char  BP, etat=0, etat_1=1;               // Bouton-poussoir actionn et variables d'tat
 unsigned int   dizaines_1, unites_1, diziemes_1;   // Utiles  la stabilit de l'affichage
 char           display_buffer_ligne0[17];          // tampon ligne 0 de l'afficheur
 char           display_buffer_ligne1[17];          // tampon ligne 1 de l'afficheur


 while(1)
  {
   BP = Lire_BP();

   switch (etat)
	{
	  case 0 : // Rglage des dizaines
                if (*dizaines==-1) *dizaines = 9;
        		    else if (*dizaines == 10) *dizaines = 0;

   		        if ((dizaines_1 != *dizaines) || (etat_1 != etat))
        		    {
        		        sprintf(display_buffer_ligne0,"inc/dec=+/- ->Ok");
        	            sprintf(display_buffer_ligne1,"%-u%-u.%-u ml/h ->ENTR",*dizaines, *unites,*diziemes);
        	            Affiche_LCD(display_buffer_ligne0,display_buffer_ligne1);
        	            dizaines_1 = *dizaines;
        	   	    }

        	    switch(BP)
        	   	    {
        	    	    case INC   : *dizaines = *dizaines + 1; break;
        	    	    case DEC   : *dizaines = *dizaines - 1; break;
        	    	    case OK    : etat = 1; break;
        	   	        case ENTR  : etat = 3; break;
        	    	    default    : etat = 0;
        	    	}

        	    etat_1 = 0;
	  break;

	  case 1 : // Rglage des unites
                if (*unites==-1) *unites = 9;
        		    else if (*unites == 10) *unites = 0;

   		        if ((unites_1 != *unites) || (etat_1 != etat))
        		    {
        		        sprintf(display_buffer_ligne0,"inc/dec=+/- ->Ok");
        	            sprintf(display_buffer_ligne1,"%-u%-u.%-u ml/h ->ENTR",*dizaines, *unites,*diziemes);
        	            Affiche_LCD(display_buffer_ligne0,display_buffer_ligne1);
        	            unites_1 = *unites;
        	   	    }

        	   switch(BP)
        	   	    {
        	    	    case INC   : *unites = *unites + 1; break;
        	    	    case DEC   : *unites = *unites - 1; break;
        	    	    case OK    : etat = 2; break;
        	   	        case ENTR  : etat = 3; break;
        	    	    default    : etat = 1;
        	    	}

        	   etat_1 = 1;
	  break;

	  case 2 : // Rglage des dizimes
                if (*diziemes==-1) *diziemes = 9;
        		    else if (*diziemes == 10) *diziemes = 0;

   		        if ((diziemes_1 != *diziemes) || (etat_1 != etat))
        		    {
        		        sprintf(display_buffer_ligne0,"inc/dec=+/- ->Ok");
        	            sprintf(display_buffer_ligne1,"%-u%-u.%-u ml/h ->ENTR",*dizaines, *unites,*diziemes);
        	             Affiche_LCD(display_buffer_ligne0,display_buffer_ligne1);
        	            diziemes_1 = *diziemes;
        	   	    }
        	    switch(BP)
        	   	    {
        	    	    case INC   : *diziemes = *diziemes + 1; break;
        	    	    case DEC   : *diziemes = *diziemes - 1; break;
        	    	    case OK    : etat = 0; break;
        	   	        case ENTR  : etat = 3; break;
        	    	    default    : etat = 2;
        	    	}

        	    etat_1 = 2;
	  break;

	  case 3 :  return 0;

	  break;
	}
   }
}
#endif
//----------------------------------------------------------------------------------------------------------------
// Cration : Mars 2003
// Dernire rvision : 26 Octobre 2010
//----------------------------------------------------------------------------------------------------------------
#if funcused Menu_Select_Seringue
unsigned char Menu_Select_Seringue(void)
{
// ---------------------------------------------------------------------------------------------------------------
// type 	    nom              				Description
// ---------------------------------------------------------------------------------------------------------------
char display_buffer_ligne0[17]; // tampon ligne 0 de l'afficheur
char display_buffer_ligne1[17]; // tampon ligne 1 de l'afficheur
unsigned char BP;               // Touche actionne
int Choix_seringue=2, Choix_seringue_1=1;  // Stabilit de l'affichage
// ---------------------------------------------------------------------------------------------------------------
sprintf(display_buffer_ligne0,"inc/dec=+/- ->Ok");

while(1)
  {
   if (Choix_seringue_1 != Choix_seringue)
    {
      switch(Choix_seringue)
        {
          case 0 : sprintf(display_buffer_ligne1,"1/3 TERUMO 50CC"); break;
          case 1 : sprintf(display_buffer_ligne1,"2/3 MON/BD 50CC"); break;
          case 2 : sprintf(display_buffer_ligne1,"3/3     BD 20CC"); break;
          default: sprintf(display_buffer_ligne1,"       ????????");
        }
      Affiche_LCD(display_buffer_ligne0,display_buffer_ligne1);
      Choix_seringue_1 = Choix_seringue;
    }

   BP = Lire_BP();

   switch(BP)
    {
      case INC : Choix_seringue = Choix_seringue + 1;
                  if (Choix_seringue > 2) Choix_seringue = 0;
      break;

      case DEC : Choix_seringue = Choix_seringue - 1;
                 if (Choix_seringue < 0 ) Choix_seringue = 2;
      break;

      case OK  : return (char)Choix_seringue;
    }
  }
}
#endif
//-----------------------------------------------------------------------------------------------
//-----------------------------------------------------------------------------------------------
// 					PPE Doppler
//-----------------------------------------------------------------------------------------------
// Cration : Dcembre 2009
// Dernire rvision : Dcembre 2009
//-----------------------------------------------------------------------------------------------
#if funcused RegVitesse
unsigned int RegVitesse(unsigned int *unites,unsigned int *diziemes, unsigned int *centiemes)
{
 unsigned char BP, etat=0, etat_1=1;
 unsigned int unites_1,diziemes_1, centiemes_1;
 char display_buffer_ligne0[17]; // tampon ligne 0 de l'afficheur
 char display_buffer_ligne1[17]; // tampon ligne 1 de l'afficheur

 while(1)
  {
   BP = Lire_BP();
   switch (etat)
	{
	  case 0 : // Rglage des units
                   if (*unites==-1) *unites = 9;
        		else if (*unites == 10) *unites = 0;
   		   if ((unites_1 != *unites) || (etat_1 != etat))
        		{
        		  sprintf(display_buffer_ligne0,"inc/dec=+/- ->Ok");
        	          sprintf(display_buffer_ligne1,"%-u%-u.%-u mm/s ->ENTR",*unites, *diziemes,*centiemes);
        	          Affiche_LCD(display_buffer_ligne0,display_buffer_ligne1);

        	          unites_1 = *unites;
        	   	}
        	   switch(BP)
        	   	{
        	    	  case INC   : *unites = *unites + 1; break;
        	    	  case DEC   : *unites = *unites - 1; break;
        	    	  case OK    : etat = 1; break;
        	   	  case ENTR  : etat = 3; break;
        	    	  default    : etat = 0;
        	    	}
        	    	  etat_1 = 0;
	  break;

	  case 1 : // Rglage des dizimes
                   if (*diziemes==-1) *diziemes = 9;
        		else if (*diziemes == 10) *diziemes = 0;
   		   if ((diziemes_1 != *diziemes) || (etat_1 != etat))
        		{
        		  sprintf(display_buffer_ligne0,"inc/dec=+/- ->Ok");
        	          sprintf(display_buffer_ligne1,"%-u%-u.%-u mm/s ->ENTR",*unites, *diziemes,*centiemes);
        	          Affiche_LCD(display_buffer_ligne0,display_buffer_ligne1);
        	          diziemes_1 = *diziemes;
        	   	}
        	   switch(BP)
        	   	{
        	    	  case INC   : *diziemes = *diziemes + 1; break;
        	    	  case DEC   : *diziemes = *diziemes - 1; break;
        	    	  case OK    : etat = 2; break;
        	   	  case ENTR  : etat = 3; break;
        	    	  default    : etat = 1;
        	    	}
        	    	  etat_1 = 1;
	  break;

	  case 2 : // Rglage des centimes
                   if (*centiemes==-1) *centiemes = 9;
        		else if (*centiemes == 10) *centiemes = 0;
   		   if ((centiemes_1 != *centiemes) || (etat_1 != etat))
        		{
        		  sprintf(display_buffer_ligne0,"inc/dec=+/- ->Ok");
        	          sprintf(display_buffer_ligne1,"%-u%-u.%-u mm/s ->ENTR",*unites, *diziemes,*centiemes);
        	          Affiche_LCD(display_buffer_ligne0,display_buffer_ligne1);
        	          centiemes_1 = *centiemes;
        	   	}
        	   switch(BP)
        	   	{
        	    	  case INC   : *centiemes = *centiemes + 1; break;
        	    	  case DEC   : *centiemes = *centiemes - 1; break;
        	    	  case OK    : etat = 0; break;
        	   	  case ENTR  : etat = 3; break;
        	    	  default    : etat = 2;
        	    	}
        	    	  etat_1 = 2;
	  break;

	  case 3 :  return 0;
	  break;
	}
   }
}
#endif

//----------------------------------------------------------------------------------------------------------------
// Cration : Dcembre 2009
// Dernire rvision :  Dcembre 2009
//----------------------------------------------------------------------------------------------------------------
#if funcused Menu_Select_Sens
unsigned char Menu_Select_Sens(void)
{
#define RENTRER 	0
#define SORTIR  	1
//----------------------------------------------------------------------------------------------------------------
// Variables locales
//----------------------------------------------------------------------------------------------------------------
// type 	nom              				Description
//----------------------------------------------------------------------------------------------------------------
char display_buffer_ligne0[17]; 		// Tampon ligne 0 de l'afficheur
char display_buffer_ligne1[17]; 		// Tampon ligne 1 de l'afficheur
unsigned char BP; 				        // Code des BP de la carte SSI
int Choix_sens=RENTRER, Choix_sens_1=SORTIR;

sprintf(display_buffer_ligne0,"inc/dec=+/- ->Ok");

  while(1)
   {
    if (Choix_sens_1 != Choix_sens)
    {
       	switch(Choix_sens)
        {
          case RENTRER : sprintf(display_buffer_ligne1,"         Rentrer"); break;
          case SORTIR  : sprintf(display_buffer_ligne1,"          Sortir"); break;
        }
       Affiche_LCD(display_buffer_ligne0,display_buffer_ligne1);
       Choix_sens_1 = Choix_sens;
    }

   BP = Lire_BP();

   switch(BP)
    {
      case INC   : Choix_sens = Choix_sens + 1; break;
      case DEC   : Choix_sens = Choix_sens - 1; break;
      case OK    : return Choix_sens;
    }

   if (Choix_sens<=-1) Choix_sens = 1;
       else if (Choix_sens >= 2) Choix_sens = 0;
  }
}
#endif
//----------------------------------------------------------------------------------------------------------------
// Cration : Dcembre 2009
// Dernire rvision : Dcembre 2009
//----------------------------------------------------------------------------------------------------------------
#if funcused ActiveTimer
void ActiveTimer(void)
{
TCCR1A= 0x40;TCCR1B=0x04; TIMSK=0x04;
}
#endif
//----------------------------------------------------------------------------------------------------------------
// Cration : Dcembre 2009
// Dernire rvision : Dcembre 2009
//----------------------------------------------------------------------------------------------------------------
#if funcused DesactiveTimer
void DesactiveTimer(void)
{
TCCR1A=0x00; TCCR1B=0x00; TIMSK=0x00;
}
#endif
//----------------------------------------------------------------------------------------------------------------

